<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Conditions_Billing_Address' ) ) {

    class WTARS_Shipped_Admin_Conditions_Billing_Address {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-condition-groups', array( $this, 'get_groups' ), 50, 2 );
            add_filter( 'wtars_shipped_admin/get-billing_address-group-conditions', array( $this, 'get_conditions' ), 10, 2 );
            
            add_filter( 'wtars_shipped_admin/get-billing_continents-condition-fields', array( $this, 'get_continents_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-billing_countries-condition-fields', array( $this, 'get_countries_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-billing_states-condition-fields', array( $this, 'get_states_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-billing_cities-condition-fields', array( $this, 'get_cities_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-billing_postcodes-condition-fields', array( $this, 'get_postcodes_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'billing_address' ] = esc_html__( 'Billing Address', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_conditions( $in_list, $args ) {

            $in_list[ 'billing_continents' ] = esc_html__( 'Billing Continents', 'shipped-table-rate-shipping' );
            $in_list[ 'billing_countries' ] = esc_html__( 'Billing Countries', 'shipped-table-rate-shipping' );
            $in_list[ 'billing_states' ] = esc_html__( 'Billing States', 'shipped-table-rate-shipping' );
            $in_list[ 'billing_cities' ] = esc_html__( 'Billing Cities', 'shipped-table-rate-shipping' );
            $in_list[ 'billing_postcodes' ] = esc_html__( 'Billing Postcode / ZIP', 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public function get_continents_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'continents',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 1,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Billing Continents...', 'shipped-table-rate-shipping' ),
                'ajax_data' => 'wc:continents',
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public function get_countries_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'countries',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 2,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Billing Countries...', 'shipped-table-rate-shipping' ),
                'ajax_data' => 'wc:countries',
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public function get_states_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'states',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 2,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Billing States...', 'shipped-table-rate-shipping' ),
                'ajax_data' => 'wc:states',
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public function get_cities_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'cities',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Seperate with comma, (e.g Jakarta, Delhi, Manila)', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public function get_postcodes_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'match' => esc_html__( 'Match', 'shipped-table-rate-shipping' ),
                    'not_match' => esc_html__( 'Not match', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '22%',
            );

            $in_fields[] = array(
                'id' => 'postcode',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'e.g 1815, 870*, [1870 - 9999], DSE, LDS', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '78%',
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Conditions_Billing_Address();
}
