<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Conditions_DateTime' ) ) {

    class WTARS_Shipped_Admin_Conditions_DateTime {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-condition-groups', array( $this, 'get_groups' ), 150, 2 );
            add_filter( 'wtars_shipped_admin/get-datetimes-group-conditions', array( $this, 'get_conditions' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-date-condition-fields', array( $this, 'get_date_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-time-condition-fields', array( $this, 'get_time_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-date_time-condition-fields', array( $this, 'get_date_time_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-days_week-condition-fields', array( $this, 'get_days_week_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-days_month-condition-fields', array( $this, 'get_days_month_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-months_year-condition-fields', array( $this, 'get_months_year_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'datetimes' ] = esc_html__( 'Dates &amp; Times', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_conditions( $in_list, $args ) {

            $in_list[ 'date' ] = esc_html__( 'Date', 'shipped-table-rate-shipping' );
            $in_list[ 'time' ] = esc_html__( 'Time', 'shipped-table-rate-shipping' );
            $in_list[ 'date_time' ] = esc_html__( 'Date &amp; Time', 'shipped-table-rate-shipping' );
            $in_list[ 'days_week' ] = esc_html__( 'Days Of Week', 'shipped-table-rate-shipping' );
            $in_list[ 'days_month' ] = esc_html__( 'Days Of Month', 'shipped-table-rate-shipping' );
            $in_list[ 'months_year' ] = esc_html__( 'Months Of Year', 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public function get_date_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'date',
                'options' => array(
                    'date' => esc_html__( 'Specific date', 'shipped-table-rate-shipping' ),
                    'from' => esc_html__( 'From', 'shipped-table-rate-shipping' ),
                    'to' => esc_html__( 'To', 'shipped-table-rate-shipping' ),
                    'between' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'from_date',
                'type' => 'date',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd', 'shipped-table-rate-shipping' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'show_button_panel' => false,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '98%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'to_date',
                'type' => 'date',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd', 'shipped-table-rate-shipping' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'show_button_panel' => false,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'date',
                'type' => 'date',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd', 'shipped-table-rate-shipping' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'show_button_panel' => false,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'neq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public function get_time_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'time_type',
                'type' => 'select2',
                'default' => 'from',
                'options' => array(
                    'from' => esc_html__( 'From', 'shipped-table-rate-shipping' ),
                    'to' => esc_html__( 'To', 'shipped-table-rate-shipping' ),
                    'between' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'time_type',
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'from_time',
                'type' => 'time',
                'default' => '',
                'placeholder' => esc_html__( '00:00:00', 'shipped-table-rate-shipping' ),
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'time_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '98%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'to_time',
                'type' => 'time',
                'default' => '',
                'placeholder' => esc_html__( '00:00:00', 'shipped-table-rate-shipping' ),
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'time_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'time',
                'type' => 'time',
                'default' => '',
                'placeholder' => esc_html__( '00:00:00', 'shipped-table-rate-shipping' ),
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'time_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'neq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public function get_date_time_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'from',
                'options' => array(
                    'from' => esc_html__( 'From', 'shipped-table-rate-shipping' ),
                    'to' => esc_html__( 'To', 'shipped-table-rate-shipping' ),
                    'between' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '26%',
            );

            $in_fields[] = array(
                'id' => 'from_date_time',
                'type' => 'datetime',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd 00:00:00', 'shipped-table-rate-shipping' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '98%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'to_date_time',
                'type' => 'datetime',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd 00:00:00', 'shipped-table-rate-shipping' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '37%',
            );

            $in_fields[] = array(
                'id' => 'date_time',
                'type' => 'datetime',
                'default' => '',
                'placeholder' => esc_html__( 'yy-mm-dd 00:00:00', 'shipped-table-rate-shipping' ),
                'date_format' => 'yy-mm-dd',
                'number_of_months' => 1,
                'change_month' => true,
                'change_year' => true,
                'first_day' => 0,
                'time_format' => 'HH:mm:ss',
                'one_line' => true,
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'between',
                    'oparator' => 'neq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '74%',
            );

            return $in_fields;
        }

        public function get_days_week_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '27%'
            );

            $in_fields[] = array(
                'id' => 'days',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Days of week...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'options' => array(
                    '0' => esc_html__( 'Monday', 'shipped-table-rate-shipping' ),
                    '1' => esc_html__( 'Tuesday', 'shipped-table-rate-shipping' ),
                    '2' => esc_html__( 'Wednesday', 'shipped-table-rate-shipping' ),
                    '3' => esc_html__( 'Thursday', 'shipped-table-rate-shipping' ),
                    '4' => esc_html__( 'Friday', 'shipped-table-rate-shipping' ),
                    '5' => esc_html__( 'Saturday', 'shipped-table-rate-shipping' ),
                    '6' => esc_html__( 'Sunday', 'shipped-table-rate-shipping' ),
                ),
                'width' => '100%',
                'box_width' => '73%',
            );

            return $in_fields;
        }

        public function get_days_month_fields( $in_fields, $args ) {

            $days = array();

            for ( $i = 1; $i <= 31; $i++ ) {
                /* translators: 1: day of month */
                $day_text = sprintf( esc_html__( 'Day %s', 'shipped-table-rate-shipping' ), $i );

                $days[ $i ] = $day_text;
            }

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '27%',
            );

            $in_fields[] = array(
                'id' => 'days',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Days of month...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'options' => $days,
                'width' => '100%',
                'box_width' => '73%',
            );

            return $in_fields;
        }

        public function get_months_year_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '27%',
            );

            $in_fields[] = array(
                'id' => 'months',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Months...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'options' => array(
                    '1' => esc_html__( 'January', 'shipped-table-rate-shipping' ),
                    '2' => esc_html__( 'February', 'shipped-table-rate-shipping' ),
                    '3' => esc_html__( 'March', 'shipped-table-rate-shipping' ),
                    '4' => esc_html__( 'April', 'shipped-table-rate-shipping' ),
                    '5' => esc_html__( 'May', 'shipped-table-rate-shipping' ),
                    '6' => esc_html__( 'June', 'shipped-table-rate-shipping' ),
                    '7' => esc_html__( 'July', 'shipped-table-rate-shipping' ),
                    '8' => esc_html__( 'August', 'shipped-table-rate-shipping' ),
                    '9' => esc_html__( 'September', 'shipped-table-rate-shipping' ),
                    '10' => esc_html__( 'October', 'shipped-table-rate-shipping' ),
                    '11' => esc_html__( 'November', 'shipped-table-rate-shipping' ),
                    '12' => esc_html__( 'December', 'shipped-table-rate-shipping' ),
                ),
                'width' => '100%',
                'box_width' => '73%',
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Conditions_DateTime();
}