<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Admin_Conditions_Order' ) ) {

    class WTARS_Shipped_Premium_Admin_Conditions_Order {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-order-group-conditions', array( $this, 'get_conditions' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-cart_quantity-condition-fields', array( $this, 'get_quantity_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-cart_line_count-condition-fields', array( $this, 'get_line_count_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-package_line_count-condition-fields', array( $this, 'get_line_count_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-applied_coupons-condition-fields', array( $this, 'get_coupons_fields' ), 10, 2 );
        }

        public function get_conditions( $in_list, $args ) {

            $in_list[ 'cart_quantity' ] = esc_html__( 'Cart Total Quantity', 'shipped-table-rate-shipping' );
            $in_list[ 'package_quantity' ] = esc_html__( 'Package Total Quantity', 'shipped-table-rate-shipping' );
            $in_list[ 'cart_line_count' ] = esc_html__( 'Number Of Cart Items', 'shipped-table-rate-shipping' );
            $in_list[ 'package_line_count' ] = esc_html__( 'Number Of Package Items', 'shipped-table-rate-shipping' );
            $in_list[ 'applied_coupons' ] = esc_html__( 'Applied Coupons', 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public function get_quantity_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '--',
                'options' => array(
                    '--' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '99%',
                'box_width' => '44%',
                'fold_id' => 'order_quantity',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '56%',
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => 'order_quantity',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'from_quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '28%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => 'order_quantity',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'to_quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '28%',
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => 'order_quantity',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_line_count_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '--',
                'options' => array(
                    '--' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '99%',
                'box_width' => '44%',
                'fold_id' => 'order_line_count',
            );

            $in_fields[] = array(
                'id' => 'line_count',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '56%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => 'order_line_count',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'from_line_count',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '28%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => 'order_line_count',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'to_line_count',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '28%',
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => 'order_line_count',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_coupons_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'any' => esc_html__( 'Any list?', 'shipped-table-rate-shipping' ),
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'coupons_compare',
                'width' => '99%',
                'box_width' => '34%',
            );

            $in_fields[] = array(
                'id' => 'is_any',
                'type' => 'select2',
                'default' => 'yes',
                'options' => array(
                    'no' => esc_html__( 'No', 'shipped-table-rate-shipping' ),
                    'yes' => esc_html__( 'Yes', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'coupons_compare',
                    'attribute' => 'value',
                    'value' => 'any',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '66%',
            );

            $in_fields[] = array(
                'id' => 'coupons',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search coupons...', 'shipped-table-rate-shipping' ),
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'posts:shop_coupon',
                    'ajax' => true,
                ),
                'fold' => array(
                    'target' => 'coupons_compare',
                    'attribute' => 'value',
                    'value' => 'any',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '66%',
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Premium_Admin_Conditions_Order();
}