<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Admin_Conditions_Package_Items' ) ) {

    class WTARS_Shipped_Premium_Admin_Conditions_Package_Items {

        public function __construct() {
            add_filter( 'wtars_shipped_admin/get-package_items-group-conditions', array( $this, 'get_conditions' ), 10, 2 );
            
            add_filter( 'wtars_shipped_admin/get-package_vars-condition-fields', array( $this, 'get_variations_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-package_attrs-condition-fields', array( $this, 'get_attributes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-package_tax_classes-condition-fields', array( $this, 'get_tax_classes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-package_metas-condition-fields', array( $this, 'get_metas_fields' ), 10, 2 );
        }

        public function get_conditions( $in_list, $args ) {

            $in_list[ 'package_ids' ] = esc_html__( 'Products In Package', 'shipped-table-rate-shipping' );
            $in_list[ 'package_vars' ] = esc_html__( 'Variations In Package', 'shipped-table-rate-shipping' );
            $in_list[ 'package_cats' ] = esc_html__( 'Categories In Package', 'shipped-table-rate-shipping' );
            $in_list[ 'package_tags' ] = esc_html__( 'Tags In Package', 'shipped-table-rate-shipping' );
            $in_list[ 'package_attrs' ] = esc_html__( 'Attributes In Package', 'shipped-table-rate-shipping' );
            $in_list[ 'package_tax_classes' ] = esc_html__( 'Tax Classes In Package', 'shipped-table-rate-shipping' );
            $in_list[ 'package_sh_classes' ] = esc_html__( 'Shipping Classes In Package', 'shipped-table-rate-shipping' );
            $in_list[ 'package_metas' ] = esc_html__( 'Product Meta Fields In Package', 'shipped-table-rate-shipping' );

            return $in_list;
        }
        
        public function get_variations_fields( $in_fields, $args ){
            
            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '99%',
                'box_width' => '29%',
            );

            $in_fields[] = array(
                'id' => 'variation_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search variations...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:product_variations',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '71%',
            );

            return $in_fields;
        }
        
        public function get_attributes_fields( $in_fields, $args ){
            
            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '99%',
                'box_width' => '29%',
            );

            $in_fields[] = array(
                'id' => 'attribute_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search attributes...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:attributes',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '71%',
            );

            return $in_fields;
        }

        public function get_tax_classes_fields( $in_fields, $args ){
            
            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '99%',
                'box_width' => '29%',
            );

            $in_fields[] = array(
                'id' => 'tax_classes',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Select tax classes...', 'shipped-table-rate-shipping' ),
                'options' => array(
                    '--0' => esc_html__( 'Standard Rate', 'shipped-table-rate-shipping' )
                ),
                'data' => array(
                    'source' => 'wc:tax_classes',
                    'ajax' => false,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '71%',
            );

            return $in_fields;
        }
        
        public function get_metas_fields( $in_fields, $args ){
            
            $in_fields[] = array(
                'id' => 'meta_key',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Meta field key', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '40%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'empty',
                'options' => array(
                    'empty' => esc_html__( 'Empty', 'shipped-table-rate-shipping' ),
                    'contains' => esc_html__( 'Contains', 'shipped-table-rate-shipping' ),
                    'not_contains' => esc_html__( 'Not contains', 'shipped-table-rate-shipping' ),
                    'begins' => esc_html__( 'Begins with', 'shipped-table-rate-shipping' ),
                    'ends' => esc_html__( 'Ends with', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                    'checked' => esc_html__( 'Checked', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'meta_field_compare',
                'width' => '98%',
                'box_width' => '34%',
            );


            $in_fields[] = array(
                'id' => 'meta_value',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Value', 'shipped-table-rate-shipping' ),
                'fold' => array(
                    'target' => 'meta_field_compare',
                    'attribute' => 'value',
                    'value' => array( 'contains', 'not_contains', 'begins', 'ends', '>=', '>', '<=', '<', '==', '!=' ),
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '26%',
            );


            $in_fields[] = array(
                'id' => 'yes_no',
                'type' => 'select2',
                'default' => 'no',
                'options' => array(
                    'no' => esc_html__( 'No', 'shipped-table-rate-shipping' ),
                    'yes' => esc_html__( 'Yes', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'meta_field_compare',
                    'attribute' => 'value',
                    'value' => array( 'empty', 'checked' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '26%',
            );



            return $in_fields;
        }
    }

    new WTARS_Shipped_Premium_Admin_Conditions_Package_Items();
}
