<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Conditions_Purchase_History_Subtotal' ) ) {

    class WTARS_Shipped_Admin_Conditions_Purchase_History_Subtotal {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-condition-groups', array( $this, 'get_groups' ), 170, 2 );
            add_filter( 'wtars_shipped_admin/get-purchase_history_subtotal-group-conditions', array( $this, 'get_conditions' ), 10, 2 );
            
            add_filter( 'wtars_shipped_admin/get-purchased_products_subtotal-condition-fields', array( $this, 'get_products_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-purchased_variations_subtotal-condition-fields', array( $this, 'get_variations_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-purchased_categories_subtotal-condition-fields', array( $this, 'get_categories_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-purchased_tags_subtotal-condition-fields', array( $this, 'get_tags_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-purchased_attributes_subtotal-condition-fields', array( $this, 'get_attributes_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'purchase_history_subtotal' ] = esc_html__( 'Purchase History Subtotals', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_conditions( $in_list, $args ) {

            $in_list[ 'purchased_products_subtotal' ] = esc_html__( 'Purchased Products Subtotal', 'shipped-table-rate-shipping' );
            $in_list[ 'purchased_variations_subtotal' ] = esc_html__( 'Purchased Variations Subtotal', 'shipped-table-rate-shipping' );
            $in_list[ 'purchased_categories_subtotal' ] = esc_html__( 'Purchased Categories Subtotal', 'shipped-table-rate-shipping' );
            $in_list[ 'purchased_tags_subtotal' ] = esc_html__( 'Purchased Tags Subtotal', 'shipped-table-rate-shipping' );
            $in_list[ 'purchased_attributes_subtotal' ] = esc_html__( 'Purchased Attributes Subtotal', 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public function get_products_fields( $in_fields, $args ) {
            
            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '14%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'all_time_product_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search products...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:products',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '51%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'product_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search products...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:products',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '37%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '21%',
            );

            $in_fields[] = array(
                'id' => 'subtotal',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '14%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );

            return $in_fields;
        }

        public function get_variations_fields( $in_fields, $args ) {
            
            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '14%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );


            $in_fields[] = array(
                'id' => 'all_time_variation_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search variations...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:product_variations',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '51%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'variation_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search variations...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:product_variations',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '37%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '21%',
            );

            $in_fields[] = array(
                'id' => 'subtotal',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '14%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );

            return $in_fields;
        }

        public function get_categories_fields( $in_fields, $args ) {
            
            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '14%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );


            $in_fields[] = array(
                'id' => 'all_time_category_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search categories...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_cat',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '51%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'category_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search categories...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_cat',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '37%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '21%',
            );

            $in_fields[] = array(
                'id' => 'subtotal',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '14%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );

            return $in_fields;
        }

        public function get_tags_fields( $in_fields, $args ) {
            
            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '14%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );


            $in_fields[] = array(
                'id' => 'all_time_tag_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search tags...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_tag',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '51%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'tag_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search tags...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_tag',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '37%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '21%',
            );

            $in_fields[] = array(
                'id' => 'subtotal',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '14%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );

            return $in_fields;
        }

        public function get_attributes_fields( $in_fields, $args ) {
            
            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '14%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '14%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );


            $in_fields[] = array(
                'id' => 'all_time_attribute_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search attributes...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:attributes',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '51%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'attribute_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search attributes...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:attributes',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '99%',
                'box_width' => '37%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>',
                'options' => array(
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '21%',
            );

            $in_fields[] = array(
                'id' => 'subtotal',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '14%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Conditions_Purchase_History_Subtotal();
}