<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Conditions_Purchase_History' ) ) {

    class WTARS_Shipped_Admin_Conditions_Purchase_History {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-condition-groups', array( $this, 'get_groups' ), 160, 2 );
            add_filter( 'wtars_shipped_admin/get-purchase_history-group-conditions', array( $this, 'get_conditions' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-purchased_products-condition-fields', array( $this, 'get_products_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-purchased_variations-condition-fields', array( $this, 'get_variations_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-purchased_categories-condition-fields', array( $this, 'get_categories_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-purchased_tags-condition-fields', array( $this, 'get_tags_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-purchased_attributes-condition-fields', array( $this, 'get_attributes_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'purchase_history' ] = esc_html__( 'Purchase History', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_conditions( $in_list, $args ) {

            $in_list[ 'purchased_products' ] = esc_html__( 'Purchased Products', 'shipped-table-rate-shipping' );
            $in_list[ 'purchased_variations' ] = esc_html__( 'Purchased Variations', 'shipped-table-rate-shipping' );
            $in_list[ 'purchased_categories' ] = esc_html__( 'Purchased Categories', 'shipped-table-rate-shipping' );
            $in_list[ 'purchased_tags' ] = esc_html__( 'Purchased Tags', 'shipped-table-rate-shipping' );
            $in_list[ 'purchased_attributes' ] = esc_html__( 'Purchased Attributes', 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public function get_products_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '18%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '15%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '15%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '24%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'all_time_product_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search products...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:products',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '57%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'product_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search products...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:products',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '43%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_variations_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '18%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '15%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '15%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '24%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'all_time_variation_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search variations...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:product_variations',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '57%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'variation_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search variations...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:product_variations',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '43%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_categories_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '18%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '15%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '15%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '24%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'all_time_category_slugs',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 1,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Search categories...', 'shipped-table-rate-shipping' ),
                'data' => array(
                    'source' => 'categories:product_cat',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '57%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'category_slugs',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 1,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Search categories...', 'shipped-table-rate-shipping' ),
                'data' => array(
                    'source' => 'categories:product_cat',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '43%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_tags_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '18%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '15%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '15%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '24%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'all_time_tag_slugs',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 1,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Search tags...', 'shipped-table-rate-shipping' ),
                'data' => array(
                    'source' => 'categories:product_tag',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '57%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'tag_slugs',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 1,
                'minimum_results_forsearch' => 10,
                'placeholder' => esc_html__( 'Search tags...', 'shipped-table-rate-shipping' ),
                'data' => array(
                    'source' => 'categories:product_tag',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '43%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_attributes_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'date_type',
                'type' => 'select2',
                'default' => 'all_time',
                'options' => array(
                    'all_time' => esc_html__( 'All time', 'shipped-table-rate-shipping' ),
                    'current' => esc_html__( 'Current', 'shipped-table-rate-shipping' ),
                    'hours' => esc_html__( 'Hours', 'shipped-table-rate-shipping' ),
                    'days' => esc_html__( 'Days', 'shipped-table-rate-shipping' ),
                    'weeks' => esc_html__( 'Weeks', 'shipped-table-rate-shipping' ),
                    'months' => esc_html__( 'Months', 'shipped-table-rate-shipping' ),
                    'years' => esc_html__( 'Years', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'date_type',
                'width' => '98%',
                'box_width' => '18%',
            );

            $in_fields[] = array(
                'id' => 'current',
                'type' => 'select2',
                'default' => 'day',
                'options' => array(
                    'day' => esc_html__( 'Day', 'shipped-table-rate-shipping' ),
                    'week' => esc_html__( 'Week', 'shipped-table-rate-shipping' ),
                    'month' => esc_html__( 'Month', 'shipped-table-rate-shipping' ),
                    'year' => esc_html__( 'Year', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'current' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '15%',
            );

            $in_fields[] = array(
                'id' => 'date_offset',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '15%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => array( 'hours', 'days', 'weeks', 'months', 'years' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '24%',
            );

            $in_fields[] = array(
                'id' => 'all_time_compare',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'in_list' => esc_html__( 'Any in list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in list', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'all_time_attribute_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search attributes...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:attributes',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '57%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'attribute_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search attributes...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:attributes',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '43%',
                'fold' => array(
                    'target' => 'date_type',
                    'attribute' => 'value',
                    'value' => 'all_time',
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Conditions_Purchase_History();
}

