<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Cost_Type_Height' ) ) {

    class WTARS_Shipped_Admin_Cost_Type_Height {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-cost-type-groups', array( $this, 'get_groups' ), 60, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-group-types-heights', array( $this, 'get_types' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-cost-box-fields', array( $this, 'get_height_fields' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-products-required-ids', array( $this, 'get_products_required_ids' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-round-required-ids', array( $this, 'get_round_required_ids' ), 10, 2 );
            
            add_filter( 'wtars_shipped_admin/process-cost-type-per_height-options', array( $this, 'process_per_height_options' ), 10, 3 );
        }

        public function get_groups( $in_groups, $args ) {

            /* translators: 1: Cost text */
            $in_groups[ 'heights' ] = sprintf( esc_html__( '%s Per Height', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );

            return $in_groups;
        }

        public function get_types( $in_types, $args ) {

            $height_unit = get_option( 'woocommerce_dimension_unit' );

            /* translators: 1: Cost text 2: height unit */
            $in_types[ 'per_height' ] = sprintf( esc_html__( '%1$s per height (%2$s)', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ], $height_unit );
            /* translators: 1: Cost text 2: height unit */
            $in_types[ 'by_height' ] = sprintf( esc_html__( '%1$s x height (%2$s)', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ], $height_unit );

            return $in_types;
        }

        public function get_height_fields( $in_fields, $args ) {

            $height_unit = get_option( 'woocommerce_dimension_unit' );

            $in_fields[] = array(
                'id' => 'height',
                'type' => 'textbox',
                'input_type' => 'number',
                /* translators: 1: height unit */
                'tooltip' => sprintf( esc_html__( 'Controls the height multiplier in (%s)', 'shipped-table-rate-shipping' ), $height_unit ),
                'column_size' => 2,
                /* translators: 1: height unit */
                'column_title' => sprintf( esc_html__( 'Height Multiplier (%s)', 'shipped-table-rate-shipping' ), $height_unit ),
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_height' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_round_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_height';

            return $in_ids;
        }

        public function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_height';
            $in_ids[] = 'by_height';

            return $in_ids;
        }

        public function process_per_height_options( $cost, $raw_cost, $args ) {

            $cost[ 'height' ] = 0;

            if ( isset( $raw_cost[ 'height' ] ) && is_numeric( $raw_cost[ 'height' ] ) ) {
                $cost[ 'height' ] = $raw_cost[ 'height' ];
            }

            if ( isset( $raw_cost[ 'round' ] ) ) {
                $cost[ 'round' ] = $raw_cost[ 'round' ];
            }

            return $cost;
        }
        
    }

    new WTARS_Shipped_Admin_Cost_Type_Height();
}