<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WTARS_Shipped_Admin_Cost_Type_Order_Items' ) ) {

    class WTARS_Shipped_Admin_Cost_Type_Order_Items {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-cost-type-groups', array( $this, 'get_groups' ), 20, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-group-types-order_items', array( $this, 'get_types' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-cost-box-fields', array( $this, 'get_quantity_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-type-fields', array( $this, 'get_quantity_range_fields' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-item-based-on-required-ids', array( $this, 'get_item_based_on_required_ids' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-products-required-ids', array( $this, 'get_products_required_ids' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-round-required-ids', array( $this, 'get_round_required_ids' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/process-cost-type-per_quantity-options', array( $this, 'process_per_quantity_options' ), 10, 3 );
            add_filter( 'wtars_shipped_admin/process-cost-type-per_cost_item-options', array( $this, 'process_per_cost_item_options' ), 10, 3 );
        }

        public function get_groups( $in_groups, $args ) {

            /* translators: 1: Cost text */
            $in_groups[ 'order_items' ] = sprintf( esc_html__( '%s Per Items', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );

            return $in_groups;
        }

        public function get_types( $in_types, $args ) {

            /* translators: 1: Cost text */
            $in_types[ 'per_line' ] = sprintf( esc_html__( '%s per line item', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );
           /* translators: 1: Cost text */
            $in_types[ 'per_quantity' ] = sprintf( esc_html__( '%s per item quantity', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );
            /* translators: 1: Cost text */
            $in_types[ 'per_product' ] = sprintf( esc_html__( '%s per product', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );
            /* translators: 1: Cost text */
            $in_types[ 'per_variation' ] = sprintf( esc_html__( '%s per variation', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );
            /* translators: 1: Cost text */
            $in_types[ 'per_cost_item' ] = sprintf( esc_html__( 'Percentage %s per item', 'shipped-table-rate-shipping' ), $args[ 'format_text' ] );

            return $in_types;
        }

        public function get_quantity_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => esc_html__( 'Controls the item quantity multiplier', 'shipped-table-rate-shipping' ),
                'column_size' => 2,
                'column_title' => esc_html__( 'Quantity Multiplier', 'shipped-table-rate-shipping' ),
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_quantity' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_item_based_on_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_cost_item';

            return $in_ids;
        }

        public function get_round_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_quantity';

            return $in_ids;
        }

        public function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_line';
            $in_ids[] = 'per_quantity';
            $in_ids[] = 'per_product';
            $in_ids[] = 'per_variation';
            $in_ids[] = 'per_cost_item';

            return $in_ids;
        }

        public function get_quantity_range_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'any_id',
                'type' => 'columns-field',
                'columns' => 4,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'quantity_range',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Tiered - Quantity Range', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Specify whether a tiered quantity range should be considered for calculations', 'shipped-table-rate-shipping' ),
                        'minimum_results_forsearch' => 10,
                        'options' => array(
                            'no' => esc_html__( 'Do not use tiered quantity range for calculation', 'shipped-table-rate-shipping' ),
                            'yes' => esc_html__( 'Use tiered tiered range for calculation', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                        'fold_id' => 'quantity_range',
                    ),
                    array(
                        'id' => 'quantity_from',
                        'type' => 'textbox',
                        'input_type' => 'number',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Quantity - From', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Specify the starting quantity for tiered quantity range. This field allows you to define the lower limit of the tiered range.', 'shipped-table-rate-shipping' ),
                        'default' => '1',
                        'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                        'width' => '100%',
                        'attributes' => array(
                            'min' => '1',
                            'step' => '1',
                        ),
                        'fold' => array(
                            'target' => 'quantity_range',
                            'attribute' => 'value',
                            'value' => array( 'yes' ),
                            'oparator' => 'eq',
                            'clear' => false,
                        ),
                    ),
                    array(
                        'id' => 'quantity_to',
                        'type' => 'textbox',
                        'input_type' => 'number',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Quantity - To', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Specify the ending quantity for tiered quantity range. This field allows you to define the upper limit of the tiered range', 'shipped-table-rate-shipping' ),
                        'placeholder' => esc_html__( 'To - No limit', 'shipped-table-rate-shipping' ),
                        'width' => '100%',
                        'attributes' => array(
                            'min' => '1',
                            'step' => '1',
                        ),
                        'fold' => array(
                            'target' => 'quantity_range',
                            'attribute' => 'value',
                            'value' => array( 'yes' ),
                            'oparator' => 'eq',
                            'clear' => false,
                        ),
                    ),
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_quantity' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );



            return $in_fields;
        }

        public function process_per_quantity_options( $cost, $raw_cost, $args ) {

            $cost[ 'quantity' ] = 1;

            if ( isset( $raw_cost[ 'quantity' ] ) && is_numeric( $raw_cost[ 'quantity' ] ) ) {
                $cost[ 'quantity' ] = $raw_cost[ 'quantity' ];
            }

            if ( isset( $raw_cost[ 'round' ] ) ) {
                $cost[ 'round' ] = $raw_cost[ 'round' ];
            }
            
            if ( isset( $raw_cost[ 'quantity_range' ] ) ) {
                $cost[ 'quantity_range' ] = $raw_cost[ 'quantity_range' ];
            }

            if ( isset( $raw_cost[ 'quantity_from' ] ) && is_numeric( $raw_cost[ 'quantity_from' ] ) ) {
                $cost[ 'quantity_from' ] = $raw_cost[ 'quantity_from' ];
            }

            if ( isset( $raw_cost[ 'quantity_to' ] ) && is_numeric( $raw_cost[ 'quantity_to' ] ) ) {
                $cost[ 'quantity_to' ] = $raw_cost[ 'quantity_to' ];
            }

            return $cost;
        }

        public function process_per_cost_item_options( $cost, $raw_cost, $args ) {

            if ( isset( $raw_cost[ 'item_based_on' ] ) ) {
                $cost[ 'item_based_on' ] = $raw_cost[ 'item_based_on' ];
            }

            return $cost;
        }

    }

    new WTARS_Shipped_Admin_Cost_Type_Order_Items();
}