<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WTARS_Shipped_Premium_Admin_Cost_Type_Order' ) ) {

    class WTARS_Shipped_Premium_Admin_Cost_Type_Order {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-cost-group-types-order', array( $this, 'get_types' ), 20, 2 );

            add_filter( 'wtars_shipped_admin/get-cost-type-per_shipping_classes-fields', array( $this, 'get_per_shipping_classes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-type-per_categories-fields', array( $this, 'get_per_categories_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-type-per_tags-fields', array( $this, 'get_per_tags_fields' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-based-on-required-ids', array( $this, 'get_based_on_required_ids' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/process-cost-type-per_shipping_classes-options', array( $this, 'process_per_shipping_classes_options' ), 10, 3 );
            add_filter( 'wtars_shipped_admin/process-cost-type-per_categories-options', array( $this, 'process_per_categories_options' ), 10, 3 );
            add_filter( 'wtars_shipped_admin/process-cost-type-per_tags-options', array( $this, 'process_per_tags_options' ), 10, 3 );
            add_filter( 'wtars_shipped_admin/process-cost-type-per_cost-options', array( $this, 'process_per_cost_options' ), 10, 3 );
        }

        public function get_types( $in_types, $args ) {

            /* translators: 1: Cost text */
            $in_types[ 'per_shipping_classes' ] = sprintf( esc_html__( '%s per shipping classes', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );
            /* translators: 1: Cost text */
            $in_types[ 'per_categories' ] = sprintf( esc_html__( '%s per categories', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );
            /* translators: 1: Cost text */
            $in_types[ 'per_tags' ] = sprintf( esc_html__( '%s per tags', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );
            /* translators: 1: Cost text */
            $in_types[ 'per_cost' ] = sprintf( esc_html__( 'Percentage %s', 'shipped-table-rate-shipping' ), $args[ 'format_text' ] );

            return $in_types;
        }

        public function get_per_shipping_classes_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'shipping_classes_args',
                'type' => 'columns-field',
                'columns' => 8,
                'merge_fields' => true,
                'fields' => array(
                    array(
                        'id' => 'shipping_classes',
                        'type' => 'select2',
                        'column_size' => 6,
                        'column_title' => esc_html__( 'Shipping Classes', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Controls which shipping classes should be included', 'shipped-table-rate-shipping' ),
                        'default' => '',
                        'multiple' => true,
                        'minimum_input_length' => 1,
                        'minimum_results_forsearch' => 10,
                        'placeholder' => esc_html__( 'Search shipping classes...', 'shipped-table-rate-shipping' ),
                        'data' => array(
                            'source' => 'wc:shipping_classes',
                            'ajax' => true,
                            'value_col' => 'slug',
                            'show_value' => false,
                        ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'compare',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Equals To', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Controls how the shipping classes should be included', 'shipped-table-rate-shipping' ),
                        'default' => 'in_list',
                        'options' => array(
                            'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                            'none' => esc_html__( 'Any NOT in the list', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                    ),
                ),
            );

            return $in_fields;
        }

        public function get_per_categories_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'product_categories_args',
                'type' => 'columns-field',
                'columns' => 8,
                'merge_fields' => true,
                'fields' => array(
                    array(
                        'id' => 'product_categories',
                        'type' => 'select2',
                        'column_size' => 6,
                        'column_title' => esc_html__( 'Product Categories', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Controls which product categories should be included', 'shipped-table-rate-shipping' ),
                        'default' => '',
                        'multiple' => true,
                        'minimum_input_length' => 1,
                        'minimum_results_forsearch' => 10,
                        'placeholder' => esc_html__( 'Search product categories...', 'shipped-table-rate-shipping' ),
                        'data' => array(
                            'source' => 'categories:product_cat',
                            'ajax' => true,
                            'value_col' => 'slug',
                            'show_value' => false,
                        ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'compare',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Equals To', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Controls how the categories should be included', 'shipped-table-rate-shipping' ),
                        'default' => 'in_list',
                        'options' => array(
                            'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                            'none' => esc_html__( 'Any NOT in the list', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                    ),
                ),
            );

            return $in_fields;
        }

        public function get_per_tags_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'product_tags_args',
                'type' => 'columns-field',
                'columns' => 8,
                'merge_fields' => true,
                'fields' => array(
                    array(
                        'id' => 'product_tags',
                        'type' => 'select2',
                        'column_size' => 6,
                        'column_title' => esc_html__( 'Product Tags', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Controls which product tags should be included', 'shipped-table-rate-shipping' ),
                        'default' => '',
                        'multiple' => true,
                        'minimum_input_length' => 1,
                        'minimum_results_forsearch' => 10,
                        'placeholder' => esc_html__( 'Search product tags...', 'shipped-table-rate-shipping' ),
                        'data' => array(
                            'source' => 'categories:product_tag',
                            'ajax' => true,
                            'value_col' => 'slug',
                            'show_value' => false,
                        ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'compare',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Equals To', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Controls how the product tags should be included', 'shipped-table-rate-shipping' ),
                        'default' => 'in_list',
                        'options' => array(
                            'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                            'none' => esc_html__( 'Any NOT in the list', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                    ),
                ),
            );

            return $in_fields;
        }

        public function get_based_on_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_cost';

            return $in_ids;
        }

        public function process_per_shipping_classes_options( $cost, $raw_cost, $args ) {

            if ( isset( $raw_cost[ 'shipping_classes_args' ] ) ) {
                $cost[ 'shipping_classes_args' ] = $raw_cost[ 'shipping_classes_args' ];
            }

            return $cost;
        }

        public function process_per_categories_options( $cost, $raw_cost, $args ) {

            if ( isset( $raw_cost[ 'product_categories_args' ] ) ) {
                $cost[ 'product_categories_args' ] = $raw_cost[ 'product_categories_args' ];
            }

            return $cost;
        }

        public function process_per_tags_options( $cost, $raw_cost, $args ) {

            if ( isset( $raw_cost[ 'product_tags_args' ] ) ) {
                $cost[ 'product_tags_args' ] = $raw_cost[ 'product_tags_args' ];
            }

            return $cost;
        }

        public function process_per_cost_options( $cost, $raw_cost, $args ) {

            if ( isset( $raw_cost[ 'based_on' ] ) ) {
                $cost[ 'based_on' ] = $raw_cost[ 'based_on' ];
            }

            return $cost;
        }

    }

    new WTARS_Shipped_Premium_Admin_Cost_Type_Order();
}
