<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Cost_Type_Surface_Area' ) ) {

    class WTARS_Shipped_Admin_Cost_Type_Surface_Area {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-cost-type-groups', array( $this, 'get_groups' ), 70, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-group-types-surface_areas', array( $this, 'get_types' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-cost-box-fields', array( $this, 'get_surface_area_fields' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-products-required-ids', array( $this, 'get_products_required_ids' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-round-required-ids', array( $this, 'get_round_required_ids' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/process-cost-type-per_surface_area-options', array( $this, 'process_per_surface_area_options' ), 10, 3 );
        }

        public function get_groups( $in_groups, $args ) {

            /* translators: 1: Cost text */
            $in_groups[ 'surface_areas' ] = sprintf( esc_html__( '%s Per Surface Area', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );

            return $in_groups;
        }

        public function get_types( $in_types, $args ) {

            $surface_area_unit = get_option( 'woocommerce_dimension_unit' );

            /* translators: 1: Cost text 2: surface area unit */
            $in_types[ 'per_surface_area' ] = sprintf( esc_html__( '%1$s per surface area (square %2$s)', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ], $surface_area_unit );
            /* translators: 1: Cost text 2: surface area unit */
            $in_types[ 'by_surface_area' ] = sprintf( esc_html__( '%1$s x surface area (square %2$s)', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ], $surface_area_unit );

            return $in_types;
        }

        public function get_surface_area_fields( $in_fields, $args ) {

            $height_unit = get_option( 'woocommerce_dimension_unit' );

            $in_fields[] = array(
                'id' => 'surface_area',
                'type' => 'textbox',
                'input_type' => 'number',
                /* translators: 1: surface area unit */
                'tooltip' => sprintf( esc_html__( 'Controls the surface area multiplier in (square %s)', 'shipped-table-rate-shipping' ), $height_unit ),
                'column_size' => 2,
                /* translators: 1: surface area unit */
                'column_title' => sprintf( esc_html__( 'Surface Area (sqr. %s)', 'shipped-table-rate-shipping' ), $height_unit ),
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_surface_area' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_round_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_surface_area';

            return $in_ids;
        }

        public function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_surface_area';
            $in_ids[] = 'by_surface_area';

            return $in_ids;
        }

        public function process_per_surface_area_options( $cost, $raw_cost, $args ) {

            $cost[ 'surface_area' ] = 0;

            if ( isset( $raw_cost[ 'surface_area' ] ) && is_numeric( $raw_cost[ 'surface_area' ] ) ) {
                $cost[ 'surface_area' ] = $raw_cost[ 'surface_area' ];
            }

            if ( isset( $raw_cost[ 'round' ] ) ) {
                $cost[ 'round' ] = $raw_cost[ 'round' ];
            }

            return $cost;
        }

    }

    new WTARS_Shipped_Admin_Cost_Type_Surface_Area();
}