<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Cost_Type_Volume' ) ) {

    class WTARS_Shipped_Admin_Cost_Type_Volume {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-cost-type-groups', array( $this, 'get_groups' ), 80, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-group-types-volumes', array( $this, 'get_types' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-cost-box-fields', array( $this, 'get_volume_fields' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-products-required-ids', array( $this, 'get_products_required_ids' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-round-required-ids', array( $this, 'get_round_required_ids' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/process-cost-type-per_volume-options', array( $this, 'process_per_volume_options' ), 10, 3 );
        }

        public function get_groups( $in_groups, $args ) {

            /* translators: 1: Cost text */
            $in_groups[ 'volumes' ] = sprintf( esc_html__( '%s Per Volume', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );

            return $in_groups;
        }

        public function get_types( $in_types, $args ) {

            $volume_unit = get_option( 'woocommerce_dimension_unit' );

            /* translators: 1: Cost text 2: volume unit */
            $in_types[ 'per_volume' ] = sprintf( esc_html__( '%1$s per volume (cubic %2$s)', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ], $volume_unit );
            /* translators: 1: Cost text 2: volume unit */
            $in_types[ 'by_volume' ] = sprintf( esc_html__( '%1$s x volume (cubic %2$s)', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ], $volume_unit );

            return $in_types;
        }

        public function get_volume_fields( $in_fields, $args ) {

            $height_unit = get_option( 'woocommerce_dimension_unit' );

            $in_fields[] = array(
                'id' => 'volume',
                'type' => 'textbox',
                'input_type' => 'number',
                /* translators: 1: volume unit */
                'tooltip' => sprintf( esc_html__( 'Controls the volume multiplier in (cubic %s)', 'shipped-table-rate-shipping' ), $height_unit ),
                'column_size' => 2,
                /* translators: 1: volume unit */
                'column_title' => sprintf( esc_html__( 'Volume (cubic %s)', 'shipped-table-rate-shipping' ), $height_unit ),
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_volume' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_round_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_volume';

            return $in_ids;
        }

        public function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_volume';
            $in_ids[] = 'by_volume';

            return $in_ids;
        }

        public function process_per_volume_options( $cost, $raw_cost, $args ) {

            $cost[ 'volume' ] = 0;

            if ( isset( $raw_cost[ 'volume' ] ) && is_numeric( $raw_cost[ 'volume' ] ) ) {
                $cost[ 'volume' ] = $raw_cost[ 'volume' ];
            }

            if ( isset( $raw_cost[ 'round' ] ) ) {
                $cost[ 'round' ] = $raw_cost[ 'round' ];
            }

            return $cost;
        }

    }

    new WTARS_Shipped_Admin_Cost_Type_Volume();
}
