<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WTARS_Shipped_Admin_Cost_Type_Weight' ) ) {

    class WTARS_Shipped_Admin_Cost_Type_Weight {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-cost-type-groups', array( $this, 'get_groups' ), 20, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-group-types-weights', array( $this, 'get_types' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-cost-box-fields', array( $this, 'get_weight_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-type-fields', array( $this, 'get_weight_calculator_fields' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-products-required-ids', array( $this, 'get_products_required_ids' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-round-required-ids', array( $this, 'get_round_required_ids' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/process-cost-type-per_weight-options', array( $this, 'process_per_weight_options' ), 10, 3 );
            add_filter( 'wtars_shipped_admin/process-cost-type-by_weight-options', array( $this, 'process_by_weight_options' ), 10, 3 );
        }

        public function get_groups( $in_groups, $args ) {

            /* translators: 1: Cost text */
            $in_groups[ 'weights' ] = sprintf( esc_html__( '%s Per Weight', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ] );

            return $in_groups;
        }

        public function get_types( $in_types, $args ) {

            $weight_unit = get_option( 'woocommerce_weight_unit' );

            /* translators: 1: Cost text 2: weight unit */
            $in_types[ 'per_weight' ] = sprintf( esc_html__( '%1$s per weight (%2$s)', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ], $weight_unit );
            /* translators: 1: Cost text 2: weight unit */
            $in_types[ 'by_weight' ] = sprintf( esc_html__( '%1$s x weight (%2$s)', 'shipped-table-rate-shipping' ), $args[ 'format_cap_text' ], $weight_unit );

            return $in_types;
        }

        public function get_weight_fields( $in_fields, $args ) {

            $weight_unit = get_option( 'woocommerce_weight_unit' );

            $in_fields[] = array(
                'id' => 'weight',
                'type' => 'textbox',
                'input_type' => 'number',
                /* translators: 1: weight unit */
                'tooltip' => sprintf( esc_html__( 'Controls the weight multiplier in (%s)', 'shipped-table-rate-shipping' ), $weight_unit ),
                'column_size' => 2,
                /* translators: 1: weight unit */
                'column_title' => sprintf( esc_html__( 'Weight Multiplier (%s)', 'shipped-table-rate-shipping' ), $weight_unit ),
                'default' => '0.5',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_weight' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_weight_calculator_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'any_id',
                'type' => 'columns-field',
                'columns' => 6,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'weight_based_on',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Weight Calculator', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Controls weight calculation based on formula', 'shipped-table-rate-shipping' ),
                        'minimum_results_forsearch' => 10,
                        'data' => 'shipped:weight_calcs',
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'weight_range',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Tiered - Weight Range', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Specify whether a tiered weight range should be considered for calculations', 'shipped-table-rate-shipping' ),
                        'minimum_results_forsearch' => 10,
                        'options' => array(
                            'no' => esc_html__( 'Do not use tiered weight range for calculation', 'shipped-table-rate-shipping' ),
                            'yes' => esc_html__( 'Use tiered weight range for calculation', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                        'fold_id' => 'weight_range',
                    ),
                    array(
                        'id' => 'weight_from',
                        'type' => 'textbox',
                        'input_type' => 'number',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Weight - From', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Specify the starting weight for the tiered weight range. This field allows you to define the lower limit of the tiered range.', 'shipped-table-rate-shipping' ),
                        'default' => '0.00',
                        'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                        'width' => '100%',
                        'attributes' => array(
                            'min' => '0',
                            'step' => '0.01',
                        ),
                        'fold' => array(
                            'target' => 'weight_range',
                            'attribute' => 'value',
                            'value' => array( 'yes' ),
                            'oparator' => 'eq',
                            'clear' => false,
                        ),
                    ),
                    array(
                        'id' => 'weight_to',
                        'type' => 'textbox',
                        'input_type' => 'number',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Weight - To', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Specify the ending weight for the tiered weight range. This field allows you to define the upper limit of the tiered range', 'shipped-table-rate-shipping' ),
                        'placeholder' => esc_html__( 'To - No limit', 'shipped-table-rate-shipping' ),
                        'width' => '100%',
                        'attributes' => array(
                            'min' => '0',
                            'step' => '0.01',
                        ),
                        'fold' => array(
                            'target' => 'weight_range',
                            'attribute' => 'value',
                            'value' => array( 'yes' ),
                            'oparator' => 'eq',
                            'clear' => false,
                        ),
                    ),
                ),
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => array( 'per_weight', 'by_weight' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );



            return $in_fields;
        }

        public function get_round_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_weight';

            return $in_ids;
        }

        public function get_products_required_ids( $in_ids, $args ) {

            $in_ids[] = 'per_weight';
            $in_ids[] = 'by_weight';

            return $in_ids;
        }

        public function process_per_weight_options( $cost, $raw_cost, $args ) {

            $cost[ 'weight' ] = 0;

            if ( isset( $raw_cost[ 'weight' ] ) && is_numeric( $raw_cost[ 'weight' ] ) ) {
                $cost[ 'weight' ] = $raw_cost[ 'weight' ];
            }

            if ( isset( $raw_cost[ 'round' ] ) ) {
                $cost[ 'round' ] = $raw_cost[ 'round' ];
            }

            if ( isset( $raw_cost[ 'weight_based_on' ] ) ) {
                $cost[ 'weight_based_on' ] = $raw_cost[ 'weight_based_on' ];
            }

            if ( isset( $raw_cost[ 'weight_range' ] ) ) {
                $cost[ 'weight_range' ] = $raw_cost[ 'weight_range' ];
            }

            if ( isset( $raw_cost[ 'weight_from' ] ) && is_numeric( $raw_cost[ 'weight_from' ] ) ) {
                $cost[ 'weight_from' ] = $raw_cost[ 'weight_from' ];
            }

            if ( isset( $raw_cost[ 'weight_to' ] ) && is_numeric( $raw_cost[ 'weight_to' ] ) ) {
                $cost[ 'weight_to' ] = $raw_cost[ 'weight_to' ];
            }

            return $cost;
        }

        public function process_by_weight_options( $cost, $raw_cost, $args ) {

            if ( isset( $raw_cost[ 'weight_based_on' ] ) ) {
                $cost[ 'weight_based_on' ] = $raw_cost[ 'weight_based_on' ];
            }
            
            if ( isset( $raw_cost[ 'weight_range' ] ) ) {
                $cost[ 'weight_range' ] = $raw_cost[ 'weight_range' ];
            }

            if ( isset( $raw_cost[ 'weight_from' ] ) && is_numeric( $raw_cost[ 'weight_from' ] ) ) {
                $cost[ 'weight_from' ] = $raw_cost[ 'weight_from' ];
            }

            if ( isset( $raw_cost[ 'weight_to' ] ) && is_numeric( $raw_cost[ 'weight_to' ] ) ) {
                $cost[ 'weight_to' ] = $raw_cost[ 'weight_to' ];
            }

            return $cost;
        }

    }

    new WTARS_Shipped_Admin_Cost_Type_Weight();
}