<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Admin_Cost_Types' ) ) {

    ReonUtil::recursive_require( dirname( __FILE__ ), array( 'cost-types.php' ) );

    class WTARS_Shipped_Premium_Admin_Cost_Types {

        private static $extr_per_types = array();

        public function __construct() {
            add_filter( 'wtars_shipped_admin/get-cost-box-fields', array( $this, 'get_cost_box_fields' ), 999, 2 );
            add_filter( 'wtars_shipped_admin/get-cost-add-methods', array( $this, 'get_cost_add_methods' ), 10, 2 );
        }

        public function get_cost_add_methods( $options, $args ) {

            $module_text = '';

            if ( 'shipping-rates' == $args[ 'module' ] ) {
                $module_text = esc_html__( 'costs', 'shipped-table-rate-shipping' );
            }

            if ( 'cart-fees' == $args[ 'module' ] ) {
                $module_text = esc_html__( 'fees', 'shipped-table-rate-shipping' );
            }

            /* translators: 1: module cost text */
            $options[ 'sub' ] = sprintf( esc_html__( 'Subtract from previous %s', 'shipped-table-rate-shipping' ), $module_text );
            /* translators: 1: module cost text */
            $options[ 'set' ] = sprintf( esc_html__( 'Override previous %s', 'shipped-table-rate-shipping' ), $module_text );

            return $options;
        }

        public function get_cost_box_fields( $in_fields, $args ) {

            $module_text = esc_html__( 'cost', 'shipped-table-rate-shipping' );

            if ( 'cart-fees' == $args[ 'module' ] ) {
                $module_text = esc_html__( 'fee', 'shipped-table-rate-shipping' );
            }

            $in_fields[] = array(
                'id' => 'round',
                'type' => 'select2',
                'column_size' => 2,
                'column_title' => esc_html__( 'Round To Multiplier', 'shipped-table-rate-shipping' ),
                'tooltip' => esc_html__( 'Controls multiplier rounding, e.g if multiplier is 0.5 and total value is 2.25, the rouded value will be 2.5 (round up) or 2.0 (round down)', 'shipped-table-rate-shipping' ),
                'default' => 'rate_cost',
                'disabled_list_filter' => 'wtars_shipped_admin/get-disabled-list',
                'options' => array(
                    'no' => esc_html__( 'No rounding', 'shipped-table-rate-shipping' ),
                    'round_up' => esc_html__( 'Round up', 'shipped-table-rate-shipping' ),
                    'round_down' => esc_html__( 'Round down', 'shipped-table-rate-shipping' ),
                    'round_up_down' => esc_html__( 'Round to nearest', 'shipped-table-rate-shipping' ),
                ),
                'width' => '100%',
                'fold' => array(
                    'target' => $args[ 'fold_id' ],
                    'attribute' => 'value',
                    'value' => $this->get_round_on_required_ids( $args ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'based_on',
                'type' => 'select2',
                'column_size' => 4,
                'column_title' => esc_html__( 'Based On', 'shipped-table-rate-shipping' ),
                /* translators: 1: module cost text */
                'tooltip' => sprintf( esc_html__( 'Controls %s based on cart or package totals', 'shipped-table-rate-shipping' ), $module_text ),
                'default' => '2234343',
                'data' => 'shipped:checkout_totals',
                'width' => '100%',
                'fold' => array(
                    'target' => 'cost_type',
                    'attribute' => 'value',
                    'value' => $this->get_based_on_required_ids( $args ),
                    'oparator' => 'eq',
                    'clear' => true,
                    'empty' => '2234343',
                ),
            );

            $in_fields[] = array(
                'id' => 'item_based_on',
                'type' => 'select2',
                'column_size' => 4,
                'column_title' => esc_html__( 'Based On', 'shipped-table-rate-shipping' ),
                /* translators: 1: module cost text */
                'tooltip' => sprintf( esc_html__( 'Controls %s based on item subtotals', 'shipped-table-rate-shipping' ), $module_text ),
                'default' => 'incl_tax',
                'options' => array(
                    'incl_tax' => esc_html__( 'Item subtotal including tax', 'shipped-table-rate-shipping' ),
                    'excl_tax' => esc_html__( 'Item subtotal excluding tax', 'shipped-table-rate-shipping' ),
                    'incl_tax_after' => esc_html__( 'Item subtotal including tax (after discounts)', 'shipped-table-rate-shipping' ),
                    'excl_tax_after' => esc_html__( 'Item subtotal excluding tax (after discounts)', 'shipped-table-rate-shipping' ),
                ),
                'width' => '100%',
                'fold' => array(
                    'target' => 'cost_type',
                    'attribute' => 'value',
                    'value' => $this->get_item_based_on_required_ids( $args ),
                    'oparator' => 'eq',
                    'clear' => true,
                    'empty' => 'incl_tax',
                ),
            );

            return $in_fields;
        }

        public static function get_extra_per_types( $args ) {

            $list_key = $args[ 'module' ] . '_per';

            if ( isset( self::$extr_per_types[ $list_key ] ) ) {

                return self::$extr_per_types[ $list_key ];
            }

            $extra_per_types = array(
                'quantity_unit' => esc_html__( 'By quantity unit', 'shipped-table-rate-shipping' ),
                'line_item' => esc_html__( 'By line item', 'shipped-table-rate-shipping' ),
                'product' => esc_html__( 'By product', 'shipped-table-rate-shipping' ),
                'product_category' => esc_html__( 'By product category', 'shipped-table-rate-shipping' ),
                'shipping_class' => esc_html__( 'By shipping class', 'shipped-table-rate-shipping' ),
                'order' => esc_html__( 'By Order', 'shipped-table-rate-shipping' ),
            );

            self::$extr_per_types[ $list_key ] = apply_filters( 'wtars_shipped_admin/get-package-grouping-types', $extra_per_types, $args );


            return self::$extr_per_types[ $list_key ];
        }

        private function get_based_on_required_ids( $args ) {

            return apply_filters( 'wtars_shipped_admin/get-based-on-required-ids', array(), $args );
        }

        private function get_item_based_on_required_ids( $args ) {

            return apply_filters( 'wtars_shipped_admin/get-item-based-on-required-ids', array(), $args );
        }

        private function get_round_on_required_ids( $args ) {

            return apply_filters( 'wtars_shipped_admin/get-round-required-ids', array(), $args );
        }

    }

    new WTARS_Shipped_Premium_Admin_Cost_Types();
}
