<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}


if ( !class_exists( 'WTARS_Shipped_Admin_Logic_Types_Product_Filters' ) ) {

    class WTARS_Shipped_Admin_Logic_Types_Product_Filters {

        public function __construct() {
            add_filter( 'wtars_shipped_admin/get-cost-type-fields', array( $this, 'get_fields' ), 10, 2 );

            add_filter( 'reon/get-simple-repeater-field-shipped-product_filters-templates', array( $this, 'get_product_templates' ), 10, 2 );
            add_filter( 'roen/get-simple-repeater-template-shipped-product_filters-product_filter-fields', array( $this, 'get_product_template_fields' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/process-cost-options', array( $this, 'process_options' ), 70, 3 );
        }

        public function get_fields( $in_fields, $args ) {


            $fields = array();

            $fields[] = array(
                'id' => 'any_id',
                'type' => 'paneltitle',
                'full_width' => true,
                'center_head' => true,
                'title' => esc_html__( 'Products', 'shipped-table-rate-shipping' ),
                'desc' => esc_html__( 'List of product to include based on rules, empty list will include all products in the package', 'shipped-table-rate-shipping' ),
                'field_css_class' => array( 'shipped_logic_title' ),
                'last' => true,
            );

            $fields[] = array(
                'id' => 'products_args',
                'filter_id' => 'shipped-product_filters',
                'type' => 'simple-repeater',
                'new_field_args' => $args,
                'white_repeater' => false,
                'repeater_size' => 'smaller',
                'buttons_sep' => false,
                'buttons_box_width' => '65px',
                'width' => '100%',
                'css_class' => array( 'shipped_conditions' ),
                'sortable' => array(
                    'enabled' => true,
                ),
                'template_adder' => array(
                    'position' => 'right',
                    'show_list' => false,
                    'button_text' => esc_html__( 'Add Product', 'shipped-table-rate-shipping' ),
                ),
            );

            $needs_fold = true;

            if ( isset( $args[ 'sub_module' ] ) && 'extra-cost' == $args[ 'sub_module' ] ) {
                $needs_fold = false;
            }

            $fold_ids = array();

            if ( true == $needs_fold ) {
                $fold_ids = $this->get_required_ids( $args );
            }

            foreach ( $fields as $field ) {

                if ( true == $needs_fold ) {
                    $field[ 'fold' ] = array(
                        'target' => $args[ 'fold_id' ],
                        'attribute' => 'value',
                        'value' => $fold_ids,
                        'oparator' => 'eq',
                        'clear' => false,
                    );
                }

                $in_fields[] = $field;
            }
            return $in_fields;
        }

        public function get_product_templates( $in_templates, $repeater_args ) {

            $in_templates[] = array(
                'id' => 'product_filter',
            );

            return $in_templates;
        }

        public function get_product_template_fields( $in_fields, $repeater_args ) {

            $args = $repeater_args[ 'field_args' ];

            $list = array();

            $groups = WTARS_Shipped_Admin_Product_Filter_Types::get_groups( $args );

            foreach ( $groups as $key => $group_label ) {
                $list[ $key ][ 'label' ] = $group_label;
                $list[ $key ][ 'options' ] = WTARS_Shipped_Admin_Product_Filter_Types::get_product_filters( $key, $args );
            }


            $in_fields[] = array(
                'id' => 'filter_type',
                'type' => 'select2',
                'default' => '',
                'options' => $list,
                'width' => '98%',
                'box_width' => '31%',
                'dyn_switcher_id' => 'filter_type',
            );


            $filters = array();
            foreach ( $list as $grp ) {
                if ( count( $grp[ 'options' ] ) > 0 ) {
                    $filters = array_merge( $filters, array_keys( $grp[ 'options' ] ) );
                }
            }



            foreach ( $filters as $filter ) {

                $in_fields[] = array(
                    'id' => 'filter_type_' . $filter,
                    'type' => 'group-field',
                    'dyn_switcher_target' => 'filter_type',
                    'dyn_switcher_target_value' => $filter,
                    'fluid-group' => true,
                    'width' => '69%',
                    'css_class' => array( 'rn-last' ),
                    'last' => true,
                    'fields' => WTARS_Shipped_Admin_Product_Filter_Types::get_product_filter_fields( $filter, $args ),
                );
            }

            return $in_fields;
        }

        public function process_options( $cost, $raw_cost, $args ) {

            $needs_fold = true;

            if ( isset( $args[ 'sub_module' ] ) && 'extra-cost' == $args[ 'sub_module' ] ) {
                $needs_fold = false;
            }

            $a_type = 'cost_type';

            if ( (false == $needs_fold || in_array( $raw_cost[ $a_type ], $this->get_required_ids( $args ) )) && isset( $raw_cost[ 'products_args' ] ) ) {
                $cost[ 'products_args' ] = $raw_cost[ 'products_args' ];
            }

            return $cost;
        }

        private function get_required_ids( $args ) {

            return apply_filters( 'wtars_shipped_admin/' . $args[ 'module' ] . '/get-products-required-ids', apply_filters( 'wtars_shipped_admin/get-products-required-ids', array(), $args ), $args );
        }

    }

    new WTARS_Shipped_Admin_Logic_Types_Product_Filters();
}