<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Product_Filter_Type_Dimensions' ) ) {

    class WTARS_Shipped_Admin_Product_Filter_Type_Dimensions {

        public function __construct() {
            add_filter( 'wtars_shipped_admin/get-product-filter-groups', array( $this, 'get_groups' ), 50, 2 );
            add_filter( 'wtars_shipped_admin/get-item_dimensions-group-product-filters', array( $this, 'get_filters' ), 10, 2 );
            
            add_filter( 'wtars_shipped_admin/get-item_length-product-filter-fields', array( $this, 'get_dimension_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_width-product-filter-fields', array( $this, 'get_dimension_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_height-product-filter-fields', array( $this, 'get_dimension_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_surface_area-product-filter-fields', array( $this, 'get_dimension_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_volume-product-filter-fields', array( $this, 'get_dimension_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'item_dimensions' ] = esc_html__( 'Product Dimensions', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_filters( $in_list, $args ) {

            $dim_unit = get_option( 'woocommerce_dimension_unit' );

            /* translators: 1: length unit */
            $in_list[ 'item_length' ] = sprintf( esc_html__( 'Product Length (%s)', 'shipped-table-rate-shipping' ), $dim_unit );
            /* translators: 1: width unit */
            $in_list[ 'item_width' ] = sprintf( esc_html__( 'Product Width (%s)', 'shipped-table-rate-shipping' ), $dim_unit );
            /* translators: 1: height unit */
            $in_list[ 'item_height' ] = sprintf( esc_html__( 'Product Height (%s)', 'shipped-table-rate-shipping' ), $dim_unit );
            /* translators: 1: surface area unit */
            $in_list[ 'item_surface_area' ] = sprintf( esc_html__( 'Product Surface Area (square %s)', 'shipped-table-rate-shipping' ), $dim_unit );
            /* translators: 1: volume unit */
            $in_list[ 'item_volume' ] = sprintf( esc_html__( 'Product Volume (cubic %s)', 'shipped-table-rate-shipping' ), $dim_unit );

            return $in_list;
        }
        
        public static function get_dimension_fields( $in_fields, $args ) {
            
            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '--',
                'options' => array(
                    '--' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '35%',
                'fold_id' => 'item_dimension_filter',
            );

            $in_fields[] = array(
                'id' => 'dimension',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '100%',
                'box_width' => '46%',
                'fold' => array(
                    'target' => 'item_dimension_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'neq',
                    'clear' => false,
                )
            );
            
            $in_fields[] = array(
                'id' => 'from_dimension',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '98%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_dimension_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                )
            );
            
            $in_fields[] = array(
                'id' => 'to_dimension',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '100%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_dimension_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                )
                
            );

            return $in_fields;
            
        }
        
        

    }

    new WTARS_Shipped_Admin_Product_Filter_Type_Dimensions();
}