<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Product_Filter_Type_Prices' ) ) {

    class WTARS_Shipped_Admin_Product_Filter_Type_Prices {

        public function __construct() {
            add_filter( 'wtars_shipped_admin/get-product-filter-groups', array( $this, 'get_groups' ), 20, 2 );
            add_filter( 'wtars_shipped_admin/get-item_prices-group-product-filters', array( $this, 'get_filters' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-item_price-product-filter-fields', array( $this, 'get_prices_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_price_ex_tax-product-filter-fields', array( $this, 'get_prices_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_d_price-product-filter-fields', array( $this, 'get_prices_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_d_price_ex_tax-product-filter-fields', array( $this, 'get_prices_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'item_prices' ] = esc_html__( 'Product Prices', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_filters( $in_list, $args ) {

            $in_list[ 'item_price' ] = esc_html__( 'Product Price', 'shipped-table-rate-shipping' );
            $in_list[ 'item_price_ex_tax' ] = esc_html__( 'Product Price (excl. tax)', 'shipped-table-rate-shipping' );
            $in_list[ 'item_d_price' ] = esc_html__( 'Discounted Price', 'shipped-table-rate-shipping' );
            $in_list[ 'item_d_price_ex_tax' ] = esc_html__( 'Discounted Price (excl. tax)', 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public static function get_prices_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '--',
                'options' => array(
                    '--' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '35%',
                'fold_id' => 'item_price_filter',
            );

            $in_fields[] = array(
                'id' => 'price',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.01',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '100%',
                'box_width' => '46%',
                'fold' => array(
                    'target' => 'item_price_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );
            
            
            $in_fields[] = array(
                'id' => 'from_price',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '98%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_price_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'to_price',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.01',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'box_width' => '55%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '100%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_price_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Product_Filter_Type_Prices();
}