<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Product_Filter_Type_Author' ) ) {

    class WTARS_Shipped_Admin_Product_Filter_Type_Author {

        public function __construct() {
            add_filter( 'wtars_shipped_admin/get-product-filter-groups', array( $this, 'get_groups' ), 70, 2 );
            add_filter( 'wtars_shipped_admin/get-item_users-group-product-filters', array( $this, 'get_filters' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-item_user-product-filter-fields', array( $this, 'get_user_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_user_roles-product-filter-fields', array( $this, 'get_user_roles_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_user_caps-product-filter-fields', array( $this, 'get_user_caps_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_user_metas-product-filter-fields', array( $this, 'get_user_metas_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'item_users' ] = esc_html__( 'Product Author (Multi Vendor)', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_filters( $in_list, $args ) {

            $in_list[ 'item_user' ] = esc_html__( 'Product Authors', 'shipped-table-rate-shipping' );
            $in_list[ 'item_user_roles' ] = esc_html__( "Product Author's Roles", 'shipped-table-rate-shipping' );
            $in_list[ 'item_user_caps' ] = esc_html__( "Product Author's Capabilities", 'shipped-table-rate-shipping' );
            $in_list[ 'item_user_metas' ] = esc_html__( "Product Author's Meta Fields", 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public static function get_user_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'user_id',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search users...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'users',
                    'ajax' => true,
                    'value_col' => 'id',
                    'show_value' => true,
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_user_roles_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'user_roles',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search user roles...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'roles',
                    'ajax' => true,
                ),
                'width' => '100%',
                'box_width' => '56%',
            );
            return $in_fields;
        }

        public static function get_user_caps_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'user_caps',
                'type' => 'select2',
                'multiple' => true,
                'allow_clear' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search capabilities...', 'shipped-table-rate-shipping' ),
                'data' => array(
                    'source' => 'wp_caps',
                    'ajax' => true,
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_user_metas_fields( $in_fields, $args ) {
            
            $in_fields[] = array(
                'id' => 'meta_key',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Meta field key', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '30%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'empty',
                'options' => array(
                    'empty' => esc_html__( 'Empty', 'shipped-table-rate-shipping' ),
                    'contains' => esc_html__( 'Contains', 'shipped-table-rate-shipping' ),
                    'not_contains' => esc_html__( 'Not contains', 'shipped-table-rate-shipping' ),
                    'begins' => esc_html__( 'Begins with', 'shipped-table-rate-shipping' ),
                    'ends' => esc_html__( 'Ends with', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                    'checked' => esc_html__( 'Checked', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'user_meta_field_compare',
                'width' => '98%',
                'box_width' => '34%',
            );

            $in_fields[] = array(
                'id' => 'meta_value',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Value', 'shipped-table-rate-shipping' ),
                'fold' => array(
                    'target' => 'user_meta_field_compare',
                    'attribute' => 'value',
                    'value' => array( 'contains', 'not_contains', 'begins', 'ends', '>=', '>', '<=', '<', '==', '!=' ),
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '17%',
            );

            $in_fields[] = array(
                'id' => 'yes_no',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'no' => esc_html__( 'No', 'shipped-table-rate-shipping' ),
                    'yes' => esc_html__( 'Yes', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'user_meta_field_compare',
                    'attribute' => 'value',
                    'value' => array( 'empty', 'checked' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '17%',
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Product_Filter_Type_Author();
}