<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Product_Filter_Type_Products' ) ) {

    class WTARS_Shipped_Admin_Product_Filter_Type_Products {

        public function __construct() {
            add_filter( 'wtars_shipped_admin/get-product-filter-groups', array( $this, 'get_groups' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-products-group-product-filters', array( $this, 'get_filters' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-spec_products-product-filter-fields', array( $this, 'get_specific_products_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-product_var-product-filter-fields', array( $this, 'get_product_variations_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-product_cats-product-filter-fields', array( $this, 'get_product_categories_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-product_tags-product-filter-fields', array( $this, 'get_product_tags_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-product_attrs-product-filter-fields', array( $this, 'get_product_attributes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-product_var_attrs-product-filter-fields', array( $this, 'get_product_attributes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-product_qty-product-filter-fields', array( $this, 'get_product_quantity_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'products' ] = esc_html__( 'Products', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_filters( $in_list, $args ) {

            $in_list[ 'spec_products' ] = esc_html__( 'Specific Products', 'shipped-table-rate-shipping' );
            $in_list[ 'product_var' ] = esc_html__( 'Product Variations', 'shipped-table-rate-shipping' );
            $in_list[ 'product_cats' ] = esc_html__( 'Product Categories', 'shipped-table-rate-shipping' );
            $in_list[ 'product_tags' ] = esc_html__( 'Product Tags', 'shipped-table-rate-shipping' );
            $in_list[ 'product_attrs' ] = esc_html__( 'Product Attributes', 'shipped-table-rate-shipping' );
            $in_list[ 'product_var_attrs' ] = esc_html__( 'Variation Attributes', 'shipped-table-rate-shipping' );
            $in_list[ 'product_qty' ] = esc_html__( 'Product Quantity In Package', 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public static function get_specific_products_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'product_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search products...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:products',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_variations_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'variation_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 2,
                'placeholder' => esc_html__( 'Search variations...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:product_variations',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_categories_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'category_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search categories...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_cat',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_tags_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'tag_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search tags...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'categories:product_tag',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_attributes_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list' => esc_html__( 'All in the list', 'shipped-table-rate-shipping' ),
                    'in_list_only' => esc_html__( 'Only in the list', 'shipped-table-rate-shipping' ),
                    'in_all_list_only' => esc_html__( 'Only all in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'attribute_slugs',
                'type' => 'select2',
                'multiple' => true,
                'minimum_input_length' => 1,
                'placeholder' => esc_html__( 'Search attributes...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:attributes',
                    'ajax' => true,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_product_quantity_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '--',
                'options' => array(
                    '--' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '35%',
                'fold_id' => 'item_quantity_filter',
            );

            $in_fields[] = array(
                'id' => 'quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'width' => '100%',
                'box_width' => '46%',
                'fold' => array(
                    'target' =>
                    'item_quantity_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'from_quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'width' => '98%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_quantity_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'to_quantity',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '2',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '1',
                    'step' => '1',
                ),
                'width' => '100%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_quantity_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Product_Filter_Type_Products();
}
        