<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Product_Filter_Type_Properties' ) ) {

    class WTARS_Shipped_Admin_Product_Filter_Type_Properties {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-product-filter-groups', array( $this, 'get_groups' ), 60, 2 );
            add_filter( 'wtars_shipped_admin/get-item_properties-group-product-filters', array( $this, 'get_filters' ), 10, 2 );

            add_filter( 'wtars_shipped_admin/get-item_is_downloadable-product-filter-fields', array( $this, 'get_is_yes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_is_featured-product-filter-fields', array( $this, 'get_is_yes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_sales_total-product-filter-fields', array( $this, 'get_total_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_is_on_sale-product-filter-fields', array( $this, 'get_is_yes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_stock_status-product-filter-fields', array( $this, 'get_stock_status_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_stock_quantity-product-filter-fields', array( $this, 'get_total_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_shipping_class-product-filter-fields', array( $this, 'get_shipping_class_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_is_taxable-product-filter-fields', array( $this, 'get_is_yes_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_tax_class-product-filter-fields', array( $this, 'get_tax_class_fields' ), 10, 2 );
            add_filter( 'wtars_shipped_admin/get-item_meta-product-filter-fields', array( $this, 'get_meta_fields' ), 10, 2 );
        }

        public function get_groups( $in_groups, $args ) {

            $in_groups[ 'item_properties' ] = esc_html__( 'Product Properties', 'shipped-table-rate-shipping' );

            return $in_groups;
        }

        public function get_filters( $in_list, $args ) {

            $in_list[ 'item_is_downloadable' ] = esc_html__( 'Product Is Downloadable', 'shipped-table-rate-shipping' );
            $in_list[ 'item_is_featured' ] = esc_html__( 'Product Is Featured', 'shipped-table-rate-shipping' );
            $in_list[ 'item_sales_total' ] = esc_html__( 'Product Total Number Of Sales', 'shipped-table-rate-shipping' );
            $in_list[ 'item_is_on_sale' ] = esc_html__( 'Product Is On Sale', 'shipped-table-rate-shipping' );
            $in_list[ 'item_stock_status' ] = esc_html__( 'Product Stock Status', 'shipped-table-rate-shipping' );
            $in_list[ 'item_stock_quantity' ] = esc_html__( 'Product Stock Quantity', 'shipped-table-rate-shipping' );
            $in_list[ 'item_shipping_class' ] = esc_html__( 'Product Shipping Class', 'shipped-table-rate-shipping' );
            $in_list[ 'item_is_taxable' ] = esc_html__( 'Product Is Taxable', 'shipped-table-rate-shipping' );
            $in_list[ 'item_tax_class' ] = esc_html__( 'Product Tax Class', 'shipped-table-rate-shipping' );
            $in_list[ 'item_meta' ] = esc_html__( 'Product Meta Field', 'shipped-table-rate-shipping' );

            return $in_list;
        }

        public static function get_is_yes_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'is_yes',
                'type' => 'select2',
                'default' => 'yes',
                'options' => array(
                    'no' => esc_html__( 'No', 'shipped-table-rate-shipping' ),
                    'yes' => esc_html__( 'Yes', 'shipped-table-rate-shipping' ),
                ),
                'width' => '100%',
                'box_width' => '81%',
            );


            return $in_fields;
        }

        public static function get_total_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '--',
                'options' => array(
                    '--' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '35%',
                'fold_id' => 'item_totals_filter',
            );

            $in_fields[] = array(
                'id' => 'totals',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'width' => '100%',
                'box_width' => '46%',
                'fold' => array(
                    'target' => 'item_totals_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'from_totals',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'width' => '98%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_totals_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'to_totals',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '1',
                'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '1',
                ),
                'width' => '100%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_totals_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public static function get_stock_status_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'stock_statuses',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Stock status...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'options' => wc_get_product_stock_status_options(),
                'width' => '100%',
                'box_width' => '56%',
            );


            return $in_fields;
        }

        public static function get_shipping_class_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'shipping_class_slugs',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Select shipping classes...', 'shipped-table-rate-shipping' ),
                'allow_clear' => true,
                'minimum_results_forsearch' => 10,
                'data' => array(
                    'source' => 'wc:shipping_classes',
                    'ajax' => false,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_tax_class_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'in_list',
                'options' => array(
                    'in_list' => esc_html__( 'Any in the list', 'shipped-table-rate-shipping' ),
                    'none' => esc_html__( 'None in the list', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '25%',
            );

            $in_fields[] = array(
                'id' => 'tax_class_slugs',
                'type' => 'select2',
                'multiple' => true,
                'placeholder' => esc_html__( 'Select tax classes...', 'shipped-table-rate-shipping' ),
                'options' => array(
                    '--0' => esc_html__( 'Standard Rate', 'shipped-table-rate-shipping' )
                ),
                'data' => array(
                    'source' => 'wc:tax_classes',
                    'ajax' => false,
                    'value_col' => 'slug',
                ),
                'width' => '100%',
                'box_width' => '56%',
            );

            return $in_fields;
        }

        public static function get_meta_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'meta_key',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Meta field key', 'shipped-table-rate-shipping' ),
                'width' => '98%',
                'box_width' => '33%',
            );

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => 'empty',
                'options' => array(
                    'empty' => esc_html__( 'Empty', 'shipped-table-rate-shipping' ),
                    'contains' => esc_html__( 'Contains', 'shipped-table-rate-shipping' ),
                    'not_contains' => esc_html__( 'Not contains', 'shipped-table-rate-shipping' ),
                    'begins' => esc_html__( 'Begins with', 'shipped-table-rate-shipping' ),
                    'ends' => esc_html__( 'Ends with', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                    'checked' => esc_html__( 'Checked', 'shipped-table-rate-shipping' ),
                ),
                'fold_id' => 'meta_field_compare',
                'width' => '98%',
                'box_width' => '31%',
            );

            $in_fields[] = array(
                'id' => 'meta_value',
                'type' => 'textbox',
                'input_type' => 'text',
                'default' => '',
                'placeholder' => esc_html__( 'Value', 'shipped-table-rate-shipping' ),
                'fold' => array(
                    'target' => 'meta_field_compare',
                    'attribute' => 'value',
                    'value' => array( 'contains', 'not_contains', 'begins', 'ends', '>=', '>', '<=', '<', '==', '!=' ),
                    'oparator' => 'eq',
                    'clear' => true,
                ),
                'width' => '100%',
                'box_width' => '17%',
            );

            $in_fields[] = array(
                'id' => 'yes_no',
                'type' => 'select2',
                'default' => '>=',
                'options' => array(
                    'no' => esc_html__( 'No', 'shipped-table-rate-shipping' ),
                    'yes' => esc_html__( 'Yes', 'shipped-table-rate-shipping' ),
                ),
                'fold' => array(
                    'target' => 'meta_field_compare',
                    'attribute' => 'value',
                    'value' => array( 'empty', 'checked' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
                'width' => '100%',
                'box_width' => '17%',
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Product_Filter_Type_Properties();
}
