<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Product_Filter_Type_Weights' ) ) {

    class WTARS_Shipped_Admin_Product_Filter_Type_Weights {

        private $prefix = 'item_weight-';

        public function __construct() {

            add_filter( 'wtars_shipped_admin/get-product-filter-groups', array( $this, 'get_groups' ), 40, 2 );
            add_filter( 'wtars_shipped_admin/get-item_weights-group-product-filters', array( $this, 'get_filters' ), 10, 2 );

            foreach ( $this->get_options() as $option ) {
                add_filter( 'wtars_shipped_admin/get-' . $this->prefix . $option[ 'option_id' ] . '-product-filter-fields', array( $this, 'get_weight_fields' ), 10, 2 );
            }
        }

        public function get_groups( $in_groups, $args ) {

            $unit = get_option( 'woocommerce_weight_unit' );

            /* translators: 1: weights unit */
            $in_groups[ 'item_weights' ] =sprintf(  esc_html__( 'Product Weights (%s)', 'shipped-table-rate-shipping' ), $unit );

            return $in_groups;
        }

        public function get_filters( $in_list, $args ) {
            
            $unit = get_option( 'woocommerce_weight_unit' );

            foreach ( $this->get_options() as $option ) {
                /* translators: 1: weights calculator name 2: weights unit */
                $in_list[ $this->prefix . $option[ 'option_id' ] ] = sprintf( esc_html__( 'Product Weight - %1$s (%2$s)', 'shipped-table-rate-shipping' ), $this->get_title( $option ), $unit );
            }

            return $in_list;
        }

        public function get_weight_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'compare',
                'type' => 'select2',
                'default' => '--',
                'options' => array(
                    '--' => esc_html__( 'Between', 'shipped-table-rate-shipping' ),
                    '>=' => esc_html__( 'More than or equal to', 'shipped-table-rate-shipping' ),
                    '>' => esc_html__( 'More than', 'shipped-table-rate-shipping' ),
                    '<=' => esc_html__( 'Less than or equal to', 'shipped-table-rate-shipping' ),
                    '<' => esc_html__( 'Less than', 'shipped-table-rate-shipping' ),
                    '==' => esc_html__( 'Equal to', 'shipped-table-rate-shipping' ),
                    '!=' => esc_html__( 'Not equal to', 'shipped-table-rate-shipping' ),
                ),
                'width' => '98%',
                'box_width' => '35%',
                'fold_id' => 'item_weight_filter',
            );

            $in_fields[] = array(
                'id' => 'weight',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.5',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '100%',
                'box_width' => '46%',
                'fold' => array(
                    'target' => 'item_weight_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'neq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'from_weight',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '98%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_weight_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            $in_fields[] = array(
                'id' => 'to_weight',
                'type' => 'textbox',
                'input_type' => 'number',
                'default' => '0.5',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'width' => '100%',
                'box_width' => '23%',
                'fold' => array(
                    'target' => 'item_weight_filter',
                    'attribute' => 'value',
                    'value' => array( '--' ),
                    'oparator' => 'eq',
                    'clear' => false,
                ),
            );

            return $in_fields;
        }

        public function get_options() {

            global $wtars_shipped;

            $options = array();

            if ( isset( $wtars_shipped[ 'weight_calcs' ] ) ) {
                $options = $wtars_shipped[ 'weight_calcs' ];
            } else {
                $options = self::get_default();
            }

            return $options;
        }

        private function get_title( $option ) {
            if ( !empty( $option[ 'admin_note' ] ) ) {
                return $option[ 'admin_note' ];
            }

            return $this->get_default_title( $option[ 'option_id' ] );
        }

        private function get_default_title( $option_id ) {

            foreach ( $this->get_default() as $option ) {

                if ( $option_id == $option[ 'option_id' ] ) {
                    return $option[ 'admin_note' ];
                }
            }
            return esc_html__( 'Volumetric Weight', 'shipped-table-rate-shipping' );
        }

        private static function get_default() {

            return array(
                array(
                    'admin_note' => esc_html__( 'Weight', 'shipped-table-rate-shipping' ),
                    'option_id' => '2234343',
                ),
                array(
                    'admin_note' => esc_html__( 'Volumetric Weight', 'shipped-table-rate-shipping' ),
                    'option_id' => '2234344',
                ),
            );
        }

    }

    new WTARS_Shipped_Admin_Product_Filter_Type_Weights();
}

