<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Cart_Fees_Panel_Extra_Costs' ) ) {

    class WTARS_Shipped_Admin_Cart_Fees_Panel_Extra_Costs {

        public function __construct() {
            add_filter( 'wtars_shipped_admin/cart-fees/get-panels', array( $this, 'get_panel' ), 30, 2 );
            add_filter( 'wtars_shipped_admin/cart-fees/get-panel-extra-costs-fields', array( $this, 'get_panel_fields' ), 10, 2 );

            add_filter( 'reon/get-repeater-field-extra_costs-templates', array( $this, 'get_option_templates' ), 10, 2 );
            add_filter( 'roen/get-repeater-template-extra_costs-extra_cost-fields', array( $this, 'get_fee_fields' ), 10, 2 );
        }

        public function get_panel( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'any_id',
                'type' => 'panel',
                'full_width' => true,
                'center_head' => true,
                'white_panel' => false,
                'panel_size' => 'smaller',
                'width' => '100%',
                'merge_fields' => false,
                'css_class' => 'shipped_panel_calcs',
                'field_css_class' => array( 'shipped_panel_calcs_field', 'shipped_mid_panel_calcs' ),
                'last' => true,
                'fields' => apply_filters( 'wtars_shipped_admin/cart-fees/get-panel-extra-costs-fields', array(), $args ),
            );

            return $in_fields;
        }

        public function get_panel_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'any_id',
                'type' => 'panel',
                'full_width' => true,
                'center_head' => true,
                'white_panel' => true,
                'panel_size' => 'smaller',
                'width' => '100%',
                'last' => true,
                'css_class' => 'shipped_calcs_title',
                'fields' => array(
                    array(
                        'id' => 'any_id',
                        'type' => 'paneltitle',
                        'full_width' => true,
                        'center_head' => true,
                        'title' => esc_html__( 'Grouped Shipping Fees', 'shipped-table-rate-shipping' ),
                        'desc' => esc_html__( 'List of grouped shipping fees to apply, empty list will apply zero fee', 'shipped-table-rate-shipping' ),
                    ),
                ),
            );

            $in_fields[] = array(
                'id' => 'extra_costs',
                'field_args' => $args,
                'type' => 'repeater',
                'white_repeater' => true,
                'repeater_size' => 'smaller',
                'collapsible' => false,
                'accordions' => false,
                'buttons_sep' => false,
                'delete_button' => true,
                'clone_button' => false,
                'css_class' => 'shipped_calcs',
                'field_css_class' => array( 'shipped_calcs_field' ),
                'width' => '100%',
                'auto_expand' => array(
                    'all_section' => true,
                    'new_section' => true,
                    'default_section' => true,
                    'cloned_section' => true,
                ),
                'sortable' => array(
                    'enabled' => true,
                ),
                'template_adder' => array(
                    'position' => 'right',
                    'button_text' => esc_html__( 'Add Fee', 'shipped-table-rate-shipping' ),
                ),
            );

            return $in_fields;
        }

        public function get_option_templates( $in_templates, $repeater_args ) {

            $in_templates[] = array(
                'id' => 'extra_cost',
                'head' => array(
                    'title' => '',
                    'subtitle' => '',
                    'defaut_title' => esc_html__( 'Grouped Shipping Fee', 'shipped-table-rate-shipping' ),
                    'defaut_subtitle' => esc_html__( 'Group By', 'shipped-table-rate-shipping' ),
                    'title_field' => 'cost_type',
                    'subtitle_field' => 'group_by',
                )
            );

            return $in_templates;
        }

        public function get_fee_fields( $in_fields, $repeater_args ) {

            $section_args = $repeater_args[ 'field_args' ];

            $args = array(
                'instance_id' => $section_args[ 'instance_id' ],
                'module' => 'shipping-rates',
                'sub_module' => 'extra-cost',
                'fold_id' => 'cost_type',
                'format_cap_text' => esc_html__( 'Fee', 'shipped-table-rate-shipping' ),
                'format_text' => esc_html__( 'fee', 'shipped-table-rate-shipping' ),
            );

            $fee_types = WTARS_Shipped_Admin_Cost_Types::get_types( $args );

            $in_fields[] = array(
                'id' => 'id',
                'type' => 'autoid',
                'autoid' => 'shipped',
            );


            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 5,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'cost_type',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Fee Type', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Controls handling fee type', 'shipped-table-rate-shipping' ),
                        'default' => apply_filters( 'wtars_shipped_admin/get-cost-types-default', 'cart_fixed', $args ),
                        'options' => $fee_types,
                        'width' => '100%',
                        'attributes' => array(
                            'data-repeater-title' => 'extra_costs',
                        ),
                        'fold_id' => 'cost_type',
                    ),
                    array(
                        'id' => 'group_by',
                        'type' => 'select2',
                        'column_size' => 2,
                        'tooltip' => esc_html__( 'Controls how package items should be grouped and charged', 'shipped-table-rate-shipping' ),
                        'column_title' => esc_html__( 'Group Package Items', 'shipped-table-rate-shipping' ),
                        'default' => 'quantity_unit',
                        'options' => WTARS_Shipped_Premium_Admin_Cost_Types::get_extra_per_types( $args ),
                        'width' => '100%',
                        'attributes' => array(
                            'data-repeater-subtitle' => 'extra_costs',
                        ),
                    ),
                    array(
                        'id' => 'set_conditions',
                        'type' => 'select2',
                        'column_size' => 1,
                        'tooltip' => esc_html__( 'Determines whether no conditions should be validated before fee calculation', 'shipped-table-rate-shipping' ),
                        'column_title' => esc_html__( 'Validate Conditions', 'shipped-table-rate-shipping' ),
                        'default' => 'no',
                        'options' => array(
                            'no' => esc_html__( 'No', 'shipped-table-rate-shipping' ),
                            'yes' => esc_html__( 'Yes', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                        'fold_id' => 'set_conditions',
                    ),
                ),
            );

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 12,
                'merge_fields' => false,
                'fields' => $this->get_fee_box_fields( array(), $args ),
            );


            foreach ( WTARS_Shipped_Admin_Cost_Types::get_type_fields( $args ) as $type_field ) {
                $in_fields[] = $type_field;
            }

            $in_fields = WTARS_Shipped_Admin_Cost_Types::get_other_fields( $in_fields, $args );

            return $in_fields;
        }

        private function get_fee_box_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'cost',
                'type' => 'textbox',
                'input_type' => 'number',
                'tooltip' => esc_html__( 'Controls the fee to apply, based on fee type', 'shipped-table-rate-shipping' ),
                'column_size' => 2,
                'column_title' => esc_html__( 'Fee', 'shipped-table-rate-shipping' ),
                'default' => '0.00',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
            );

            $in_fields = WTARS_Shipped_Admin_Cost_Types::get_cost_box_fields( $in_fields, $args );

            $in_fields[] = array(
                'id' => 'taxable',
                'type' => 'select2',
                'column_size' => 4,
                'column_title' => esc_html__( 'Tax Class', 'shipped-table-rate-shipping' ),
                'tooltip' => esc_html__( 'Controls fee tax class', 'shipped-table-rate-shipping' ),
                'default' => '--0',
                'disabled_list_filter' => 'wtars_shipped_admin/get-disabled-list',
                'data' => 'shipped:tax_options',
                'width' => '100%',
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Cart_Fees_Panel_Extra_Costs();
}
  