<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Premium_Cart_Fees_Section' ) ) {

    ReonUtil::recursive_require( dirname( __FILE__ ), array( 'cart-fees-section.php' ) );

    class WTARS_Shipped_Admin_Premium_Cart_Fees_Section extends WTARS_Shipped_Admin_Section {

        protected function init() {

            add_filter( 'get-option-page-' . $this->get_option_name() . 'section-cart_fees-fields', array( $this, 'get_settings_fields' ), 20, 2 );
        }

        public function get_settings_fields( $in_fields, $section_id ) {

            $currency = get_woocommerce_currency_symbol( get_woocommerce_currency() );

            $in_fields[] = array(
                'id' => 'cart_fees_settings',
                'type' => 'panel',
                'last' => true,
                'white_panel' => false,
                'panel_size' => 'smaller',
                'width' => '100%',
                'field_css_class' => array( 'wtars_shipped_rules_apply_mode' ),
                'fields' => array(
                    array(
                        'id' => 'shipped_any_id',
                        'type' => 'columns-field',
                        'columns' => 8,
                        'merge_fields' => false,
                        'fields' => array(
                            array(
                                'id' => 'limit_type',
                                'type' => 'select2',
                                'column_size' => 2,
                                'column_title' => esc_html__( 'Handling Fees Limit', 'shipped-table-rate-shipping' ),
                                'tooltip' => esc_html__( 'Controls handling fees limits', 'shipped-table-rate-shipping' ),
                                'default' => 'no',
                                'options' => array(
                                    'no' => esc_html__( 'No limit', 'shipped-table-rate-shipping' ),
                                    'fixed_limit' => str_replace( '[0]', $currency, esc_html__( 'Fixed ([0])', 'shipped-table-rate-shipping' ) ),
                                    'per_limit' => esc_html__( 'Percentage  (%)', 'shipped-table-rate-shipping' ),
                                ),
                                'width' => '100%',
                                'fold_id' => 'limit_type',
                            ),
                            array(
                                'id' => 'limit',
                                'type' => 'textbox',
                                'input_type' => 'number',
                                'column_size' => 1,
                                'column_title' => esc_html__( 'Limit', 'shipped-table-rate-shipping' ),
                                'tooltip' => esc_html__( 'Controls handling fees limits', 'shipped-table-rate-shipping' ),
                                'default' => '',
                                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                                'width' => '100%',
                                'attributes' => array(
                                    'min' => '0',
                                    'step' => '0.01',
                                ),
                                'fold' => array(
                                    'target' => 'limit_type',
                                    'attribute' => 'value',
                                    'value' => 'no',
                                    'oparator' => 'neq',
                                    'clear' => true,
                                ),
                            ),
                            array(
                                'id' => 'based_on',
                                'type' => 'select2',
                                'column_size' => 2,
                                'column_title' => esc_html__( 'Limit Based On', 'shipped-table-rate-shipping' ),
                                'tooltip' => esc_html__( 'Controls percentage amount limits, based on cart or package totals', 'shipped-table-rate-shipping' ),
                                'default' => '2234343',
                                'data' => 'shipped:checkout_totals',
                                'width' => '100%',
                                'fold' => array(
                                    'target' => 'limit_type',
                                    'attribute' => 'value',
                                    'value' => 'per_limit',
                                    'oparator' => 'eq',
                                    'clear' => true,
                                    'empty' => '2234343',
                                ),
                            ),
                            array(
                                'id' => 'mode',
                                'type' => 'select2',
                                'column_size' => 3,
                                'column_title' => esc_html__( 'Apply Mode', 'shipped-table-rate-shipping' ),
                                'tooltip' => esc_html__( 'Controls handling fees apply mode', 'shipped-table-rate-shipping' ),
                                'default' => 'all',
                                'disabled_list_filter' => 'wtars_shipped_admin/get-disabled-list',
                                'data' => 'shipped:cart_fee_modes',
                                'width' => '100%',
                            ),
                        ),
                    ),
                ),
            );




            return $in_fields;
        }

    }

}