<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Admin_Checkout_Msgs_Panel_Parameters' ) ) {

    class WTARS_Shipped_Premium_Admin_Checkout_Msgs_Panel_Parameters {

        public function __construct() {

            add_filter( 'wtars_shipped_admin/checkout-messages/get-panel-parameters-fields', array( $this, 'get_panel_fields' ), 10, 2 );

            add_filter( 'reon/get-repeater-field-shipped-parameters-templates', array( $this, 'get_option_templates' ), 10, 2 );
            add_filter( 'roen/get-repeater-template-shipped-parameters-parameter-fields', array( $this, 'get_parameter_fields' ), 10, 2 );
        }

        public function get_panel_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'any_id',
                'type' => 'panel',
                'full_width' => true,
                'center_head' => true,
                'white_panel' => true,
                'panel_size' => 'smaller',
                'width' => '100%',
                'last' => true,
                'css_class' => 'shipped_calcs_title',
                'fields' => array(
                    array(
                        'id' => 'any_id',
                        'type' => 'paneltitle',
                        'full_width' => true,
                        'center_head' => true,
                        'title' => esc_html__( 'Message Parameters', 'shipped-table-rate-shipping' ),
                        'desc' => esc_html__( 'Specify what parameters needs to be included in the message', 'shipped-table-rate-shipping' ),
                    )
                ),
            );

            $in_fields[] = array(
                'id' => 'parameters',
                'field_args' => $args,
                'filter_id' => 'shipped-parameters',
                'type' => 'repeater',
                'white_repeater' => true,
                'repeater_size' => 'smaller',
                'collapsible' => false,
                'accordions' => false,
                'buttons_sep' => false,
                'delete_button' => true,
                'clone_button' => false,
                'css_class' => 'shipped_calcs',
                'field_css_class' => array( 'shipped_calcs_field' ),
                'width' => '100%',
                'auto_expand' => array(
                    'all_section' => true,
                    'new_section' => true,
                    'default_section' => true,
                    'cloned_section' => true,
                ),
                'sortable' => array(
                    'enabled' => true,
                ),
                'template_adder' => array(
                    'position' => 'right',
                    'button_text' => esc_html__( 'Add Parameter', 'shipped-table-rate-shipping' ),
                ),
            );

            return $in_fields;
        }

        public function get_option_templates( $in_templates, $repeater_args ) {

            $in_templates[] = array(
                'id' => 'parameter',
                'head' => array(
                    'title' => '',
                    'defaut_title' => esc_html__( 'Parameter', 'shipped-table-rate-shipping' ),
                    'title_field' => 'parameter_type',
                )
            );

            return $in_templates;
        }

        public function get_parameter_fields( $in_fields, $repeater_args ) {

            $section_args = $repeater_args[ 'field_args' ];

            $args = array(
                'instance_id' => $section_args[ 'instance_id' ],
                'module' => 'checkout-messages',
                'sub_module' => 'parameters',
                'fold_id' => 'cost_type',
            );

            $parameter_types = WTARS_Shipped_Admin_Parameter_Types::get_types( $args );

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 12,
                'merge_fields' => false,
                'fields' => $this->get_box_fields( array(), $parameter_types, $args ),
            );


            return apply_filters( 'wtars_shipped_admin/get-parameter-fields', $in_fields, $args );
        }

        private function get_box_fields( $in_fields, $parameter_types, $args ) {

            $in_fields[] = array(
                'id' => 'parameter_id',
                'type' => 'textbox',
                'tooltip' => esc_html__( 'Controls the parameter id in the message', 'shipped-table-rate-shipping' ),
                'column_size' => 3,
                'column_title' => esc_html__( 'Parameter ID', 'shipped-table-rate-shipping' ),
                'placeholder' => esc_html__( 'parameter-id', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'attributes' => array(
                    'class' => 'rn-ui-autoid',
                    'data-autoid_id' => 'shipped-params',
                    'data-autoid_prefix' => 'P',
                ),
            );

            $in_fields[] = array(
                'id' => 'parameter_type',
                'type' => 'select2',
                'column_size' => 4,
                'column_title' => esc_html__( 'Parameter Type', 'shipped-table-rate-shipping' ),
                'tooltip' => esc_html__( 'Controls the parameter type and value in the message', 'shipped-table-rate-shipping' ),
                'disabled_list_filter' => 'wtars_shipped_admin/get-disabled-grouped-list',
                'options' => $parameter_types,
                'attributes' => array(
                    'data-repeater-title' => 'parameters',
                ),
                'width' => '100%',
                'fold_id' => 'parameter_type',
            );

            return apply_filters( 'wtars_shipped_admin/get-parameter-box-fields', $in_fields, $args );
        }

    }

    new WTARS_Shipped_Premium_Admin_Checkout_Msgs_Panel_Parameters();
}
