<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Admin_Volumetric_Weight_Settings' ) ) {

    class WTARS_Shipped_Premium_Admin_Volumetric_Weight_Settings {

        public function __construct() {

            add_filter( 'roen/get-repeater-template-weight_calcs-calc_default-fields', array( $this, 'get_template_fields' ), 10, 2 );
            add_filter( 'roen/get-repeater-template-weight_calcs-calc_option-fields', array( $this, 'get_template_fields' ), 10, 2 );
        }

        public static function get_template_fields( $in_fields, $repeater_args ) {

            $in_fields[] = array(
                'id' => 'option_id',
                'type' => 'autoid',
                'autoid' => 'shipped',
            );

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 3,
                'full_width' => true,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'admin_note',
                        'type' => 'textbox',
                        'tooltip' => esc_html__( 'Adds a private note for reference purposes', 'shipped-table-rate-shipping' ),
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Admin Note', 'shipped-table-rate-shipping' ),
                        'default' => '',
                        'placeholder' => esc_html__( 'Type here...', 'shipped-table-rate-shipping' ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'formula',
                        'type' => 'select2',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Volumetric Weight Formula', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Determines how volumetric weights should be calculated', 'shipped-table-rate-shipping' ),
                        'default' => 'no',
                        'disabled_list_filter' => 'wtars_shipped_admin/get-disabled-list',
                        'options' => array(
                            'no' => esc_html__( 'No formula', 'shipped-table-rate-shipping' ),
                            'divide' => esc_html__( 'Weight = ( L x W x H ) / DIM Factor', 'shipped-table-rate-shipping' ),
                            'multiply' => esc_html__( 'Weight = ( L x W x H ) x DIM Factor', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                        'fold_id' => 'weight_formula',
                    ),
                    array(
                        'id' => 'dim_factor',
                        'type' => 'textbox',
                        'input_type' => 'number',
                        'tooltip' => esc_html__( 'Controls the dim factor value in the formula, dim factor can be obtain from your courier company', 'shipped-table-rate-shipping' ),
                        'column_size' => 1,
                        'column_title' => esc_html__( 'DIM Factor', 'shipped-table-rate-shipping' ),
                        'default' => '0',
                        'placeholder' => esc_html__( '0', 'shipped-table-rate-shipping' ),
                        'width' => '100%',
                        'attributes' => array(
                            'min' => '0',
                            'step' => '1',
                        ),
                        'fold' => array(
                            'target' => 'weight_formula',
                            'attribute' => 'value',
                            'value' => 'no',
                            'oparator' => 'neq',
                            'clear' => false,
                        ),
                    ),
                ),
            );

            $in_fields[] = array(
                'id' => 'any_ids',
                'type' => 'columns-field',
                'columns' => 5,
                'full_width' => true,
                'merge_fields' => false,
                'fields' => array(
                    array(
                        'id' => 'round_measurements',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Round Measurements', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Determines how measurements should be rounded', 'shipped-table-rate-shipping' ),
                        'default' => 'round_whole',
                        'options' => array(
                            'no' => esc_html__( 'Do not round measurements', 'shipped-table-rate-shipping' ),
                            'round_up_whole' => esc_html__( 'Round measurements up to whole unit', 'shipped-table-rate-shipping' ),
                            'round_down_whole' => esc_html__( 'Round measurements down to whole unit', 'shipped-table-rate-shipping' ),
                            'round_whole' => esc_html__( 'Round measurements to the nearest whole unit', 'shipped-table-rate-shipping' ),
                            'round_up_half' => esc_html__( 'Round measurements up to half unit', 'shipped-table-rate-shipping' ),
                            'round_down_half' => esc_html__( 'Round measurements down to half unit', 'shipped-table-rate-shipping' ),
                            'round_half' => esc_html__( 'Round measurements to the nearest half unit', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                        'fold' => array(
                            'target' => 'weight_formula',
                            'attribute' => 'value',
                            'value' => 'no',
                            'oparator' => 'neq',
                            'clear' => false,
                        ),
                    ),
                    array(
                        'id' => 'round_weight',
                        'type' => 'select2',
                        'column_size' => 2,
                        'column_title' => esc_html__( 'Round Weight', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( 'Determines how weights or volumetric weight should be rounded', 'shipped-table-rate-shipping' ),
                        'default' => 'round_half',
                        'options' => array(
                            'no' => esc_html__( 'Do not round weight', 'shipped-table-rate-shipping' ),
                            'round_up_whole' => esc_html__( 'Round weight up to whole unit', 'shipped-table-rate-shipping' ),
                            'round_down_whole' => esc_html__( 'Round weight down to whole unit', 'shipped-table-rate-shipping' ),
                            'round_whole' => esc_html__( 'Round weight to the nearest whole unit', 'shipped-table-rate-shipping' ),
                            'round_up_half' => esc_html__( 'Round weight up to half unit', 'shipped-table-rate-shipping' ),
                            'round_down_half' => esc_html__( 'Round weight down to half unit', 'shipped-table-rate-shipping' ),
                            'round_half' => esc_html__( 'Round weight to the nearest half unit', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                    ),
                    array(
                        'id' => 'compare_weights',
                        'type' => 'select2',
                        'column_size' => 1,
                        'column_title' => esc_html__( 'Compare Weights', 'shipped-table-rate-shipping' ),
                        'tooltip' => esc_html__( '"No" will always choose the calculated weight', 'shipped-table-rate-shipping' ),
                        'default' => 'yes',
                        'options' => array(
                            'yes' => esc_html__( 'Yes', 'shipped-table-rate-shipping' ),
                            'no' => esc_html__( 'No', 'shipped-table-rate-shipping' ),
                        ),
                        'width' => '100%',
                        'fold' => array(
                            'target' => 'weight_formula',
                            'attribute' => 'value',
                            'value' => 'no',
                            'oparator' => 'neq',
                            'clear' => false,
                        ),
                    ),
                ),
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Premium_Admin_Volumetric_Weight_Settings();
}