<?php

if ( !class_exists( 'Reon' ) ) {
    return;
}

if ( !class_exists( 'WTARS_Shipped_Admin_Shipping_Rates_Panel_Max' ) ) {

    class WTARS_Shipped_Admin_Shipping_Rates_Panel_Max {

        public function __construct() {
            add_filter( 'wtars_shipped_admin/shipping-rates/get-panels', array( $this, 'get_panel' ), 40, 2 );
            add_filter( 'wtars_shipped_admin/shipping-rates/get-panel-max-fields', array( $this, 'get_panel_fields' ), 10, 2 );
        }

        public function get_panel( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'any_id',
                'type' => 'panel',
                'full_width' => true,
                'center_head' => true,
                'white_panel' => false,
                'panel_size' => 'smaller',
                'width' => '100%',
                'merge_fields' => false,
                'css_class' => 'shipped_panel_calcs',
                'field_css_class' => array( 'shipped_panel_calcs_field' ),
                'last' => true,
                'fields' => apply_filters( 'wtars_shipped_admin/shipping-rates/get-panel-max-fields', array(), $args ),
            );

            return $in_fields;
        }

        public function get_panel_fields( $in_fields, $args ) {

            $in_fields[] = array(
                'id' => 'any_id',
                'type' => 'panel',
                'full_width' => true,
                'center_head' => true,
                'white_panel' => true,
                'panel_size' => 'smaller',
                'merge_fields' => false,
                'width' => '100%',
                'last' => true,
                'fields' => array(
                    array(
                        'id' => 'costs_limit',
                        'type' => 'columns-field',
                        'columns' => 4,
                        'merge_fields' => true,
                        'fields' => $this->get_fields( $in_fields, $args ),
                    ),
                ),
            );

            return $in_fields;
        }

        private function get_fields( $in_fields, $args ) {

            $currency = get_woocommerce_currency_symbol( get_woocommerce_currency() );

            $in_fields[] = array(
                'id' => 'limit_type',
                'type' => 'select2',
                'column_size' => 1,
                'column_title' => esc_html__( 'Costs Limit', 'shipped-table-rate-shipping' ),
                'tooltip' => esc_html__( 'Controls shipping rate limit', 'shipped-table-rate-shipping' ),
                'default' => 'no',
                'options' => array(
                    'no' => esc_html__( 'No limit', 'shipped-table-rate-shipping' ),
                    'fixed_limit' => str_replace( '[0]', $currency, esc_html__( 'Fixed ([0])', 'shipped-table-rate-shipping' ) ),
                    'per_limit' => esc_html__( 'Percentage (%)', 'shipped-table-rate-shipping' ),
                ),
                'width' => '100%',
                'fold_id' => 'limit_type',
            );

            $in_fields[] = array(
                'id' => 'limit',
                'type' => 'textbox',
                'input_type' => 'number',
                'column_size' => 1,
                'column_title' => esc_html__( 'Limit', 'shipped-table-rate-shipping' ),
                'tooltip' => esc_html__( 'Controls shipping rate amount limit', 'shipped-table-rate-shipping' ),
                'default' => '',
                'placeholder' => esc_html__( '0.00', 'shipped-table-rate-shipping' ),
                'width' => '100%',
                'attributes' => array(
                    'min' => '0',
                    'step' => '0.01',
                ),
                'fold' => array(
                    'target' => 'limit_type',
                    'attribute' => 'value',
                    'value' => 'no',
                    'oparator' => 'neq',
                    'clear' => true,
                ),
            );

            $in_fields[] = array(
                'id' => 'based_on',
                'type' => 'select2',
                'column_size' => 1,
                'column_title' => esc_html__( 'Limit Based On', 'shipped-table-rate-shipping' ),
                'tooltip' => esc_html__( 'Controls percentage limit based on cart or package totals', 'shipped-table-rate-shipping' ),
                'default' => '2234343',
                'data' => 'shipped:checkout_totals',
                'width' => '100%',
                'fold' => array(
                    'target' => 'limit_type',
                    'attribute' => 'value',
                    'value' => 'per_limit',
                    'oparator' => 'eq',
                    'clear' => true,
                    'empty' => '2234343',
                ),
            );

            return $in_fields;
        }

    }

    new WTARS_Shipped_Admin_Shipping_Rates_Panel_Max();
}
