<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_WMC_Cart' ) ) {

    class WTARS_Shipped_WMC_Cart {

        public function __construct() {

            add_filter( 'wtars_shipped/get-cart-item', array( $this, 'get_cart_item' ), 10, 2 );
            add_filter( 'wtars_shipped/get-cart-product-data', array( $this, 'get_cart_product_data' ), 10, 3 );
            add_filter( 'wtars_shipped/get-cart-totals', array( $this, 'get_cart_totals' ), 10, 2 );
            add_filter( 'wtars_shipped/get-cart-applied-coupons', array( $this, 'get_applied_coupons' ), 10, 2 );
            add_filter( 'wtars_shipped/get-cart-shipping-rates', array( $this, 'get_shipping_rate' ), 10, 2 );
        }

        public function get_cart_item( $item, $cart_item ) {

            $converter = $this->get_converter();

            $item[ 'line_price' ] = $converter->revert_amount( $item[ 'line_price' ] );
            $item[ 'line_price_tax' ] = $converter->revert_amount( $item[ 'line_price_tax' ] );
            $item[ 'line_total_price' ] = $converter->revert_amount( $item[ 'line_total_price' ] );
            $item[ 'line_total_price_tax' ] = $converter->revert_amount( $item[ 'line_total_price_tax' ] );
            $item[ 'line_subtotal' ] = $converter->revert_amount( $item[ 'line_subtotal' ] );
            $item[ 'line_subtotal_tax' ] = $converter->revert_amount( $item[ 'line_subtotal_tax' ] );
            $item[ 'line_total' ] = $converter->revert_amount( $item[ 'line_total' ] );
            $item[ 'line_tax' ] = $converter->revert_amount( $item[ 'line_tax' ] );

            return $item;
        }

        public function get_cart_product_data( $item_data, $product, $item_key ) {

            $converter = $this->get_converter();

            $item_data[ 'regular_price' ] = $converter->revert_amount( $item_data[ 'regular_price' ] );
            $item_data[ 'sale_price' ] = $converter->revert_amount( $item_data[ 'sale_price' ] );
            $item_data[ 'price' ] = $converter->revert_amount( $item_data[ 'price' ] );

            return $item_data;
        }

        public function get_cart_totals( $cart_totals, $cart ) {

            $converter = $this->get_converter();

            $cart_totals[ 'subtotal' ] = $converter->revert_amount( $cart_totals[ 'subtotal' ] );
            $cart_totals[ 'subtotal_tax' ] = $converter->revert_amount( $cart_totals[ 'subtotal_tax' ] );
            $cart_totals[ 'discount_total' ] = $converter->revert_amount( $cart_totals[ 'discount_total' ] );
            $cart_totals[ 'discount_tax' ] = $converter->revert_amount( $cart_totals[ 'discount_tax' ] );
            $cart_totals[ 'cart_contents_total' ] = $converter->revert_amount( $cart_totals[ 'cart_contents_total' ] );
            $cart_totals[ 'cart_contents_tax' ] = $converter->revert_amount( $cart_totals[ 'cart_contents_tax' ] );
            $cart_totals[ 'cart_contents_taxes' ] = $converter->revert_amount_list( $cart_totals[ 'cart_contents_taxes' ] );

            return $cart_totals;
        }

        public function get_applied_coupons( $applied_coupons, $cart ) {

            $converter = $this->get_converter();

            $keys = array_keys( $applied_coupons );

            foreach ( $keys as $key ) {

                $applied_coupons[ $key ][ 'coupon_totals' ] = $converter->revert_amount( $applied_coupons[ $key ][ 'coupon_totals' ] );
                $applied_coupons[ $key ][ 'coupon_totals_tax' ] = $converter->revert_amount( $applied_coupons[ $key ][ 'coupon_totals_tax' ] );
            }

            return $applied_coupons;
        }

        public function get_shipping_rate( $shipping_rates, $cart ) {

            $converter = $this->get_converter();

            $keys = array_keys( $shipping_rates );

            foreach ( $keys as $key ) {

                $shipping_rates[ $key ][ 'cost' ] = $converter->revert_amount( $shipping_rates[ $key ][ 'cost' ] );
                $shipping_rates[ $key ][ 'shipping_tax' ] = $converter->revert_amount( $shipping_rates[ $key ][ 'shipping_tax' ] );
                $shipping_rates[ $key ][ 'taxes' ] = $converter->revert_amount_list( $shipping_rates[ $key ][ 'taxes' ] );
            }

            return $shipping_rates;
        }

        private function get_converter() {

            return WTARS_Shipped_WMC::get_instance();
        }

    }

    new WTARS_Shipped_WMC_Cart();
}
