<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Conditions_Billing_Address' ) ) {

    class WTARS_Shipped_Conditions_Billing_Address {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-billing_continents-condition', array( $this, 'validate_continent' ), 10 );
            add_filter( 'wtars_shipped/validate-billing_countries-condition', array( $this, 'validate_countries' ), 10 );
            add_filter( 'wtars_shipped/validate-billing_states-condition', array( $this, 'validate_states' ), 10 );
            add_filter( 'wtars_shipped/validate-billing_cities-condition', array( $this, 'validate_cities' ), 10 );
            add_filter( 'wtars_shipped/validate-billing_postcodes-condition', array( $this, 'validate_postcodes' ), 10 );
        }

        public function validate_continent( $condition ) {

            $rule_continents = $condition[ 'continents' ];

            $rule_compare = $condition[ 'compare' ];

            if ( !is_array( $rule_continents ) ) {
                return false;
            }

            $country = WC()->customer->get_billing_country();

            if ( empty( $country ) ) {
                return false;
            }

            $wc_Countries = new WC_Countries();

            $continent = $wc_Countries->get_continent_code_for_country( $country );

            return WTARS_Shipped_Validation_Util::validate_value_list( $continent, $rule_continents, $rule_compare );
        }

        public function validate_countries( $condition ) {

            $rule_countries = $condition[ 'countries' ];

            $rule_compare = $condition[ 'compare' ];

            if ( !is_array( $rule_countries ) ) {
                return false;
            }

            $country = WC()->customer->get_billing_country();

            if ( empty( $country ) ) {
                return false;
            }

            return WTARS_Shipped_Validation_Util::validate_value_list( $country, $rule_countries, $rule_compare );
        }

        public function validate_states( $condition ) {

            $rule_states = $condition[ 'states' ];

            $rule_compare = $condition[ 'compare' ];

            if ( !is_array( $rule_states ) ) {
                return false;
            }

            $country = WC()->customer->get_billing_country();

            $dest_state = WC()->customer->get_billing_state();

            $state = $country . ':' . $dest_state;

            return WTARS_Shipped_Validation_Util::validate_value_list( $state, $rule_states, $rule_compare );
        }

        public function validate_cities( $condition ) {

            $rule_city_str = $condition[ 'cities' ];

            if ( empty( $rule_city_str ) ) {
                return false;
            }

            $rule_cities = explode( ',', str_replace( ', ', ',', strtolower( $rule_city_str ) ) );

            $rule_compare = $condition[ 'compare' ];

            $city = strtolower( WC()->customer->get_billing_city() );

            return WTARS_Shipped_Validation_Util::validate_value_list( $city, $rule_cities, $rule_compare );
        }

        public function validate_postcodes( $condition ) {

            $rule_postcode = $condition[ 'postcode' ];

            if ( empty( $rule_postcode ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            $postcode = WC()->customer->get_billing_postcode();

            return WTARS_Shipped_Validation_Util::validate_match_value( $rule_compare, $postcode, $rule_postcode );
        }

    }

    new WTARS_Shipped_Conditions_Billing_Address();
}

