<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Conditions_Customer' ) ) {

    class WTARS_Shipped_Premium_Conditions_Customer {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-user_roles-condition', array( $this, 'validate_user_roles' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-user_caps-condition', array( $this, 'validate_user_caps' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-user_meta-condition', array( $this, 'validate_user_meta' ), 10, 2 );
        }

        public function validate_user_roles( $condition, $data ) {

            if ( !isset( $condition[ 'user_roles' ] ) ) {
                return false;
            }

            $rule_user_roles = $condition[ 'user_roles' ];

            if ( !count( $rule_user_roles ) ) {
                return false;
            }


            $user_roles = WTARS_Shipped_Customer_Util::get_user_roles( $data );

            if ( !count( $user_roles ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $user_roles, $rule_user_roles, $rule_compare );
        }

        public function validate_user_caps( $condition, $data ) {

            if ( !isset( $condition[ 'user_caps' ] ) ) {
                return false;
            }

            $rule_user_caps = $condition[ 'user_caps' ];

            if ( !count( $rule_user_caps ) ) {
                return false;
            }

            $user_caps = WTARS_Shipped_Customer_Util::get_user_caps( $data );

            if ( !count( $user_caps ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $user_caps, $rule_user_caps, $rule_compare );
        }

        public function validate_user_meta( $condition, $data ) {

            if ( !isset( $condition[ 'meta_key' ] ) ) {
                return false;
            }

            $rule_meta_key = $condition[ 'meta_key' ];

            if ( $rule_meta_key == '' ) {
                return false;
            }

            $rule_yes_no = 'no';

            if ( isset( $condition[ 'yes_no' ] ) && !empty( $condition[ 'yes_no' ] ) ) {
                $rule_yes_no = $condition[ 'yes_no' ];
            }

            $rule_meta_value = '';

            if ( isset( $condition[ 'meta_value' ] ) ) {
                $rule_meta_value = $condition[ 'meta_value' ];
            }

            $meta_value = WTARS_Shipped_Customer_Util::get_user_meta( $data, $rule_meta_key, array() );

            if ( is_array( $meta_value ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $meta_value, $rule_meta_value, $rule_yes_no );
        }

    }

    new WTARS_Shipped_Premium_Conditions_Customer();
}