<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Conditions_DateTime' ) ) {

    class WTARS_Shipped_Conditions_DateTime {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-date-condition', array( $this, 'validate_date' ), 10 );
            add_filter( 'wtars_shipped/validate-time-condition', array( $this, 'validate_time' ), 10 );
            add_filter( 'wtars_shipped/validate-date_time-condition', array( $this, 'validate_date_time' ), 10 );
            add_filter( 'wtars_shipped/validate-days_week-condition', array( $this, 'validate_days_week' ), 10 );
            add_filter( 'wtars_shipped/validate-days_month-condition', array( $this, 'validate_days_month' ), 10 );
            add_filter( 'wtars_shipped/validate-months_year-condition', array( $this, 'validate_months_year' ), 10 );
        }

        public function validate_date( $condition ) {

            if ( !isset( $condition[ 'date_type' ] ) ) {
                return false;
            }

            $date_type = $condition[ 'date_type' ];

            if ( $date_type == 'between' ) {

                $rule_from_date = $condition[ 'from_date' ];
                $rule_to_date = $condition[ 'to_date' ];

                if ( $rule_from_date == '' || $rule_to_date == '' ) {
                    return false;
                }

                $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );


                $from_is_valid = WTARS_Shipped_Validation_Util::validate_date( '>=', $current_date_time, $rule_from_date . ' 00:00:00', 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
                $to_is_valid = WTARS_Shipped_Validation_Util::validate_date( '<=', $current_date_time, $rule_to_date . ' 23:59:59', 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

                return ($from_is_valid == true && $to_is_valid == true);
            } else if ( $date_type == 'date' ) {

                $rule_date = $condition[ 'date' ];

                if ( $rule_date == '' ) {
                    return false;
                }

                $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );


                $from_is_valid = WTARS_Shipped_Validation_Util::validate_date( '>=', $current_date_time, $rule_date . ' 00:00:00', 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
                $to_is_valid = WTARS_Shipped_Validation_Util::validate_date( '<=', $current_date_time, $rule_date . ' 23:59:59', 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

                return ($from_is_valid == true && $to_is_valid == true);
            } else {
                $rule_date = $condition[ 'date' ];

                if ( $rule_date == '' ) {
                    return false;
                }

                $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );

                $valid_type = '>=';
                $date_time = ' 00:00:00';

                if ( $date_type == 'to' ) {
                    $valid_type = '<=';
                    $date_time = ' 23:59:59';
                }

                return WTARS_Shipped_Validation_Util::validate_date( $valid_type, $current_date_time, $rule_date . $date_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            }
        }

        public function validate_time( $condition ) {

            if ( !isset( $condition[ 'time_type' ] ) ) {
                return false;
            }

            $rule_time_type = $condition[ 'time_type' ];

            if ( $rule_time_type == 'between' ) {

                $rule_from_time = $condition[ 'from_time' ];
                $rule_to_time = $condition[ 'to_time' ];

                if ( $rule_from_time == '' || $rule_to_time == '' ) {
                    return false;
                }

                $today = WTARS_Shipped_DateTime_Util::get_current_date( false ) . ' ';
                $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );


                $from_is_valid = WTARS_Shipped_Validation_Util::validate_date( '>=', $current_date_time, $today . $rule_from_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
                $to_is_valid = WTARS_Shipped_Validation_Util::validate_date( '<=', $current_date_time, $today . $rule_to_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

                return ($from_is_valid == true && $to_is_valid == true);
            } else {

                $rule_time = $condition[ 'time' ];

                if ( $rule_time == '' ) {
                    return false;
                }

                $today = WTARS_Shipped_DateTime_Util::get_current_date( false ) . ' ';
                $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );

                $valid_type = '>=';
                if ( $rule_time_type == 'to' ) {
                    $valid_type = '<=';
                }

                return WTARS_Shipped_Validation_Util::validate_date( $valid_type, $current_date_time, $today . $rule_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            }
        }

        public function validate_date_time( $condition ) {

            $rule_date_type = $condition[ 'date_type' ];

            if ( $rule_date_type == 'between' ) {

                $rule_from_date_time = $condition[ 'from_date_time' ];
                $rule_to_date_time = $condition[ 'to_date_time' ];

                if ( $rule_from_date_time == '' || $rule_to_date_time == '' ) {
                    return false;
                }

                $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );

                $from_is_valid = WTARS_Shipped_Validation_Util::validate_date( '>=', $current_date_time, $rule_from_date_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
                $to_is_valid = WTARS_Shipped_Validation_Util::validate_date( '<=', $current_date_time, $rule_to_date_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

                return ($from_is_valid == true && $to_is_valid == true);
            } else {

                $rule_date_time = $condition[ 'date_time' ];

                if ( $rule_date_time == '' ) {
                    return false;
                }

                $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );

                $valid_type = '>=';
                if ( $rule_date_type == 'to' ) {
                    $valid_type = '<=';
                }

                return WTARS_Shipped_Validation_Util::validate_date( $valid_type, $current_date_time, $rule_date_time, 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            }
        }

        public function validate_days_week( $condition ) {

            $rule_days = $condition[ 'days' ];

            if ( !is_array( $rule_days ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];


            $range = WTARS_Shipped_DateTime_Util::get_date_from_week_days( $rule_compare, $rule_days );

            if ( !count( $range ) ) {
                return false;
            }

            $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );

            $from_is_valid = WTARS_Shipped_Validation_Util::validate_date( '>=', $current_date_time, $range[ 'from' ], 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            $to_is_valid = WTARS_Shipped_Validation_Util::validate_date( '<=', $current_date_time, $range[ 'to' ], 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

            return ($from_is_valid == true && $to_is_valid == true);
        }

        public function validate_days_month( $condition ) {

            $rule_days = $condition[ 'days' ];

            if ( !is_array( $rule_days ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            $date_range = WTARS_Shipped_DateTime_Util::get_date_from_month_days( $rule_compare, $rule_days );

            if ( !count( $date_range ) ) {
                return false;
            }

            $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );

            $from_is_valid = WTARS_Shipped_Validation_Util::validate_date( '>=', $current_date_time, $date_range[ 'from' ], 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            $to_is_valid = WTARS_Shipped_Validation_Util::validate_date( '<=', $current_date_time, $date_range[ 'to' ], 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

            return ($from_is_valid == true && $to_is_valid == true);
        }

        public function validate_months_year( $condition ) {
            
            $rule_months = $condition[ 'months' ];

            if ( !is_array( $rule_months ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            $date_range = WTARS_Shipped_DateTime_Util::get_date_from_year_months( $rule_compare, $rule_months );

            if ( !count( $date_range ) ) {
                return false;
            }

            $current_date_time = WTARS_Shipped_DateTime_Util::get_current_date( true );

            $from_is_valid = WTARS_Shipped_Validation_Util::validate_date( '>=', $current_date_time, $date_range[ 'from' ], 'Y-m-d H:i:s', 'Y-m-d H:i:s' );
            $to_is_valid = WTARS_Shipped_Validation_Util::validate_date( '<=', $current_date_time, $date_range[ 'to' ], 'Y-m-d H:i:s', 'Y-m-d H:i:s' );

            return ($from_is_valid == true && $to_is_valid == true);
        }

    }

    new WTARS_Shipped_Conditions_DateTime();
}