<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Conditions_Order' ) ) {

    class WTARS_Shipped_Premium_Conditions_Order {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-cart_quantity-condition', array( $this, 'validate_quantity' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-cart_line_count-condition', array( $this, 'validate_line_count' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_line_count-condition', array( $this, 'validate_line_count' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-applied_coupons-condition', array( $this, 'validate_coupons' ), 10, 2 );
        }

        public function validate_quantity( $condition, $data ) {

            $quantity = $this->get_quantity( $data );

            $rule_compare = $condition[ 'compare' ];

            if ( '--' == $rule_compare ) {

                $rule_from_quantity = 0;

                if ( is_numeric( $condition[ 'from_quantity' ] ) ) {

                    $rule_from_quantity = $condition[ 'from_quantity' ];
                }

                $rule_to_quantity = 1;

                if ( is_numeric( $condition[ 'to_quantity' ] ) ) {

                    $rule_to_quantity = $condition[ 'to_quantity' ];
                }

                $from_is_valid = WTARS_Shipped_Validation_Util::validate_value( '>=', $quantity, $rule_from_quantity, 'no' );

                $to_is_valid = WTARS_Shipped_Validation_Util::validate_value( '<=', $quantity, $rule_to_quantity, 'no' );

                return (true == $from_is_valid && true == $to_is_valid);
            }


            $rule_quantity = 0;

            if ( is_numeric( $condition[ 'quantity' ] ) ) {

                $rule_quantity = $condition[ 'quantity' ];
            }

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_line_count( $condition, $data ) {

            $condition_type = $condition[ 'condition_type' ];

            $line_count = $this->get_line_count( $condition_type, $data );

            $rule_compare = $condition[ 'compare' ];

            if ( '--' == $rule_compare ) {

                $rule_from_line_count = 0;

                if ( is_numeric( $condition[ 'from_line_count' ] ) ) {

                    $rule_from_line_count = $condition[ 'from_line_count' ];
                }

                $rule_to_line_count = 0;

                if ( is_numeric( $condition[ 'to_line_count' ] ) ) {

                    $rule_to_line_count = $condition[ 'to_line_count' ];
                }

                $from_is_valid = WTARS_Shipped_Validation_Util::validate_value( '>=', $line_count, $rule_from_line_count, 'no' );

                $to_is_valid = WTARS_Shipped_Validation_Util::validate_value( '<=', $line_count, $rule_to_line_count, 'no' );

                return (true == $from_is_valid && true == $to_is_valid);
            }

            $rule_line_count = 0;

            if ( is_numeric( $condition[ 'line_count' ] ) ) {

                $rule_line_count = $condition[ 'line_count' ];
            }

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $line_count, $rule_line_count, 'no' );
        }

        public function validate_coupons( $condition, $data ) {
            
            $coupon_ids = $this->get_coupon_ids( $data );

            $rule_compare = $condition[ 'compare' ];

            if ( $rule_compare === 'any' ) {

                $is_any = 'yes';

                if ( !empty( $condition[ 'is_any' ] ) ) {
                    
                    $is_any = $condition[ 'is_any' ];
                }

                return WTARS_Shipped_Validation_Util::validate_list_empty( $coupon_ids, $is_any );
            }

            $rule_coupons = $condition[ 'coupons' ];


            if ( !is_array( $rule_coupons ) ) {
                return false;
            }

            return WTARS_Shipped_Validation_Util::validate_list_list( $coupon_ids, $rule_coupons, $rule_compare );
        }

        private function get_quantity( $data ) {

            $quantity = 0;

            if ( !isset( $data[ 'wc' ][ 'cart' ][ 'items' ] ) ) {
                return $quantity;
            }

            foreach ( $data[ 'wc' ][ 'cart' ][ 'items' ] as $cart_item ) {
                $quantity += $cart_item[ 'quantity' ];
            }

            return $quantity;
        }

        private function get_line_count( $condition_type, $data ) {

            if ( 'cart_line_count' == $condition_type ) {

                if ( !isset( $data[ 'wc' ][ 'cart' ][ 'items' ] ) ) {
                    return 0;
                }

                return count( $data[ 'wc' ][ 'cart' ][ 'items' ] );
            }

            if ( 'package_line_count' == $condition_type ) {
                if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                    return 0;
                }

                return count( $data[ 'wc' ][ 'package' ][ 'items' ] );
            }

            return 0;
        }

        private function get_coupon_ids( $data ) {

            $coupon_ids = array();

            if ( !isset( $data[ 'wc' ][ 'cart' ][ 'applied_coupons' ] ) ) {
                return $coupon_ids;
            }

            foreach ( $data[ 'wc' ][ 'cart' ][ 'applied_coupons' ] as $coupon ) {

                $coupon_id = wc_get_coupon_id_by_code( $coupon[ 'coupon_code' ] );

                if ( $coupon_id > 0 ) {

                    $coupon_ids[] = $coupon_id;
                }
            }

            return $coupon_ids;
        }

    }

    new WTARS_Shipped_Premium_Conditions_Order();
}