<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Conditions_Package_Items_Quantity' ) ) {

    class WTARS_Shipped_Conditions_Package_Items_Quantity {

        public function __construct() {
            
            add_filter( 'wtars_shipped/validate-package_qty_ids-condition', array( $this, 'validate_products' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_qty_vars-condition', array( $this, 'validate_variations' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_qty_cats-condition', array( $this, 'validate_categories' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_qty_tags-condition', array( $this, 'validate_tags' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_qty_attrs-condition', array( $this, 'validate_attributes' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_qty_tax_classes-condition', array( $this, 'validate_tax_classes' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_qty_sh_classes-condition', array( $this, 'validate_shipping_classes' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_qty_metas-condition', array( $this, 'validate_metas' ), 10, 2 );
        }

        public function validate_products( $condition, $data ) {

            if ( !isset( $condition[ 'product_slugs' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $data ) ) {
                return false;
            }

            $rule_product_ids = WTARS_Shipped_Util::get_product_ids_by_slugs( $condition[ 'product_slugs' ] );

            if ( !count( $rule_product_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WTARS_Shipped_Order_Util::get_package_items_by_ids( $data, $rule_product_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_variations( $condition, $data ) {

            if ( !isset( $condition[ 'variation_slugs' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $data ) ) {
                return false;
            }

            $rule_variation_ids = WTARS_Shipped_Util::get_variation_ids_by_slugs( $condition[ 'variation_slugs' ] );

            if ( !count( $rule_variation_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WTARS_Shipped_Order_Util::get_package_items_by_variation_ids( $data, $rule_variation_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_categories( $condition, $data ) {

            if ( !isset( $condition[ 'category_slugs' ] ) ) {
                return false;
            }

            if ( $this->is_empty_items( $data ) ) {
                return false;
            }

            $rule_category_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $condition[ 'category_slugs' ], 'product_cat' );

            if ( !count( $rule_category_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WTARS_Shipped_Order_Util::get_package_items_by_category_ids( $data, $rule_category_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_tags( $condition, $data ) {

            if ( !isset( $condition[ 'tag_slugs' ] ) ) {
                return false;
            }

            if ( $this->is_empty_items( $data ) ) {
                return false;
            }

            $rule_tag_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $condition[ 'tag_slugs' ], 'product_tag' );

            if ( !count( $rule_tag_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WTARS_Shipped_Order_Util::get_package_items_by_tag_ids( $data, $rule_tag_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_attributes( $condition, $data ) {

            if ( !isset( $condition[ 'attribute_slugs' ] ) ) {
                return false;
            }


            if ( $this->is_empty_items( $data ) ) {
                return false;
            }

            $rule_attribute_ids = WTARS_Shipped_Util::get_attribute_ids_by_slugs( $condition[ 'attribute_slugs' ] );

            if ( !count( $rule_attribute_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WTARS_Shipped_Order_Util::get_package_items_by_attribute_ids( $data, $rule_attribute_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_tax_classes( $condition, $data ) {

            if ( !isset( $condition[ 'tax_classes' ] ) ) {
                return false;
            }

            if ( $this->is_empty_items( $data ) ) {
                return false;
            }

            $rule_tax_classes = $condition[ 'tax_classes' ];

            if ( !count( $rule_tax_classes ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WTARS_Shipped_Order_Util::get_package_items_by_tax_classes( $data, $rule_tax_classes ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_shipping_classes( $condition, $data ) {

            if ( !isset( $condition[ 'shipping_classes' ] ) ) {
                return false;
            }

            if ( $this->is_empty_items( $data ) ) {
                return false;
            }

            $rule_shipping_classe_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $condition[ 'shipping_classes' ], 'product_shipping_class' );

            if ( !count( $rule_shipping_classe_ids ) ) {
                return false;
            }

            $quantity = $this->get_quantity( WTARS_Shipped_Order_Util::get_package_items_by_shipping_class_ids( $data, $rule_shipping_classe_ids ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        public function validate_metas( $condition, $data ) {

            if ( !isset( $condition[ 'meta_key' ] ) || !isset( $condition[ 'meta_value' ] ) ) {
                return false;
            }

            if ( $this->is_empty_items( $data ) ) {
                return false;
            }

            $meta_key = $condition[ 'meta_key' ];
            $meta_value = $condition[ 'meta_value' ];

            $quantity = $this->get_quantity( WTARS_Shipped_Order_Util::get_package_items_by_meta( $data, $meta_key, $meta_value ) );

            $rule_quantity = $condition[ 'quantity' ];

            if ( !is_numeric( $rule_quantity ) ) {
                return false;
            }

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $quantity, $rule_quantity, 'no' );
        }

        private function get_quantity( $package_items ) {

            $quantity = 0;

            if ( !count( $package_items ) ) {
                return $quantity;
            }

            foreach ( $package_items as $package_item ) {

                $quantity += $package_item[ 'quantity' ];
            }

            return $quantity;
        }

        private function is_empty_items( $data ) {

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return true;
            }

            return false;
        }

    }

    new WTARS_Shipped_Conditions_Package_Items_Quantity();
}