<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Conditions_Package_Items' ) ) {

    class WTARS_Shipped_Premium_Conditions_Package_Items {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-package_vars-condition', array( $this, 'validate_variations' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_attrs-condition', array( $this, 'validate_attributes' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_tax_classes-condition', array( $this, 'validate_tax_classes' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-package_metas-condition', array( $this, 'validate_metas' ), 10, 2 );
        }

        public function validate_variations( $condition, $data ) {

            if ( !isset( $condition[ 'variation_slugs' ] ) ) {
                return false;
            }

            $rule_variation_ids = WTARS_Shipped_Util::get_variation_ids_by_slugs( $condition[ 'variation_slugs' ] );

            if ( !count( $rule_variation_ids ) ) {
                return false;
            }

            $variation_ids = WTARS_Shipped_Order_Util::get_package_variation_ids( $data );

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $variation_ids, $rule_variation_ids, $rule_compare );
        }

        public function validate_attributes( $condition, $data ) {

            if ( !isset( $condition[ 'attribute_slugs' ] ) ) {
                return false;
            }

            $rule_attribute_ids = WTARS_Shipped_Util::get_attribute_ids_by_slugs( $condition[ 'attribute_slugs' ] );

            if ( !count( $rule_attribute_ids ) ) {
                return false;
            }

            $attribute_ids = WTARS_Shipped_Order_Util::get_package_attribute_ids( $data );

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $attribute_ids, $rule_attribute_ids, $rule_compare );
        }

        public function validate_tax_classes( $condition, $data ) {

            if ( !isset( $condition[ 'tax_classes' ] ) ) {
                return false;
            }

            $rule_tax_classes = $condition[ 'tax_classes' ];

            $tax_classes = WTARS_Shipped_Order_Util::get_package_tax_classes( $data );

            $rule_compare = $condition[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $tax_classes, $rule_tax_classes, $rule_compare );
        }

        public function validate_metas( $condition, $data ) {
            
            $rule_meta_key = $condition[ 'meta_key' ];

            $rule_yes_no = 'no';
            $rule_meta_value = '';

            if ( isset( $condition[ 'yes_no' ] ) ) {
                $rule_yes_no = $condition[ 'yes_no' ];
            }

            if ( isset( $condition[ 'meta_value' ] ) ) {
                $rule_meta_value = $condition[ 'meta_value' ];
            }

            $product_metas = WTARS_Shipped_Order_Util::get_package_product_metas( $data, $rule_meta_key );


            $rule_compare = $condition[ 'compare' ];

            foreach ( $product_metas as $product_meta ) {

                $is_valid = WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $product_meta, $rule_meta_value, $rule_yes_no );
                if ( $is_valid ) {
                    return true;
                }
            }

            return false;
        }

    }

    new WTARS_Shipped_Premium_Conditions_Package_Items();
}
