<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Conditions_Package_Weight' ) ) {

    class WTARS_Shipped_Premium_Conditions_Package_Weight {

        private $option_id_list = array();
        private $prefix = 'package_weight-';

        public function __construct() {

            add_filter( 'wtars_shipped/cache-data', array( $this, 'init' ), 1 );
        }

        public function init( $data ) {

            if ( !isset( $data[ 'wc' ][ 'instance_id' ] ) ) {
                return $data;
            }

            $instance_id = $data[ 'wc' ][ 'instance_id' ];

            foreach ( $this->get_option_ids( $instance_id ) as $option_id ) {

                if ( in_array( $option_id, $this->option_id_list ) ) {
                    continue;
                }
                add_filter( 'wtars_shipped/validate-' . $this->prefix . $option_id . '-condition', array( $this, 'validate_weights' ), 10, 2 );
                
                $this->option_id_list[] = $option_id;
            }

            return $data;
        }

        public function validate_weights( $condition, $data ) {

            $condition_type = $condition[ 'condition_type' ];

            $total_weight = $this->get_total_weight( $condition_type, $data );

            $rule_compare = $condition[ 'compare' ];

            if ( '--' == $rule_compare ) {

                $rule_from_weight = 0;

                if ( is_numeric( $condition[ 'from_weight' ] ) ) {

                    $rule_from_weight = $condition[ 'from_weight' ];
                }

                $rule_to_weight = .5;

                if ( is_numeric( $condition[ 'to_weight' ] ) ) {

                    $rule_to_weight = $condition[ 'to_weight' ];
                }

                $from_is_valid = WTARS_Shipped_Validation_Util::validate_value( '>=', $total_weight, $rule_from_weight, 'no' );

                $to_is_valid = WTARS_Shipped_Validation_Util::validate_value( '<=', $total_weight, $rule_to_weight, 'no' );

                return (true == $from_is_valid && true == $to_is_valid);
            }

            $rule_weight = 0;

            if ( is_numeric( $condition[ 'weight' ] ) ) {

                $rule_weight = $condition[ 'weight' ];
            }

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $total_weight, $rule_weight, 'no' );
        }

        private function get_total_weight( $condition_type, $data ) {

            if ( !isset( $data[ 'wc' ][ 'instance_id' ] ) ) {
                return 0;
            }

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return 0;
            }

            $instance_id = $data[ 'wc' ][ 'instance_id' ];
            $option_id = preg_replace( '/' . $this->prefix . '/', '', $condition_type );

            $weight_calc = new WTARS_Shipped_Weight_Calculator();

            $weight_args = array(
                'instance_id' => $instance_id,
                'option_id' => $option_id,
            );

            $package_items = WTARS_Shipped_Product_Filter_Types::get_package_items( $data, array(), true );

            $total_weight = $weight_calc->get_total_weight( $package_items, $weight_args );

            return $total_weight;
        }

        public function get_option_ids( $instance_id ) {

            $opts = WTARS_Shipped::get_option( 'weight_calcs', $instance_id, array() );

            $options = array();

            foreach ( $opts as $opt ) {

                if ( !isset( $opt[ 'option_id' ] ) ) {
                    continue;
                }
                $options[] = $opt[ 'option_id' ];
            }

            if ( !count( $options ) ) {
                
                return self::get_default();
            }

            return $options;
        }

        private static function get_default() {

            return array( '2234343', '2234344' );
        }

    }

    new WTARS_Shipped_Premium_Conditions_Package_Weight();
}