<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Conditions_Purchase_History_Subtotal' ) ) {

    class WTARS_Shipped_Conditions_Purchase_History_Subtotal {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-purchased_products_subtotal-condition', array( $this, 'validate_products' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-purchased_variations_subtotal-condition', array( $this, 'validate_variations' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-purchased_categories_subtotal-condition', array( $this, 'validate_categories' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-purchased_tags_subtotal-condition', array( $this, 'validate_tags' ), 10, 2 );
            add_filter( 'wtars_shipped/validate-purchased_attributes_subtotal-condition', array( $this, 'validate_attributes' ), 10, 2 );
        }

        public function validate_products( $condition, $data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $rule_product_slugs = '';

            if ( isset( $condition[ 'all_time_product_slugs' ] ) ) {
                $rule_product_slugs = $condition[ 'all_time_product_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_product_slugs = '';

                if ( isset( $condition[ 'product_slugs' ] ) ) {
                    $rule_product_slugs = $condition[ 'product_slugs' ];
                }
            }

            if ( $rule_product_slugs == '' ) {
                return false;
            }

            $rule_product_ids = WTARS_Shipped_Util::get_product_ids_by_slugs( $rule_product_slugs );

            $from_date = WTARS_Shipped_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $rule_compare = $condition[ 'compare' ];

            $rule_subtotal = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotal ) ) {
                $rule_subtotal = 0;
            }

            $subtotal = $this->get_subtotals( WTARS_Shipped_Customer_Util::get_purchased_products( $data, $from_date, $rule_product_ids, $hash_key ) );

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $subtotal, $rule_subtotal );
        }

        public function validate_variations( $condition, $data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $rule_variation_slugs = '';

            if ( isset( $condition[ 'all_time_variation_slugs' ] ) ) {

                $rule_variation_slugs = $condition[ 'all_time_variation_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_variation_slugs = '';

                if ( isset( $condition[ 'variation_slugs' ] ) ) {
                    $rule_variation_slugs = $condition[ 'variation_slugs' ];
                }
            }

            if ( $rule_variation_slugs == '' ) {
                return false;
            }

            $rule_variation_ids = WTARS_Shipped_Util::get_variation_ids_by_slugs( $rule_variation_slugs );

            $from_date = WTARS_Shipped_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $rule_compare = $condition[ 'compare' ];

            $rule_subtotal = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotal ) ) {
                $rule_subtotal = 0;
            }

            $subtotal = $this->get_subtotals( WTARS_Shipped_Customer_Util::get_purchased_variations( $data, $from_date, $rule_variation_ids, $hash_key ) );

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $subtotal, $rule_subtotal );
        }

        public function validate_categories( $condition, $data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $rule_category_slugs = '';

            if ( isset( $condition[ 'all_time_category_slugs' ] ) ) {

                $rule_category_slugs = $condition[ 'all_time_category_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_category_slugs = '';

                if ( isset( $condition[ 'category_slugs' ] ) ) {
                    $rule_category_slugs = $condition[ 'category_slugs' ];
                }
            }

            if ( $rule_category_slugs == '' ) {
                return false;
            }

            $rule_category_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $rule_category_slugs, 'product_cat' );

            $from_date = WTARS_Shipped_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $rule_compare = $condition[ 'compare' ];

            $rule_subtotal = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotal ) ) {
                $rule_subtotal = 0;
            }

            $subtotal = $this->get_subtotals( WTARS_Shipped_Customer_Util::get_purchased_terms( $data, $from_date, $rule_category_ids, 'product_cat', $hash_key ) );

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $subtotal, $rule_subtotal );
        }

        public function validate_tags( $condition, $data ) {

            $rule_date_type = $condition[ 'date_type' ];

            $rule_tags_slugs = '';

            if ( isset( $condition[ 'all_time_tag_slugs' ] ) ) {

                $rule_tags_slugs = $condition[ 'all_time_tag_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_tags_slugs = '';

                if ( isset( $condition[ 'tag_slugs' ] ) ) {
                    $rule_tags_slugs = $condition[ 'tag_slugs' ];
                }
            }

            if ( $rule_tags_slugs == '' ) {
                return false;
            }

            $rule_tag_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $rule_tags_slugs, 'product_tag' );

            $from_date = WTARS_Shipped_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $rule_compare = $condition[ 'compare' ];

            $rule_subtotal = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotal ) ) {
                $rule_subtotal = 0;
            }

            $subtotal = $this->get_subtotals( WTARS_Shipped_Customer_Util::get_purchased_terms( $data, $from_date, $rule_tag_ids, 'product_tag', $hash_key ) );

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $subtotal, $rule_subtotal );
        }

        public function validate_attributes( $condition, $data ) {
            
            $rule_date_type = $condition[ 'date_type' ];

            $rule_attribute_slugs = '';

            if ( isset( $condition[ 'all_time_attribute_slugs' ] ) ) {

                $rule_attribute_slugs = $condition[ 'all_time_attribute_slugs' ];
            }

            if ( $rule_date_type != 'all_time' && $rule_date_type != '' ) {

                $rule_attribute_slugs = '';

                if ( isset( $condition[ 'attribute_slugs' ] ) ) {
                    $rule_attribute_slugs = $condition[ 'attribute_slugs' ];
                }
            }

            if ( $rule_attribute_slugs == '' ) {
                return false;
            }

            $rule_attribute_ids = WTARS_Shipped_Util::get_attribute_ids_by_slugs( $rule_attribute_slugs );

            $from_date = WTARS_Shipped_DateTime_Util::get_date_from_args( $condition );

            $hash_key = $this->get_hash_key( $condition );

            $rule_compare = $condition[ 'compare' ];

            $rule_subtotal = $condition[ 'subtotal' ];

            if ( !is_numeric( $rule_subtotal ) ) {
                $rule_subtotal = 0;
            }

            $subtotal = $this->get_subtotals( WTARS_Shipped_Customer_Util::get_purchased_attributes($data, $from_date, $rule_attribute_ids, $hash_key ) );

            return WTARS_Shipped_Validation_Util::validate_value( $rule_compare, $subtotal, $rule_subtotal );
        }

        private function get_subtotals( $products ) {

            $subtotals = 0;

            if ( !count( $products ) ) {
                return $subtotals;
            }

            foreach ( $products as $product ) {

                $subtotals += $product[ 'subtotal' ];
                $subtotals += $product[ 'subtotal_tax' ];
            }

            return $subtotals;
        }

        private function get_hash_key( $condition ) {

            $hash_args = array();

            if ( isset( $condition[ 'date_type' ] ) ) {
                $hash_args[ 'date_type' ] = $condition[ 'date_type' ];
            }

            if ( isset( $condition[ 'current' ] ) ) {
                $hash_args[ 'current' ] = $condition[ 'current' ];
            }

            if ( isset( $condition[ 'date_offset' ] ) ) {
                $hash_args[ 'date_offset' ] = $condition[ 'date_offset' ];
            }

            return md5( wp_json_encode( $hash_args ) );
        }

    }

    new WTARS_Shipped_Conditions_Purchase_History_Subtotal();
}