<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Cost_Tax' ) ) {

    class WTARS_Shipped_Premium_Cost_Tax {

        private static function get_instance() {
            return new self();
        }

        public static function calculate( $cost, $tax_args, $package_items ) {

            if ( 'ship_rates' == $tax_args[ 'tax_type' ] ) {
                return self::get_instance()->calculate_shipping_rates( $cost, $tax_args );
            }

            if ( 'reg_rates' == $tax_args[ 'tax_type' ] ) {
                return self::get_instance()->calculate_rates( $cost, $tax_args );
            }

            return array();
        }

        private function calculate_rates( $cost, $tax_args ) {

            $tax_rates = WC_Tax::get_rates( $tax_args[ 'tax_class' ] );
            $taxes = WC_Tax::calc_tax( $cost, $tax_rates, $tax_args[ 'inclusive_tax' ] );

            return array_map( array( $this, 'round_tax' ), $taxes );
        }

        private function calculate_shipping_rates( $cost, $tax_args ) {

            $tax_rates = WC_Tax::get_shipping_tax_rates( $tax_args[ 'tax_class' ] );
            $taxes = WC_Tax::calc_tax( $cost, $tax_rates, $tax_args[ 'inclusive_tax' ] );

            return array_map( array( $this, 'round_tax' ), $taxes );
        }

        private function round_tax( $tax ) {
            
            return WTARS_Shipped_Util::round_num( $tax, wc_get_price_decimals() );
        }

    }

}
