<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Cost_Type_Width' ) ) {

    class WTARS_Shipped_Cost_Type_Width {

        public function __construct() {

            add_filter( 'wtars_shipped/calculate-per_height-cost', array( $this, 'calculate_per_height' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-by_height-cost', array( $this, 'calculate_by_height' ), 1, 3 );
        }

        public function calculate_per_height( $cost, $cost_args, $data ) {

            $height = $cost_args[ 'height' ];

            if ( 0 >= $height ) {
                return $cost;
            }

            $round = $cost_args[ 'round' ];

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_height = $this->get_total_height( $package_items, $height, $round );

            if ( 0 >= $total_height ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * ($total_height / $height);

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        public function calculate_by_height( $cost, $cost_args, $data ) {

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_height = $this->get_total_height( $package_items, 0, 'no' );
            
            if ( 0 >= $total_height ) {
                return $cost;
            }

            $calc_cost = $total_height * $cost_args[ 'cost' ];

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        private function get_total_height( $package_items, $rule_height, $round ) {

            $total_height = 0;


            foreach ( $package_items as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'dimensions' ][ 'height' ] ) ) {
                    continue;
                }

                $height = $package_item[ 'data' ][ 'dimensions' ][ 'height' ];

                if ( !is_numeric( $height ) ) {
                    continue;
                }

                $total_height += ($height * $package_item[ 'quantity' ]);
            }

            if ( 0 >= $total_height ) {
                return $total_height;
            }

            if ( 'round_up' == $round ) {
                return ceil( $total_height / $rule_height ) * $rule_height;
            }

            if ( 'round_down' == $round ) {
                return floor( $total_height / $rule_height ) * $rule_height;
            }

            if ( 'round_up_down' == $round ) {
                return round( $total_height / $rule_height ) * $rule_height;
            }

            return $total_height;
        }

        private function get_package_items( $data, $cost_args ) {

            $product_args = array();

            if ( isset( $cost_args[ 'products_args' ] ) && is_array( $cost_args[ 'products_args' ] ) ) {
                $product_args = $cost_args[ 'products_args' ];
            }


            return WTARS_Shipped_Product_Filter_Types::get_package_items( $data, $product_args, true );
        }

    }

    new WTARS_Shipped_Cost_Type_Width();
}