<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Cost_Type_Length' ) ) {

    class WTARS_Shipped_Cost_Type_Length {

        public function __construct() {

            add_filter( 'wtars_shipped/calculate-per_length-cost', array( $this, 'calculate_per_length' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-by_length-cost', array( $this, 'calculate_by_length' ), 1, 3 );
        }

        public function calculate_per_length( $cost, $cost_args, $data ) {

            $length = $cost_args[ 'lengths' ];

            if ( 0 >= $length ) {
                return $cost;
            }

            $round = $cost_args[ 'round' ];

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_length = $this->get_total_length( $package_items, $length, $round );

            if ( 0 >= $total_length ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * ($total_length / $length);

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        public function calculate_by_length( $cost, $cost_args, $data ) {

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_length = $this->get_total_length( $package_items, 0, 'no' );
            
            if ( 0 >= $total_length ) {
                return $cost;
            }

            $calc_cost = $total_length * $cost_args[ 'cost' ];

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        private function get_total_length( $package_items, $rule_length, $round ) {

            $total_length = 0;


            foreach ( $package_items as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'dimensions' ][ 'length' ] ) ) {
                    continue;
                }

                $length = $package_item[ 'data' ][ 'dimensions' ][ 'length' ];

                if ( !is_numeric( $length ) ) {
                    continue;
                }

                $total_length += ($length * $package_item[ 'quantity' ]);
            }

            if ( 0 >= $total_length ) {
                return $total_length;
            }

            if ( 'round_up' == $round ) {
                return ceil( $total_length / $rule_length ) * $rule_length;
            }

            if ( 'round_down' == $round ) {
                return floor( $total_length / $rule_length ) * $rule_length;
            }

            if ( 'round_up_down' == $round ) {
                return round( $total_length / $rule_length ) * $rule_length;
            }

            return $total_length;
        }

        private function get_package_items( $data, $cost_args ) {

            $product_args = array();

            if ( isset( $cost_args[ 'products_args' ] ) && is_array( $cost_args[ 'products_args' ] ) ) {
                $product_args = $cost_args[ 'products_args' ];
            }


            return WTARS_Shipped_Product_Filter_Types::get_package_items( $data, $product_args, true );
        }

    }

    new WTARS_Shipped_Cost_Type_Length();
}