<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Cost_Type_Order_Items' ) ) {

    class WTARS_Shipped_Cost_Type_Order_Items {

        public function __construct() {

            add_filter( 'wtars_shipped/calculate-per_line-cost', array( $this, 'calculate_per_line' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-per_quantity-cost', array( $this, 'calculate_per_quantity' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-per_product-cost', array( $this, 'calculate_per_product' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-per_variation-cost', array( $this, 'calculate_per_variation' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-per_cost_item-cost', array( $this, 'calculate_per_cost_item' ), 1, 3 );
        }

        public function calculate_per_line( $cost, $cost_args, $data ) {

            $package_items = $this->get_package_items( $data, $cost_args );

            $items_count = count( $package_items );

            if ( !$items_count ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * $items_count;

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args, $package_items );
        }

        public function calculate_per_quantity( $cost, $cost_args, $data ) {

            $qty = $cost_args[ 'quantity' ];

            if ( 0 >= $qty ) {
                return $cost;
            }

            $round = 'no';

            if ( isset( $cost_args[ 'round' ] ) ) {

                $round = $cost_args[ 'round' ];
            }

            $package_items = $this->get_package_items( $data, $cost_args );

            $range_args = $this->get_range_args( $cost_args );

            $total_qty = $this->get_total_qty( $package_items, $qty, $round, $range_args );

            if ( 0 >= $total_qty ) {
                return $cost;
            }

            $calc_cost = ($total_qty / $qty) * $cost_args[ 'cost' ];

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args, $package_items );
        }

        public function calculate_per_product( $cost, $cost_args, $data ) {

            $package_items = $this->get_package_items( $data, $cost_args );

            $item_ids_count = count( $this->get_item_ids( $package_items ) );

            if ( !$item_ids_count ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * $item_ids_count;

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args, $package_items );
        }

        public function calculate_per_variation( $cost, $cost_args, $data ) {

            $package_items = $this->get_package_items( $data, $cost_args );

            $item_ids_count = count( $this->get_item_variation_ids( $package_items ) );

            if ( !$item_ids_count ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * $item_ids_count;

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args, $package_items );
        }

        public function calculate_per_cost_item( $cost, $cost_args, $data ) {

            if ( !isset( $cost_args[ 'item_based_on' ] ) ) {
                return $cost;
            }

            $item_based_on = $cost_args[ 'item_based_on' ];

            $package_items = $this->get_package_items( $data, $cost_args );

            $subtotal = $this->get_item_subtotals( $package_items, $item_based_on );

            if ( 0 >= $subtotal ) {
                return $cost;
            }

            $calc_cost = ($cost_args[ 'cost' ] / 100) * $subtotal;

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args, $package_items );
        }

        private function get_total_qty( $package_items, $rule_qty, $round, $range_args ) {

            $qty = 0;

            foreach ( $package_items as $package_item ) {

                $qty += $package_item[ 'quantity' ];
            }

            $qty = WTARS_Shipped_Util::get_value_by_range( $qty, $range_args );

            if ( 'round_up' == $round ) {
                
                return ceil( $qty / $rule_qty ) * $rule_qty;
            }

            if ( 'round_down' == $round ) {
                
                return floor( $qty / $rule_qty ) * $rule_qty;
            }

            if ( 'round_up_down' == $round ) {
               
                return round( $qty / $rule_qty ) * $rule_qty;
            }

            return $qty;
        }

        private function get_item_ids( $package_items ) {

            $item_ids = array();

            foreach ( $package_items as $package_item ) {

                if ( in_array( $package_item[ 'product_id' ], $item_ids ) ) {
                    continue;
                }

                $item_ids[] = $package_item[ 'product_id' ];
            }
            return $item_ids;
        }

        private function get_item_variation_ids( $package_items ) {

            $variation_ids = array();

            foreach ( $package_items as $package_item ) {

                if ( 0 >= $package_item[ 'variation_id' ] ) {
                    continue;
                }

                if ( in_array( $package_item[ 'variation_id' ], $variation_ids ) ) {
                    continue;
                }

                $variation_ids[] = $package_item[ 'variation_id' ];
            }

            return $variation_ids;
        }

        private function get_item_subtotals( $package_items, $item_based_on ) {

            $subtotal = 0;

            foreach ( $package_items as $package_item ) {

                switch ( $item_based_on ) {
                    case 'excl_tax':

                        $subtotal += $package_item[ 'line_subtotal' ];
                        break;

                    case 'incl_tax_after':

                        $subtotal += $package_item[ 'line_total' ];
                        $subtotal += $package_item[ 'line_tax' ];
                        break;

                    case 'excl_tax_after':

                        $subtotal += $package_item[ 'line_total' ];
                        break;

                    default:

                        $subtotal += $package_item[ 'line_subtotal' ];
                        $subtotal += $package_item[ 'line_subtotal_tax' ];
                        break;
                }
            }
            return $subtotal;
        }

        private function get_package_items( $data, $cost_args ) {

            $product_args = array();

            if ( isset( $cost_args[ 'products_args' ] ) && is_array( $cost_args[ 'products_args' ] ) ) {
                $product_args = $cost_args[ 'products_args' ];
            }


            return WTARS_Shipped_Product_Filter_Types::get_package_items( $data, $product_args, true );
        }

        private function get_range_args( $cost_args ) {

            if ( !isset( $cost_args[ 'quantity_range' ] ) ) {

                return false;
            }

            if ( '' == $cost_args[ 'quantity_range' ] || 'no' == $cost_args[ 'quantity_range' ] ) {

                return false;
            }

            $range_args = array(
                'value_from' => 0,
                'value_to' => 0,
            );

            if ( isset( $cost_args[ 'quantity_from' ] ) ) {

                $range_args[ 'value_from' ] = ($this->get_range_value( $cost_args[ 'quantity_from' ] ) - 1);
            }

            if ( $range_args[ 'value_from' ] < 0 ) {

                $range_args[ 'value_from' ] = 0;
            }


            if ( isset( $cost_args[ 'quantity_to' ] ) ) {

                $range_args[ 'value_to' ] = $this->get_range_value( $cost_args[ 'quantity_to' ] );
            }

            //from value should be less than to value
            if ( $range_args[ 'value_to' ] < $range_args[ 'value_from' ] && $range_args[ 'value_to' ] > 0 ) {

                $range_args[ 'value_to' ] = 0;
            }

            return $range_args;
        }

        private function get_range_value( $range_value ) {

            if ( !is_numeric( $range_value ) ) {

                return 0;
            }

            return floatval( $range_value );
        }

    }

    new WTARS_Shipped_Cost_Type_Order_Items();
}