<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Premium_Cost_Type_Order' ) ) {

    class WTARS_Shipped_Premium_Cost_Type_Order {

        public function __construct() {

            add_filter( 'wtars_shipped/calculate-per_shipping_classes-cost', array( $this, 'calculate_per_shipping_classes' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-per_categories-cost', array( $this, 'calculate_per_categories' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-per_tags-cost', array( $this, 'calculate_per_tags' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-per_cost-cost', array( $this, 'calculate_per_cost' ), 1, 3 );
        }

        public function calculate_per_shipping_classes( $cost, $cost_args, $data ) {

            if ( !isset( $cost_args[ 'shipping_classes_args' ] ) ) {
                return $cost;
            }

            $shipping_classes_args = $cost_args[ 'shipping_classes_args' ];

            $package_items = $this->get_items_by_shipping_classes( $data, $shipping_classes_args );

            $shipping_classes_count = $this->get_shipping_classes_count( $package_items );

            $calc_cost = $cost_args[ 'cost' ] * $shipping_classes_count;

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args, $package_items );
        }

        public function calculate_per_categories( $cost, $cost_args, $data ) {

            if ( !isset( $cost_args[ 'product_categories_args' ] ) ) {
                return $cost;
            }

            $product_categories_args = $cost_args[ 'product_categories_args' ];

            $package_items = $this->get_items_by_product_categories( $data, $product_categories_args );

            $product_categories_count = $this->get_product_categories_count( $package_items, $product_categories_args );

            $calc_cost = $cost_args[ 'cost' ] * $product_categories_count;

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args, $package_items );
        }

        public function calculate_per_tags( $cost, $cost_args, $data ) {

            if ( !isset( $cost_args[ 'product_tags_args' ] ) ) {
                return $cost;
            }

            $product_tags_args = $cost_args[ 'product_tags_args' ];

            $package_items = $this->get_items_by_product_tags( $data, $product_tags_args );

            $product_tags_count = $this->get_product_tags_count( $package_items, $product_tags_args );


            $calc_cost = $cost_args[ 'cost' ] * $product_tags_count;

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args, $package_items );
        }

        public function calculate_per_cost( $cost, $cost_args, $data ) {

            $args = array(
                'module' => $cost_args[ 'module' ],
                'option_id' => $cost_args[ 'based_on' ],
                'instance_id' => $cost_args[ 'instance_id' ]
            );

            $totals = WTARS_Shipped_Total_Types::get_totals( $args, $data );

            $calc_cost = ($cost_args[ 'cost' ] / 100) * $totals;

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost );
        }

        private function get_shipping_classes_count( $package_items ) {

            $shipping_classes = array();

            foreach ( $package_items as $package_item ) {

                $item_shipping_class_id = $package_item[ 'data' ][ 'shipping_class_id' ];

                if ( in_array( $item_shipping_class_id, $shipping_classes ) ) {
                    continue;
                }

                if ( 0 >= $item_shipping_class_id ) {
                    continue;
                }

                $shipping_classes[] = $item_shipping_class_id;
            }

            return count( $shipping_classes );
        }

        private function get_product_categories_count( $package_items, $product_categories_args ) {

            $compare = 'in_list';
            if ( isset( $product_categories_args[ 'compare' ] ) ) {
                $compare = $product_categories_args[ 'compare' ];
            }

            $rule_categories = array();

            if ( isset( $product_categories_args[ 'product_categories' ] ) ) {
                $rule_categories = $product_categories_args[ 'product_categories' ];
            }

            $rule_product_category_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $rule_categories, 'product_cat' );



            $product_categories = array();

            foreach ( $package_items as $package_item ) {

                $item_category_ids = $package_item[ 'data' ][ 'category_ids' ];

                $product_categories = $this->merge_product_terms( $product_categories, $item_category_ids, $rule_product_category_ids, $compare );
            }

            return count( $product_categories );
        }

        private function get_product_tags_count( $package_items, $product_tags_args ) {

            $compare = 'in_list';
            if ( isset( $product_tags_args[ 'compare' ] ) ) {
                $compare = $product_tags_args[ 'compare' ];
            }

            $rule_tags = array();

            if ( isset( $product_tags_args[ 'product_tags' ] ) ) {
                $rule_tags = $product_tags_args[ 'product_tags' ];
            }

            $rule_product_tags_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $rule_tags, 'product_tag' );


            $product_tags = array();

            foreach ( $package_items as $package_item ) {

                $item_tag_ids = $package_item[ 'data' ][ 'tag_ids' ];

                $product_tags = $this->merge_product_terms( $product_tags, $item_tag_ids, $rule_product_tags_ids, $compare );
            }

            return count( $product_tags );
        }

        private function get_items_by_shipping_classes( $data, $shipping_classes_args ) {

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return array();
            }

            $package_items = WTARS_Shipped_Product_Filter_Types::get_package_items( $data, array(), true );

            if ( !isset( $shipping_classes_args[ 'shipping_classes' ] ) || !is_array( $shipping_classes_args[ 'shipping_classes' ] ) ) {
                return $package_items;
            }

            $shipping_classes = $shipping_classes_args[ 'shipping_classes' ];

            $shipping_class_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $shipping_classes, 'product_shipping_class' );

            $compare = 'in_list';
            if ( isset( $shipping_classes_args[ 'compare' ] ) ) {
                $compare = $shipping_classes_args[ 'compare' ];
            }

            $items = array();

            foreach ( $package_items as $key => $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'shipping_class_id' ] ) ) {
                    continue;
                }

                $item_shipping_class_id = $package_item[ 'data' ][ 'shipping_class_id' ];

                if ( 0 >= $item_shipping_class_id ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_value_list( $item_shipping_class_id, $shipping_class_ids, $compare ) != true ) {
                    continue;
                }

                $items[ $key ] = $package_item;
            }

            return $items;
        }

        private function get_items_by_product_categories( $data, $product_categories_args ) {

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return array();
            }

            $package_items = WTARS_Shipped_Product_Filter_Types::get_package_items( $data, array(), true );


            if ( !isset( $product_categories_args[ 'product_categories' ] ) || !is_array( $product_categories_args[ 'product_categories' ] ) ) {
                return $package_items;
            }


            $product_categories = $product_categories_args[ 'product_categories' ];

            $product_category_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $product_categories, 'product_cat' );

            $compare = 'in_list';
            if ( isset( $product_categories_args[ 'compare' ] ) ) {
                $compare = $product_categories_args[ 'compare' ];
            }

            $items = array();

            foreach ( $package_items as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'category_ids' ] ) ) {
                    continue;
                }

                $item_category_ids = $package_item[ 'data' ][ 'category_ids' ];

                if ( !count( $item_category_ids ) ) {
                    continue;
                }


                if ( WTARS_Shipped_Validation_Util::validate_list_list( $item_category_ids, $product_category_ids, $compare ) != true ) {
                    continue;
                }

                $items[] = $package_item;
            }

            return $items;
        }

        private function get_items_by_product_tags( $data, $product_tags_args ) {

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return array();
            }

            $package_items = WTARS_Shipped_Product_Filter_Types::get_package_items( $data, array(), true );


            if ( !isset( $product_tags_args[ 'product_tags' ] ) || !is_array( $product_tags_args[ 'product_tags' ] ) ) {
                return $package_items;
            }


            $product_tags = $product_tags_args[ 'product_tags' ];

            $product_tag_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $product_tags, 'product_tag' );

            $compare = 'in_list';
            if ( isset( $product_tags_args[ 'compare' ] ) ) {
                $compare = $product_tags_args[ 'compare' ];
            }

            $items = array();

            foreach ( $package_items as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'tag_ids' ] ) ) {
                    continue;
                }

                $item_tag_ids = $package_item[ 'data' ][ 'tag_ids' ];

                if ( !count( $item_tag_ids ) ) {
                    continue;
                }


                if ( WTARS_Shipped_Validation_Util::validate_list_list( $item_tag_ids, $product_tag_ids, $compare ) != true ) {
                    continue;
                }

                $items[] = $package_item;
            }

            return $items;
        }

        private function merge_product_terms( $product_terms, $item_term_ids, $rule_product_term_ids, $rule_compare ) {

            foreach ( $item_term_ids as $item_term_id ) {

                if ( in_array( $item_term_id, $product_terms ) ) {
                    continue;
                }

                if ( !count( $rule_product_term_ids ) ) {
                    $product_terms[] = $item_term_id;
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_value_list( $item_term_id, $rule_product_term_ids, $rule_compare ) != true ) {
                    continue;
                }

                $product_terms[] = $item_term_id;
            }

            return $product_terms;
        }

    }

    new WTARS_Shipped_Premium_Cost_Type_Order();
}