<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Cost_Type_Surface_Area' ) ) {

    class WTARS_Shipped_Cost_Type_Surface_Area {

        public function __construct() {

            add_filter( 'wtars_shipped/calculate-per_surface_area-cost', array( $this, 'calculate_per_surface_area' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-by_surface_area-cost', array( $this, 'calculate_by_surface_area' ), 1, 3 );
        }

        public function calculate_per_surface_area( $cost, $cost_args, $data ) {

            $surface_area = $cost_args[ 'surface_area' ];

            if ( 0 >= $surface_area ) {
                return $cost;
            }

            $round = $cost_args[ 'round' ];

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_surface_area = $this->get_total_surface_area( $package_items, $surface_area, $round );

            if ( 0 >= $total_surface_area ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * ($total_surface_area / $surface_area);

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }
        
        public function calculate_by_surface_area( $cost, $cost_args, $data ) {

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_surface_area = $this->get_total_surface_area( $package_items, 0, 'no' );
            
            if ( 0 >= $total_surface_area ) {
                return $cost;
            }

            $calc_cost = $total_surface_area * $cost_args[ 'cost' ];

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }
        
        private function get_total_surface_area( $package_items, $rule_area, $round ) {

            $total_area = 0;


            foreach ( $package_items as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'dimensions' ][ 'length' ] ) ) {
                    continue;
                }

                if ( !isset( $package_item[ 'data' ][ 'dimensions' ][ 'width' ] ) ) {
                    continue;
                }

                $length = $package_item[ 'data' ][ 'dimensions' ][ 'length' ];
                $width = $package_item[ 'data' ][ 'dimensions' ][ 'width' ];

                if ( !is_numeric( $length ) ) {
                    continue;
                }

                if ( !is_numeric( $width ) ) {
                    continue;
                }

                $area = $length * $width;



                $total_area += ($area * $package_item[ 'quantity' ]);
            }

            if ( 0 >= $total_area ) {
                return $total_area;
            }

            if ( 'round_up' == $round ) {
                return ceil( $total_area / $rule_area ) * $rule_area;
            }

            if ( 'round_down' == $round ) {
                return floor( $total_area / $rule_area ) * $rule_area;
            }

            if ( 'round_up_down' == $round ) {
                return round( $total_area / $rule_area ) * $rule_area;
            }

            return $total_area;
        }

        private function get_package_items( $data, $cost_args ) {

            $product_args = array();

            if ( isset( $cost_args[ 'products_args' ] ) && is_array( $cost_args[ 'products_args' ] ) ) {
                $product_args = $cost_args[ 'products_args' ];
            }


            return WTARS_Shipped_Product_Filter_Types::get_package_items( $data, $product_args, true );
        }

    }

    new WTARS_Shipped_Cost_Type_Surface_Area();
}