<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Cost_Type_Volume' ) ) {

    class WTARS_Shipped_Cost_Type_Volume {

        public function __construct() {

            add_filter( 'wtars_shipped/calculate-per_volume-cost', array( $this, 'calculate_per_volume' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-by_volume-cost', array( $this, 'calculate_by_volume' ), 1, 3 );
        }

        public function calculate_per_volume( $cost, $cost_args, $data ) {
            $volume = $cost_args[ 'volume' ];

            if ( 0 >= $volume ) {
                return $cost;
            }

            $round = $cost_args[ 'round' ];

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_volume = $this->get_total_volume( $package_items, $volume, $round );

            if ( 0 >= $total_volume ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * ($total_volume / $volume);

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        public function calculate_by_volume( $cost, $cost_args, $data ) {
            
            $package_items = $this->get_package_items( $data, $cost_args );

            $total_volume = $this->get_total_volume( $package_items, 0, 'no' );
            
            if ( 0 >= $total_volume ) {
                return $cost;
            }

            $calc_cost = $total_volume * $cost_args[ 'cost' ];

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        private function get_total_volume( $package_items, $rule_volume, $round ) {

            $total_volume = 0;

            foreach ( $package_items as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'dimensions' ][ 'length' ] ) ) {
                    continue;
                }

                if ( !isset( $package_item[ 'data' ][ 'dimensions' ][ 'width' ] ) ) {
                    continue;
                }

                if ( !isset( $package_item[ 'data' ][ 'dimensions' ][ 'height' ] ) ) {
                    continue;
                }

                $length = $package_item[ 'data' ][ 'dimensions' ][ 'length' ];
                $width = $package_item[ 'data' ][ 'dimensions' ][ 'width' ];
                $height = $package_item[ 'data' ][ 'dimensions' ][ 'height' ];

                if ( !is_numeric( $length ) ) {
                    continue;
                }

                if ( !is_numeric( $width ) ) {
                    continue;
                }

                if ( !is_numeric( $height ) ) {
                    continue;
                }

                $volume = ($length * $width) * $height;


                $total_volume += ($volume * $package_item[ 'quantity' ]);
            }

            if ( 0 >= $total_volume ) {
                return $total_volume;
            }

            if ( 'round_up' == $round ) {
                return ceil( $total_volume / $rule_volume ) * $rule_volume;
            }

            if ( 'round_down' == $round ) {
                return floor( $total_volume / $rule_volume ) * $rule_volume;
            }

            if ( 'round_up_down' == $round ) {
                return round( $total_volume / $rule_volume ) * $rule_volume;
            }

            return $total_volume;
        }

        private function get_package_items( $data, $cost_args ) {

            $product_args = array();

            if ( isset( $cost_args[ 'products_args' ] ) && is_array( $cost_args[ 'products_args' ] ) ) {
                $product_args = $cost_args[ 'products_args' ];
            }


            return WTARS_Shipped_Product_Filter_Types::get_package_items( $data, $product_args, true );
        }

    }

    new WTARS_Shipped_Cost_Type_Volume();
}