<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Cost_Type_Weight' ) ) {

    class WTARS_Shipped_Cost_Type_Weight {

        public function __construct() {

            add_filter( 'wtars_shipped/calculate-per_weight-cost', array( $this, 'calculate_per_weight' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-by_weight-cost', array( $this, 'calculate_by_weight' ), 1, 3 );
        }

        public function calculate_per_weight( $cost, $cost_args, $data ) {

            $weight = $cost_args[ 'weight' ];

            if ( 0 >= $weight ) {
                return $cost;
            }

            $round = $cost_args[ 'round' ];

            $weight_args = array(
                'instance_id' => $cost_args[ 'instance_id' ],
                'option_id' => $cost_args[ 'weight_based_on' ],
                'module' => $cost_args[ 'module' ],
                'sub_module' => $cost_args[ 'sub_module' ],
            );

            $package_items = $this->get_package_items( $data, $cost_args );

            $range_args = $this->get_range_args( $cost_args );

            $total_weight = $this->get_total_weight( $package_items, $weight, $round, $weight_args, $range_args );

            if ( 0 >= $total_weight ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * ($total_weight / $weight);

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        public function calculate_by_weight( $cost, $cost_args, $data ) {

            $weight_args = array(
                'instance_id' => $cost_args[ 'instance_id' ],
                'option_id' => $cost_args[ 'weight_based_on' ],
            );

            $package_items = $this->get_package_items( $data, $cost_args );

            $range_args = $this->get_range_args( $cost_args );

            $total_weight = $this->get_total_weight( $package_items, 0, 'no', $weight_args, $range_args );

            if ( 0 >= $total_weight ) {
                return $cost;
            }

            $calc_cost = $total_weight * $cost_args[ 'cost' ];

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        private function get_total_weight( $package_items, $rule_weight, $round, $weight_args, $range_args ) {

            $weight_calc = new WTARS_Shipped_Weight_Calculator();

            $total_weight = WTARS_Shipped_Util::get_value_by_range( $weight_calc->get_total_weight( $package_items, $weight_args ), $range_args );
            
            
            if ( 'round_up' == $round ) {
                return ceil( $total_weight / $rule_weight ) * $rule_weight;
            }

            if ( 'round_down' == $round ) {
                return floor( $total_weight / $rule_weight ) * $rule_weight;
            }

            if ( 'round_up_down' == $round ) {
                return round( $total_weight / $rule_weight ) * $rule_weight;
            }

            return $total_weight;
        }

        private function get_package_items( $data, $cost_args ) {

            $product_args = array();

            if ( isset( $cost_args[ 'products_args' ] ) && is_array( $cost_args[ 'products_args' ] ) ) {
                $product_args = $cost_args[ 'products_args' ];
            }


            return WTARS_Shipped_Product_Filter_Types::get_package_items( $data, $product_args, true );
        }

        private function get_range_args( $cost_args ) {

            if ( !isset( $cost_args[ 'weight_range' ] ) ) {

                return false;
            }

            if ( '' == $cost_args[ 'weight_range' ] || 'no' == $cost_args[ 'weight_range' ] ) {

                return false;
            }

            $range_args = array(
                'value_from' => 0,
                'value_to' => 0,
            );

            if ( isset( $cost_args[ 'weight_from' ] ) ) {

                $range_args[ 'value_from' ] = $this->get_range_value( $cost_args[ 'weight_from' ] );
            }

            if ( isset( $cost_args[ 'weight_to' ] ) ) {

                $range_args[ 'value_to' ] = $this->get_range_value( $cost_args[ 'weight_to' ] );
            }

            //from value should be less than to value
            if ( $range_args[ 'value_to' ] < $range_args[ 'value_from' ] && $range_args[ 'value_to' ] > 0 ) {

                $range_args[ 'value_to' ] = 0;
            }

            return $range_args;
        }

        private function get_range_value( $range_value ) {

            if ( !is_numeric( $range_value ) ) {

                return 0;
            }

            return floatval( $range_value );
        }

    }

    new WTARS_Shipped_Cost_Type_Weight();
}