<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Cost_Type_Width' ) ) {

    class WTARS_Shipped_Cost_Type_Width {

        public function __construct() {

            add_filter( 'wtars_shipped/calculate-per_width-cost', array( $this, 'calculate_per_width' ), 1, 3 );
            add_filter( 'wtars_shipped/calculate-by_width-cost', array( $this, 'calculate_by_width' ), 1, 3 );
        }

        public function calculate_per_width( $cost, $cost_args, $data ) {

            $width = $cost_args[ 'width' ];

            if ( 0 >= $width ) {
                return $cost;
            }

            $round = $cost_args[ 'round' ];

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_width = $this->get_total_width( $package_items, $width, $round );

            if ( 0 >= $total_width ) {
                return $cost;
            }

            $calc_cost = $cost_args[ 'cost' ] * ($total_width / $width);

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        public function calculate_by_width( $cost, $cost_args, $data ) {

            $package_items = $this->get_package_items( $data, $cost_args );

            $total_width = $this->get_total_width( $package_items, 0, 'no' );
            
            if ( 0 >= $total_width ) {
                return $cost;
            }

            $calc_cost = $total_width * $cost_args[ 'cost' ];

            return WTARS_Shipped_Cost_Types::prepare_cost( $cost, $calc_cost, $cost_args );
        }

        private function get_total_width( $package_items, $rule_width, $round ) {

            $total_width = 0;


            foreach ( $package_items as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'dimensions' ][ 'width' ] ) ) {
                    continue;
                }

                $width = $package_item[ 'data' ][ 'dimensions' ][ 'width' ];

                if ( !is_numeric( $width ) ) {
                    continue;
                }

                $total_width += ($width * $package_item[ 'quantity' ]);
            }

            if ( 0 >= $total_width ) {
                return $total_width;
            }

            if ( 'round_up' == $round ) {
                return ceil( $total_width / $rule_width ) * $rule_width;
            }

            if ( 'round_down' == $round ) {
                return floor( $total_width / $rule_width ) * $rule_width;
            }

            if ( 'round_up_down' == $round ) {
                return round( $total_width / $rule_width ) * $rule_width;
            }

            return $total_width;
        }

        private function get_package_items( $data, $cost_args ) {

            $product_args = array();

            if ( isset( $cost_args[ 'products_args' ] ) && is_array( $cost_args[ 'products_args' ] ) ) {
                $product_args = $cost_args[ 'products_args' ];
            }


            return WTARS_Shipped_Product_Filter_Types::get_package_items( $data, $product_args, true );
        }

    }

    new WTARS_Shipped_Cost_Type_Width();
}