<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Cost_Types' ) ) {
    WTARS_Shipped_Inc::recursive_require( dirname( __FILE__ ), array( 'cost-types.php' ) );

    class WTARS_Shipped_Premium_Cost_Types {

        private static $instance = null;

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function merge_costs( $costs ) {

            $calc_cost = array(
                'cost' => 0,
                'tax_total' => 0,
                'taxes' => array(),
            );

            foreach ( $costs as $cost ) {

                if ( 'set' == $cost[ 'add_type' ] ) {

                    $calc_cost[ 'cost' ] = $cost[ 'cost' ];

                    $calc_cost[ 'tax_total' ] = $cost[ 'tax_total' ];

                    $calc_cost[ 'taxes' ] = $cost[ 'taxes' ];
                } else if ( 'sub' == $cost[ 'add_type' ] ) {

                    $calc_cost[ 'cost' ] -= $cost[ 'cost' ];

                    $taxes = self::get_instance()->sub_taxes( $calc_cost[ 'tax_total' ], $cost[ 'tax_total' ], $calc_cost[ 'taxes' ] );

                    $calc_cost[ 'tax_total' ] -= $cost[ 'tax_total' ];

                    $calc_cost[ 'taxes' ] = $taxes;
                } else {

                    $calc_cost[ 'cost' ] += $cost[ 'cost' ];

                    $calc_cost[ 'tax_total' ] += $cost[ 'tax_total' ];

                    $calc_cost[ 'taxes' ] = self::get_instance()->add_taxes( $calc_cost[ 'taxes' ], $cost[ 'taxes' ] );
                }
            }


            if ( $calc_cost[ 'cost' ] <= 0 ) {
                $calc_cost[ 'cost' ] = 0;
                $calc_cost[ 'taxes' ] = array();
            }

            if ( $calc_cost[ 'tax_total' ] <= 0 ) {
                $calc_cost[ 'tax_total' ] = 0;
                $calc_cost[ 'taxes' ] = array();
            }

            if ( !isset( $calc_cost[ 'taxes' ] ) ) {
                $calc_cost[ 'taxes' ] = array();
            }

            return $calc_cost;
        }

        private function add_taxes( $prev_cost_taxes, $new_cost_taxes ) {

            foreach ( $new_cost_taxes as $key => $tax ) {
                if ( isset( $prev_cost_taxes[ $key ] ) ) {
                    $prev_cost_taxes[ $key ] += $tax;
                } else {
                    $prev_cost_taxes[ $key ] = $tax;
                }
            }
            return $prev_cost_taxes;
        }

        private function sub_taxes( $prev_cost_tax, $new_cost_tax, $prev_taxes ) {
            $taxes = array();

            $cost_tax = $prev_cost_tax - $new_cost_tax;

            foreach ( $prev_taxes as $key => $tax ) {
                $tax_cost = (($tax / $prev_cost_tax) * $cost_tax);
                if ( isset( $taxes[ $key ] ) ) {
                    $taxes[ $key ] += $tax_cost;
                } else {
                    $taxes[ $key ] = $tax_cost;
                }
            }

            return $taxes;
        }

    }

}