<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Premium_Cart_Fees_Engine' ) ) {

    class WTARS_Shipped_Premium_Cart_Fees_Engine {

        private static $instance = null;

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function calculate_costs( $fee_option, $instance_id, $data ) {

            $this_obj = self::get_instance();

            $max_args = $this_obj->get_max_args( $fee_option, $instance_id );

            $cost = $this_obj->calculate_base_costs( $fee_option, $instance_id, $data );

            if ( $this_obj->get_reached_limit( $cost, $max_args, $data ) ) {

                return $this_obj->get_cost_max( $cost, $max_args, $data );
            }

            $cost = $this_obj->calculate_extra_costs( $cost, $fee_option, $max_args, $instance_id, $data );

            return $this_obj->get_cost_max( $cost, $max_args, $data );
        }

        public static function can_apply_fee( $fee_option_head, $data ) {

            $instance_id = $fee_option_head[ 'instance_id' ];

            if ( 'if_others' == $fee_option_head[ 'apply_mode' ] && !isset( $data[ 'fees' ][ $instance_id ] ) ) {
                return false;
            }

            if ( 'if_no_others' == $fee_option_head[ 'apply_mode' ] && isset( $data[ 'fees' ][ $instance_id ] ) ) {
                return false;
            }

            if ( 'first' == $fee_option_head[ 'settings' ][ 'mode' ] && isset( $data[ 'fees' ][ $instance_id ] ) ) {
                return false;
            }

            return true;
        }

        public static function add_fee( $data, $fee, $fee_option_head ) {

            $instance_id = $fee_option_head[ 'instance_id' ];

            $s_mode = $fee_option_head[ 'settings' ][ 'mode' ];

            // add last valid fees data or only fee if valid
            if ( 'last' == $s_mode || 'only_this' == $fee_option_head[ 'apply_mode' ] ) {
                $data = self::get_instance()->force_fee( $data, $fee, $instance_id, $fee_option_head );
                return $data;
            }

            // add fee data with higher cost only
            if ( 'higher' == $s_mode ) {
                if ( self::get_instance()->get_is_higher( $data, $fee, $instance_id ) ) {
                    $data = self::get_instance()->force_fee( $data, $fee, $instance_id, $fee_option_head );
                }
                return $data;
            }

            // add fee data with lower cost only
            if ( 'lower' == $s_mode ) {
                if ( self::get_instance()->get_is_lower( $data, $fee, $instance_id ) ) {
                    $data = self::get_instance()->force_fee( $data, $fee, $instance_id, $fee_option_head );
                }
                return $data;
            }

            // add fee data as usual
            $data[ 'fees' ][ $instance_id ][ $fee_option_head[ 'fee_id' ] ] = $fee;

            // allows other plugins to modify fee data once added
            if ( has_filter( 'wtars_shipped/cart-fees/added-fee' ) ) {
                if ( isset( $data[ 'fees' ][ $instance_id ][ $fee_option_head[ 'fee_id' ] ] ) ) {
                    $data[ 'fees' ][ $instance_id ][ $fee_option_head[ 'fee_id' ] ] = apply_filters( 'wtars_shipped/cart-fees/added-fee', $data[ 'fees' ][ $instance_id ][ $fee_option_head[ 'fee_id' ] ], $instance_id, $fee_option_head );
                }
            }

            return $data;
        }

        private function calculate_base_costs( $fee_option, $instance_id, $data ) {

            $costs_args = $this->get_valid_costs_args( $this->get_costs_args_from_fee_option( $fee_option, 'base-costs', $instance_id ), $data );

            $costs = WTARS_Shipped_Cost_Types::calculate_costs( array(), $costs_args, $data );

            $merge_args = $this->get_merge_args( $fee_option, 'base-costs', $instance_id );

            $cost = WTARS_Shipped_Cost_Types::merge_costs( $costs, $merge_args );

            if ( has_filter( 'wtars_shipped/cart-fees/calculated-base-cost' ) ) {
                $cost = apply_filters( 'wtars_shipped/cart-fees/calculated-base-cost', $cost, $fee_option[ 'fee_id' ], $data );
            }

            return $cost;
        }

        private function calculate_extra_costs( $cost, $fee_option, $max_args, $instance_id, $data ) {

            $costs_args = $this->get_costs_args_from_fee_option( $fee_option, 'extra-costs', $instance_id );

            if ( !count( $costs_args ) ) {
                return $cost;
            }

            $merge_args = $this->get_merge_args( $fee_option, 'extra-costs', $instance_id );

            $extra_cost = array(
                'cost' => 0,
                'tax_total' => 0,
                'taxes' => array(),
            );

            foreach ( $costs_args as $cost_args ) {

                $costs = array();

                $grouped_data = $this->get_grouped_data( $data, $cost_args );

                //remove product args (products are already filtered)
                if ( isset( $cost_args[ 'products_args' ] ) ) {
                    unset( $cost_args[ 'products_args' ] );
                }

                // remove conditions
                if ( isset( $cost_args[ 'conditions' ] ) ) {
                    unset( $cost_args[ 'conditions' ] );
                }

                unset( $cost_args[ 'set_conditions' ] );


                $costs = $this->calculate_group_costs( $costs, $cost_args, $grouped_data );

                $new_cost = WTARS_Shipped_Cost_Types::merge_costs( $costs, $merge_args );

                $extra_cost = $this->combine_costs( $extra_cost, $new_cost );

                if ( $this->get_reached_limit( $this->combine_costs( $cost, $extra_cost ), $max_args, $data ) ) {
                    break;
                }
            }

            // allows other plugins to modify grouped package costs
            if ( has_filter( 'wtars_shipped/cart-fees/calculated-extra-cost' ) ) {
                $extra_cost = apply_filters( 'wtars_shipped/cart-fees/calculated-extra-cost', $extra_cost, $fee_option[ 'fee_id' ], $data );
            }

            return $this->combine_costs( $cost, $extra_cost );
        }

        private function calculate_group_costs( $costs, $cost_args, $grouped_data ) {

            foreach ( $grouped_data as $data ) {

                if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                    continue; //skip empty package items
                }

                if ( !count( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                    continue; //skip empty package items
                }

                $costs = WTARS_Shipped_Cost_Types::calculate_costs( $costs, array( $cost_args ), $data );
            }
            return $costs;
        }

        private function get_grouped_data( $data, $cost_args ) {

            $group_by = $cost_args[ 'group_by' ];

            $product_filters = isset( $cost_args[ 'products_args' ] ) ? $cost_args[ 'products_args' ] : array();

            $grd_data = WTARS_Shipped_Groups::get_packages( $data, $group_by, $product_filters );

            $grouped_data = array();

            foreach ( $grd_data as $key => $grp ) {

                if ( $this->get_cost_args_is_valid( $cost_args, $grp ) ) {

                    $grouped_data[ $key ] = $grp;
                }
            }

            return $grouped_data;
        }

        private function get_merge_args( $fee_option, $sub_module, $instance_id ) {
            return $merge_args = array(
                'fee_id' => $fee_option[ 'fee_id' ],
                'instance_id' => $instance_id,
                'module' => 'cart-fees',
                'sub_module' => $sub_module,
            );
        }

        private function get_reached_limit( $cost, $max_args, $data ) {

            $cost_value = $cost[ 'cost' ];

            if ( 'yes' == $max_args[ 'inclusive_tax' ] ) {
                $cost_value = $cost[ 'cost' ] + $cost[ 'tax_total' ];
            }

            if ( $this->can_use_fee_limit( $max_args[ 'costs_limit' ] ) ) {

                $max_cost = $this->get_fee_limit( $max_args[ 'costs_limit' ], $data );

                return ($cost_value >= $max_cost);
            }

            if ( $this->can_use_global_limit( $max_args[ 'settings' ] ) ) {

                $max_cost = $this->get_global_limit( $max_args[ 'settings' ], $data );

                return ($cost_value >= $max_cost);
            }

            return false;
        }

        private function combine_costs( $prev_cost, $new_cost ) {

            if ( !isset( $prev_cost[ 'cost' ] ) ) {
                $prev_cost[ 'cost' ] = 0;
            }

            if ( !isset( $prev_cost[ 'tax_total' ] ) ) {
                $prev_cost[ 'tax_total' ] = 0;
            }

            $prev_cost[ 'cost' ] += $new_cost[ 'cost' ];

            $prev_cost[ 'tax_total' ] += $new_cost[ 'tax_total' ];

            foreach ( $new_cost[ 'taxes' ] as $key => $tax ) {

                if ( !isset( $prev_cost[ 'taxes' ][ $key ] ) ) {

                    $prev_cost[ 'taxes' ][ $key ] = 0;
                }

                $prev_cost[ 'taxes' ][ $key ] += $tax;
            }
            return $prev_cost;
        }

        private function get_costs_args_from_fee_option( $fee_option, $sub_module, $instance_id ) {

            $costs_args = array();

            $option_key = 'base_costs';

            if ( $sub_module == 'extra-costs' ) {
                $option_key = 'extra_costs';
            }

            if ( isset( $fee_option[ $option_key ] ) ) {

                $costs_args = $fee_option[ $option_key ];
            }

            $arg_keys = array_keys( $costs_args );

            $tax_type = $this->get_tax_type( $instance_id );

            foreach ( $arg_keys as $key ) {

                $costs_args[ $key ][ 'instance_id' ] = $instance_id;
                $costs_args[ $key ][ 'module' ] = 'cart-fees';
                $costs_args[ $key ][ 'sub_module' ] = $sub_module;
                $costs_args[ $key ][ 'fee_id' ] = $fee_option[ 'fee_id' ];
                $costs_args[ $key ][ 'tax_type' ] = $tax_type;
                $costs_args[ $key ][ 'inclusive_tax' ] = $fee_option[ 'inclusive_tax' ];
            }

            return $costs_args;
        }

        private function get_valid_costs_args( $costs_args, $data ) {

            $args = array();
            foreach ( $costs_args as $key => $cost_args ) {

                if ( !isset( $cost_args[ 'conditions' ] ) ) {

                    $args[ $key ] = $cost_args;
                    continue;
                }

                if ( !WTARS_Shipped_Cost_Types::can_calculate_cost( $cost_args, $data ) ) {
                    continue; //do nothing
                }

                $args[ $key ] = $cost_args;

                unset( $args[ $key ][ 'set_conditions' ] );
                unset( $args[ $key ][ 'conditions' ] );
            }

            return $args;
        }

        private function get_cost_args_is_valid( $cost_args, $data ) {

            if ( !isset( $cost_args[ 'conditions' ] ) ) {
                return true;
            }

            return WTARS_Shipped_Cost_Types::can_calculate_cost( $cost_args, $data );
        }

        private function get_cost_max( $cost, $max_args, $data ) {

            $cost_value = $cost[ 'cost' ];

            if ( 'yes' == $max_args[ 'inclusive_tax' ] ) {
                $cost_value = $cost_value + $cost[ 'tax_total' ];
            }

            // adjust cost based on max cost by fee
            if ( $this->can_use_fee_limit( $max_args[ 'costs_limit' ] ) ) {

                $max_cost = $this->get_fee_limit( $max_args[ 'costs_limit' ], $data );

                if ( $cost_value > $max_cost ) {
                    $cost = $this->get_adjusted_cost( $cost, $max_cost, $max_args[ 'inclusive_tax' ] );
                }

                return $cost;
            }

            // adjust cost based on global max cost
            if ( $this->can_use_global_limit( $max_args[ 'settings' ] ) ) {

                $max_cost = $this->get_global_limit( $max_args[ 'settings' ], $data );

                if ( $cost_value > $max_cost ) {
                    $cost = $this->get_adjusted_cost( $cost, $max_cost, $max_args[ 'inclusive_tax' ] );
                }

                return $cost;
            }

            return $cost;
        }

        private function force_fee( $data, $fee, $instance_id, $fee_option_head ) {

            if ( isset( $data[ 'fees' ][ $instance_id ] ) ) {
                unset( $data[ 'fees' ][ $instance_id ] );
            }

            $data[ 'fees' ][ $instance_id ][ $fee_option_head[ 'fee_id' ] ] = $fee;

            return $data;
        }

        private function get_adjusted_cost( $cost, $new_cost, $inclusive_tax ) {

            foreach ( $cost[ 'taxes' ] as $key => $tax ) {

                $new_tax = ($new_cost / $cost[ 'cost' ]) * $tax;

                $cost[ 'taxes' ][ $key ] = WTARS_Shipped_Util::round_num( $new_tax, wc_get_price_decimals() );
            }

            $cost[ 'cost' ] = $new_cost;
            $cost[ 'tax_total' ] = array_sum( $cost[ 'taxes' ] );

            if ( 'yes' == $inclusive_tax ) {
                $cost[ 'cost' ] = $new_cost - $cost[ 'tax_total' ];
            }

            return $cost;
        }

        private function get_fee_limit( $limit_args, $data ) {

            if ( 'no' == $limit_args[ 'limit_type' ] ) {
                return 0;
            }

            $opt_limit = $limit_args[ 'limit' ];

            if ( !is_numeric( $opt_limit ) ) {
                $opt_limit = 0;
            }

            if ( 'fixed_limit' == $limit_args[ 'limit_type' ] ) {
                return $opt_limit;
            }

            if ( 'per_limit' == $limit_args[ 'limit_type' ] ) {

                $args = array(
                    'module' => 'cart-fees',
                    'sub_module' => 'fees',
                    'instance_id' => $data[ 'wc' ][ 'instance_id' ],
                    'option_id' => $limit_args[ 'based_on' ],
                );

                return $this->get_per_limit( $opt_limit, $args, $data );
            }

            return 0;
        }

        private function get_global_limit( $settings, $data ) {

            if ( 'no' == $settings[ 'limit_type' ] ) {
                return 0;
            }

            $opt_limit = $settings[ 'limit' ];
            if ( !is_numeric( $opt_limit ) ) {
                $opt_limit = 0;
            }

            if ( 'fixed_limit' == $settings[ 'limit_type' ] ) {

                return $opt_limit;
            }

            if ( 'per_limit' == $settings[ 'limit_type' ] ) {

                $args = array(
                    'module' => 'cart-fees',
                    'sub_module' => 'fees',
                    'instance_id' => $data[ 'wc' ][ 'instance_id' ],
                    'option_id' => $settings[ 'based_on' ]
                );

                return $this->get_per_limit( $opt_limit, $args, $data );
            }

            return 0;
        }

        private function get_per_limit( $opt_limit, $args, $data ) {

            $totals = WTARS_Shipped_Total_Types::get_totals( $args, $data );

            if ( $totals > 0 ) {
                return (($opt_limit / 100) * $totals);
            }
            return 0;
        }

        private function get_is_higher( $data, $fee, $instance_id ) {

            $value = 0;

            if ( !isset( $data[ 'fees' ][ $instance_id ] ) ) {
                return true;
            }

            foreach ( $data[ 'fees' ][ $instance_id ] as $prev_fee ) {

                if ( $prev_fee[ 'cost' ] > $value ) {
                    $value = $prev_fee[ 'cost' ];
                }
            }

            return ($fee[ 'cost' ] > $value);
        }

        private function get_is_lower( $data, $fee, $instance_id ) {

            $value = 0;

            if ( !isset( $data[ 'fees' ][ $instance_id ] ) ) {
                return true;
            }

            foreach ( $data[ 'fees' ][ $instance_id ] as $prev_fee ) {

                if ( $value < $prev_fee[ 'cost' ] ) {
                    $value = $prev_fee[ 'cost' ];
                }
            }

            return ($fee[ 'cost' ] < $value);
        }

        private function can_use_fee_limit( $limit_args ) {

            if ( !isset( $limit_args[ 'limit' ] ) || !is_numeric( $limit_args[ 'limit' ] ) ) {
                return false;
            }

            if ( $limit_args[ 'limit' ] <= 0 ) {
                return false;
            }

            return ('no' != $limit_args[ 'limit_type' ]);
        }

        private function can_use_global_limit( $settings ) {

            if ( !isset( $settings[ 'limit' ] ) || !is_numeric( $settings[ 'limit' ] ) ) {
                return false;
            }

            if ( $settings[ 'limit' ] <= 0 ) {
                return false;
            }

            return ( 'no' != $settings[ 'limit_type' ] );
        }

        private function get_tax_type( $instance_id ) {

            $default = array(
                'tax_type' => 'ship_rates',
            );

            $shipping = WTARS_Shipped::get_option( 'cart_fee_settings', $instance_id, $default );

            return $shipping[ 'tax_type' ];
        }

        private function get_max_args( $fee_option, $instance_id ) {

            $max_args = array(
                'costs_limit' => $fee_option[ 'costs_limit' ],
                'settings' => $this->get_fees_settings( $instance_id ),
                'inclusive_tax' => $fee_option[ 'inclusive_tax' ],
            );

            return $max_args;
        }

        private function get_fees_settings( $instance_id ) {

            $default = array(
                'mode' => 'no',
            );

            return WTARS_Shipped::get_option( 'cart_fees_settings', $instance_id, $default );
        }

    }

}