<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Premium_Cart_Fees' ) ) {
    WTARS_Shipped_Inc::recursive_require( dirname( __FILE__ ), array( 'cart-fees.php' ) );

    class WTARS_Shipped_Premium_Cart_Fees {

        private $fees = array();

        public function process_fees( $package, $data, $instance_id ) {


            foreach ( $data[ 'fees' ][ $instance_id ] as $fee_id => $fee ) {

                if ( 'cart_fee' != $fee[ 'fee_method' ] ) {
                    continue;
                }

                $this->fees[ $fee_id ] = $fee;
                $this->fees[ $fee_id ][ 'instance_id' ] = $instance_id;
            }


            // rates cost with fees cost

            return $this->apply_rate_fees( $package, $data, $instance_id );
        }

        public function apply_cart_fees() {

            foreach ( $this->fees as $fee_id => $fee ) {

                $rate_args = array(
                    'shipping_rates' => $fee[ 'shipping_rates' ],
                    'compare' => $fee[ 'compare' ],
                    'instance_id' => $fee[ 'instance_id' ],
                );

                if ( !$this->can_apply_cart_fee( $rate_args ) ) {
                    continue;
                }

                $this->apply_cart_fee( $fee_id, $fee );
            }
        }

        public function get_taxes( $fee_taxes, $fee_id ) {

            // do not modify fee taxes
            if ( !isset( $this->fees[ $fee_id ] ) ) {
                return $fee_taxes;
            }

            $fee_taxes = array(); // return zero tax if not taxable

            if ( $this->fees[ $fee_id ][ 'tax_total' ] > 0 ) {

                $instance_id = $this->fees[ $fee_id ][ 'instance_id' ];

                $d_taxes = apply_filters( 'wtars_shipped/fee-taxes', $this->fees[ $fee_id ][ 'taxes' ], $fee_id, $instance_id );

                foreach ( $d_taxes as $key => $tax ) {
                    $fee_taxes[ $key ] = wc_add_number_precision_deep( $tax );
                }
            }

            return $fee_taxes;
        }

        public function get_fee_html( $fee_html, $fee_id ) {

            // do not modify fee html
            if ( !isset( $this->fees[ $fee_id ] ) ) {
                return $fee_html;
            }

            $fee = $this->fees[ $fee_id ];
            $instance_id = $fee[ 'instance_id' ];

            $fee_cost = apply_filters( 'wtars_shipped/fee-cost', $fee[ 'cost' ], $fee_id, $instance_id );
            $fee_cost_tax = apply_filters( 'wtars_shipped/fee-tax', $fee[ 'tax_total' ], $fee_id, $instance_id );

            if ( WC()->cart->display_prices_including_tax() ) {

                $fee_html = wc_price( $fee_cost + $fee_cost_tax );

                if ( $fee_cost_tax > 0 && !wc_prices_include_tax() ) {
                    $fee_html .= ' <small class="tax_label">' . WC()->countries->inc_tax_or_vat() . '</small>';
                }
            } else {

                $fee_html = wc_price( $fee_cost );

                if ( $fee_cost_tax > 0 && wc_prices_include_tax() ) {
                    $fee_html .= ' <small class="tax_label">' . WC()->countries->ex_tax_or_vat() . '</small>';
                }
            }

            $tooltip = '';

            if ( '' != $fee[ 'tooltip' ] ) {

                $fee_tooltip = apply_filters( 'wtars_shipped/fee-tooltip', $fee[ 'tooltip' ], $fee_id, $instance_id );

                $tooltip = '<span class="wtars_shipped_tooltip wtars_shipped_tooltip_mv dashicons dashicons-editor-help" title="' . wc_sanitize_tooltip( $fee_tooltip ) . '"></span>';
            }

            return $fee_html . $tooltip;
        }

        public function get_sort_order( $sort_order, $a, $b ) {

            $sort_count = -300;

            if ( count( $this->fees ) ) {

                $keys = array_keys( $this->fees );

                foreach ( $keys as $key ) {

                    if ( $a->id == $key ) {
                        $sort_order[ 'a' ] = $sort_count;
                    }

                    if ( $b->id == $key ) {
                        $sort_order[ 'b' ] = $sort_count;
                    }

                    $sort_count++;
                }
            }

            return $sort_order;
        }

        private function apply_cart_fee( $fee_id, $fee ) {

            $instance_id = $fee[ 'instance_id' ];

            $args = array(
                'id' => $fee_id,
                'name' => apply_filters( 'wtars_shipped/fee-title', $fee[ 'title' ], $fee_id, $instance_id ),
                'amount' => apply_filters( 'wtars_shipped/fee-cost', $fee[ 'cost' ], $fee_id, $instance_id ),
                'taxable' => ($fee[ 'tax_total' ] > 0),
            );

            WC()->cart->fees_api()->add_fee( $args );
        }

        private function can_apply_cart_fee( $args ) {

            $rate_ids = $this->get_chosen_rate_ids( $args[ 'instance_id' ] );

            if ( !is_array( $args[ 'shipping_rates' ] ) ) {
                return count( $rate_ids ) > 0;
            }

            return WTARS_Shipped_Validation_Util::validate_list_list( $rate_ids, $args[ 'shipping_rates' ], $args[ 'compare' ] );
        }

        private function get_chosen_rate_ids( $instance_id ) {

            $rate_ids = array();

            $cart_rates = WC()->session->get( 'chosen_shipping_methods' );


            if ( !isset( $cart_rates ) ) {
                return $rate_ids;
            }

            foreach ( $cart_rates as $cart_rate ) {
                $cart_rt = explode( ':', $cart_rate );

                if ( count( $cart_rt ) < 2 ) {
                    continue;
                }

                if ( WTARS_SHIPPED_METHOD_ID != $cart_rt[ 0 ] ) {
                    continue;
                }

                $cart_rt_prp = explode( '_', $cart_rt[ 1 ] );

                if ( count( $cart_rt_prp ) < 2 ) {
                    continue;
                }

                if ( $instance_id != $cart_rt_prp[ 0 ] ) {
                    continue;
                }
                if ( in_array( $cart_rt_prp[ 1 ], $rate_ids ) ) {
                    continue;
                }

                $rate_ids[] = $cart_rt_prp[ 1 ];
            }

            return $rate_ids;
        }

        /* -----------------
         * rates functions 
         * ----------------- */

        private function apply_rate_fees( $package, $data, $instance_id ) {

            // rates cost with fees cost

            $rates = array();

            foreach ( $data[ 'fees' ][ $instance_id ] as $fee ) {

                if ( 'rate_cost' != $fee[ 'fee_method' ] ) {
                    continue;
                }

                $rates = $this->apply_rate_fee( $rates, $fee, $data[ 'rates' ][ $instance_id ], $instance_id );
            }

            return $this->update_package_rates( $package, $rates, $instance_id );
        }

        private function apply_rate_fee( $rates, $fee, $data_rates, $instance_id ) {

            $rate_args = array(
                'shipping_rates' => $fee[ 'shipping_rates' ],
                'compare' => $fee[ 'compare' ],
            );

            $fee_rates = $this->get_rates( $rate_args, $data_rates, $instance_id );


            foreach ( $fee_rates as $key => $fee_rate ) {

                if ( !isset( $rates[ $key ] ) ) {
                    $rates[ $key ] = $fee_rate;
                }

                $rate_fee = $this->add_fee_to_rate( $rates[ $key ], $fee );

                $rates[ $key ] = apply_filters( 'wtars_shipped/rate-fee', $rate_fee, $rates[ $key ], $fee, $instance_id );
            }

            return $rates;
        }

        private function update_package_rates( $package, $rates, $instance_id ) {

            foreach ( $rates as $rate_id => $rate ) {

                $shipping_rate_id = WTARS_Shipped::get_rate_client_id( $instance_id, $rate_id );

                if ( isset( $package[ 'rates' ][ $shipping_rate_id ] ) ) {

                    $package[ 'rates' ][ $shipping_rate_id ]->set_cost( apply_filters( 'wtars_shipped/rate-cost', $rate[ 'cost' ], $rate_id, $instance_id ) );
                    $package[ 'rates' ][ $shipping_rate_id ]->set_taxes( apply_filters( 'wtars_shipped/rate-taxes', $rate[ 'taxes' ], $rate_id, $instance_id ) );
                }
            }

            return $package;
        }

        private function add_fee_to_rate( $rate, $fee ) {

            $rate[ 'cost' ] += $fee[ 'cost' ];
            $rate[ 'tax_total' ] += $fee[ 'tax_total' ];
            $rate[ 'taxes' ] = $this->add_fee_taxes_to_rate( $rate[ 'taxes' ], $fee[ 'taxes' ] );

            if ( isset( $rate[ 'max' ] ) && $rate[ 'cost' ] > $rate[ 'max' ] ) {

                foreach ( $rate[ 'taxes' ] as $key => $tax ) {

                    $new_tax = ($rate[ 'max' ] / $rate[ 'cost' ]) * $tax;

                    $rate[ 'taxes' ][ $key ] = WTARS_Shipped_Util::round_num( $new_tax, wc_get_price_decimals() );
                }

                $rate[ 'cost' ] = $rate[ 'max' ];
                $rate[ 'tax_total' ] = array_sum( $rate[ 'taxes' ] );
                if ( 'yes' == $rate[ 'inclusive_tax' ] ) {
                    $rate[ 'cost' ] = $rate[ 'max' ] - $rate[ 'tax_total' ];
                }
            }

            return $rate;
        }

        private function add_fee_taxes_to_rate( $rate_taxes, $fee_taxes ) {

            $keys = array_keys( $fee_taxes );

            foreach ( $keys as $key ) {

                if ( !isset( $rate_taxes[ $key ] ) ) {
                    $rate_taxes[ $key ] = 0;
                }

                $rate_taxes[ $key ] += $fee_taxes[ $key ];
            }

            return $rate_taxes;
        }

        private function get_rates( $args, $data_rates, $instance_id ) {

            if ( !is_array( $args[ 'shipping_rates' ] ) ) {
                return $data_rates;
            }

            $rates = array();

            foreach ( $data_rates as $key => $data_rate ) {

                if ( WTARS_Shipped_Validation_Util::validate_value_list( $key, $args[ 'shipping_rates' ], $args[ 'compare' ] ) ) {

                    $rates[ $key ] = $data_rate;
                }
            }

            return $rates;
        }

    }

}