<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Checkout_Messages_Engine' ) ) {

    class WTARS_Shipped_Premium_Checkout_Messages_Engine {

        private static $instance = null;

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function get_parameters( $message_option, $instance_id, $data ) {

            $parameters_args = self::get_instance()->get_parameters_args_from_message_option( $message_option, $instance_id );

            $parameters = WTARS_Shipped_Parameter_Types::get_parameters( $parameters_args, $data );

            return $parameters;
        }

        public static function can_apply_message( $message_option_head, $data ) {

            $instance_id = $message_option_head[ 'instance_id' ];

            if ( 'if_others' == $message_option_head[ 'apply_mode' ] && !isset( $data[ 'messages' ][ $instance_id ] ) ) {
                return false;
            }

            if ( 'if_no_others' == $message_option_head[ 'apply_mode' ] && isset( $data[ 'messages' ][ $instance_id ] ) ) {
                return false;
            }

            if ( 'first' == $message_option_head[ 'settings' ][ 'mode' ] && isset( $data[ 'messages' ][ $instance_id ] ) ) {
                return false;
            }

            return true;
        }

        public static function add_message( $data, $message, $message_option_head ) {

            $instance_id = $message_option_head[ 'instance_id' ];

            $s_mode = $message_option_head[ 'settings' ][ 'mode' ];

            // add last valid messages data or only message if valid
            if ( 'last' == $s_mode || 'only_this' == $message_option_head[ 'apply_mode' ] ) {
                $data = self::get_instance()->force_message( $data, $message, $instance_id, $message_option_head );
                return $data;
            }

            // add message data as usual
            $data[ 'messages' ][ $instance_id ][ $message_option_head[ 'message_id' ] ] = $message;

            // allows other plugins to modify message data once added
            if ( has_filter( 'wtars_shipped/checkout-messages/added-message' ) ) {

                if ( isset( $data[ 'messages' ][ $instance_id ][ $message_option_head[ 'message_id' ] ] ) ) {

                    $data[ 'messages' ][ $instance_id ][ $message_option_head[ 'message_id' ] ] = apply_filters( 'wtars_shipped/checkout-messages/added-message', $data[ 'messages' ][ $instance_id ][ $message_option_head[ 'message_id' ] ], $instance_id, $message_option_head );
                }
            }

            return $data;
        }

        private function get_parameters_args_from_message_option( $message_option, $instance_id ) {

            $parameters_args = array();

            if ( isset( $message_option[ 'parameters' ] ) ) {

                $parameters_args = $message_option[ 'parameters' ];
            }

            $arg_keys = array_keys( $parameters_args );

            foreach ( $arg_keys as $key ) {

                $parameters_args[ $key ][ 'instance_id' ] = $instance_id;
                $parameters_args[ $key ][ 'module' ] = 'checkout-messages';
                $parameters_args[ $key ][ 'sub_module' ] = 'parameters';
                $parameters_args[ $key ][ 'message_id' ] = $message_option[ 'message_id' ];
            }

            return $parameters_args;
        }

        private function force_message( $data, $message, $instance_id, $message_option_head ) {

            if ( isset( $data[ 'messages' ][ $instance_id ] ) ) {
                unset( $data[ 'messages' ][ $instance_id ] );
            }

            $data[ 'messages' ][ $instance_id ][ $message_option_head[ 'message_id' ] ] = $message;

            return $data;
        }

    }

}