<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Premium_Checkout_Messages' ) ) {
    WTARS_Shipped_Inc::recursive_require( dirname( __FILE__ ), array( 'checkout-messages.php' ) );

    class WTARS_Shipped_Premium_Checkout_Messages {

        private static $instance = null;

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function process_messages( $data, $instance_id ) {

            $this_obj = self::get_instance();

            foreach ( $data[ 'messages' ][ $instance_id ] as $message_id => $messages_data ) {

                $this_obj->process_message( $messages_data, $message_id, $instance_id );
            }
        }

        private function process_message( $message_data, $message_id, $instance_id ) {

            if ( '' == $message_data[ 'message' ] ) {
                return;
            }

            if ( !$this->can_apply_message( $message_data, $message_id ) ) {
                return;
            }


            $message_type = $message_data[ 'message_type' ];

            $raw_message = apply_filters( 'wtars_shipped/message-text', $message_data[ 'message' ], $message_id, $message_type, $instance_id );

            $message = $this->prepare_message( $raw_message, $message_data[ 'parameters' ], $instance_id );

            if ( !wc_has_notice( $message, $message_type ) ) {

                wc_add_notice( $message, $message_type );
            }

            if ( 'yes' != $message_data[ 'always_show' ] ) {
                $this->store_hash( $message_data, $message_id );
            }
        }

        private function prepare_message( $message, $parameters, $instance_id ) {

            foreach ( $parameters as $parameter_id => $parameter ) {

                $parameter_type = $parameter[ 'parameter_type' ];

                $parameter_value = apply_filters( 'wtars_shipped/parameter-value', $parameter[ 'value' ], $parameter_id, $parameter_type, $instance_id );

                if ( $parameter[ 'is_currency' ] && is_numeric( $parameter_value ) ) {
                    $parameter_value = wc_price( apply_filters( 'wtars_shipped/parameter-currency-value', $parameter_value, $parameter_id, $parameter_type, $instance_id ) );
                }

                $rep_value = '/{{' . $parameter_id . '}}/';

                $message = preg_replace( $rep_value, $parameter_value, $message );
            }

            return $message;
        }

        private function can_apply_message( $message_data, $message_id ) {

            if ( 'yes' == $message_data[ 'always_show' ] ) {
                return true;
            }

            $s_hash = $this->get_stored_hash( $message_id );


            $hash = $this->get_hash( $message_data );

            return ($s_hash != $hash && $hash != '');
        }

        private function store_hash( $message_data, $message_id ) {

            WTARS_Shipped_Cart::set_session_data( $message_id, $this->get_hash( $message_data ), 'notices-hash' );
        }

        private function get_stored_hash( $message_id ) {

            return WTARS_Shipped_Cart::get_session_data( $message_id, '', 'notices-hash' );
        }

        private function get_hash( $message_data ) {

            $hash_obj = array(
                'message' => $message_data[ 'message' ],
                'message_type' => $message_data[ 'message_type' ],
                'parameters' => $message_data[ 'parameters' ],
            );

            return md5( wp_json_encode( $hash_obj ) );
        }

    }

}