<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Premium_Shipping_Rates_Cache' ) ) {

    class WTARS_Shipped_Premium_Shipping_Rates_Cache {

        private $is_availables = array();
        private $cache;
        private $loaded = false;

        public function __construct() {

            $this->cache = new WTARS_Shipped_Cache();

            add_filter( 'wtars_shipped/cache-data', array( $this, 'cache_data' ), 10, 1 );
        }

        public function cache_data( $data ) {

            //shipping instance needs to be set
            if ( !isset( $data[ 'wc' ][ 'instance_id' ] ) ) {
                return $data;
            }

            $instance_id = $data[ 'wc' ][ 'instance_id' ];

            //get in memory cached is_availables
            if ( isset( $this->is_availables[ $instance_id ] ) ) {
                $data[ 'is_availables' ][ $instance_id ] = $this->is_availables[ $instance_id ];
            }

            if ( isset( $data[ 'is_availables' ][ $instance_id ] ) ) {
                return $data;
            }

            // validate cache hash
            if ( !$this->cache->validate_hash( $instance_id ) ) {
                // reload is_availables
                $data[ 'wc' ][ 'reload' ] = true;
                return $data;
            }

            // try load is_availables from session cache
            $data = $this->load_cache( $data, $instance_id );

            if ( isset( $data[ 'is_availables' ][ $instance_id ] ) ) {

                $this->is_availables[ $instance_id ] = $data[ 'is_availables' ][ $instance_id ];
            } else if ( !$this->loaded ) {

                // reload is_availables
                $data[ 'wc' ][ 'reload' ] = true;
            }

            return $data;
        }

        public function store_cache( $is_availables, $instance_id ) {

            $instance_is_availables = array();

            if ( isset( $is_availables[ $instance_id ] ) ) {
                $instance_is_availables = $is_availables[ $instance_id ];
            }

            //set in memory cache
            $this->is_availables[ $instance_id ] = $instance_is_availables;


            //store cache hash
            $this->cache->store_hash( $instance_id );

            //store cache data
            $this->cache->store_cache( 'is_availables', $instance_is_availables, $instance_id );
        }

        private function load_cache( $data, $instance_id ) {
            $cache_data = $this->cache->load_cache( 'is_availables', $instance_id );

            $this->loaded = is_array( $cache_data );

            if ( $cache_data ) {
                $data[ 'is_availables' ][ $instance_id ] = $cache_data;
            }

            return $data;
        }

    }

}