<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Product_Filter_Type_Dimensions' ) ) {

    class WTARS_Shipped_Product_Filter_Type_Dimensions {

        public function __construct() {
            add_filter( 'wtars_shipped/validate-item_length-fitler', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_width-fitler', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_height-fitler', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_surface_area-fitler', array( $this, 'validate_dimensions' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_volume-fitler', array( $this, 'validate_dimensions' ), 1, 2 );
        }

        public function validate_dimensions( $filter_args, $package_item ) {

            $filter_type = $filter_args[ 'filter_type' ];

            $item_dimension = $this->get_item_dimension( $filter_type, $package_item );

            $filter_compare = $filter_args[ 'compare' ];

            if ( '--' == $filter_compare ) {

                $filter_from_dimension = 0;

                if ( is_numeric( $filter_args[ 'from_dimension' ] ) ) {

                    $filter_from_dimension = $filter_args[ 'from_dimension' ];
                }

                $filter_to_dimension = 1;

                if ( is_numeric( $filter_args[ 'to_dimension' ] ) ) {

                    $filter_to_dimension = $filter_args[ 'to_dimension' ];
                }

                $from_is_valid = WTARS_Shipped_Validation_Util::validate_value( '>=', $item_dimension, $filter_from_dimension, 'no' );

                $to_is_valid = WTARS_Shipped_Validation_Util::validate_value( '<=', $item_dimension, $filter_to_dimension, 'no' );

                return (true == $from_is_valid && true == $to_is_valid);
            }

            $filter_dimension = 0;

            if ( is_numeric( $filter_args[ 'dimension' ] ) ) {

                $filter_dimension = $filter_args[ 'dimension' ];
            }

            return WTARS_Shipped_Validation_Util::validate_value( $filter_compare, $item_dimension, $filter_dimension, 'no' );
        }

        private function get_item_dimension( $filter_type, $package_item ) {

            $dimension = $package_item[ 'data' ][ 'dimensions' ];

            switch ( $filter_type ) {

                case 'item_length':

                    if ( is_numeric( $dimension[ 'length' ] ) ) {
                        return $dimension[ 'length' ];
                    }

                    return 0;

                case 'item_width':

                    if ( is_numeric( $dimension[ 'width' ] ) ) {
                        return $dimension[ 'width' ];
                    }

                    return 0;

                case 'item_height':

                    if ( is_numeric( $dimension[ 'height' ] ) ) {
                        return $dimension[ 'height' ];
                    }

                    return 0;

                case 'item_surface_area':

                    $length = $dimension[ 'length' ];
                    $width = $dimension[ 'width' ];

                    if ( !is_numeric( $length ) ) {
                        return 0;
                    }

                    if ( !is_numeric( $width ) ) {
                        return 0;
                    }

                    return $length * $width;

                case 'item_volume':
                    $length = $dimension[ 'length' ];
                    $width = $dimension[ 'width' ];
                    $height = $dimension[ 'height' ];

                    if ( !is_numeric( $length ) ) {
                        return 0;
                    }

                    if ( !is_numeric( $width ) ) {
                        return 0;
                    }

                    if ( !is_numeric( $height ) ) {
                        return 0;
                    }

                    return ($length * $width) * $height;

                default:

                    return 0;
            }
        }

    }

    new WTARS_Shipped_Product_Filter_Type_Dimensions();
}