<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Product_Filter_Type_Author' ) ) {

    class WTARS_Shipped_Product_Filter_Type_Author {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-item_user-fitler', array( $this, 'validate_user' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_user_roles-fitler', array( $this, 'validate_user_roles' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_user_caps-fitler', array( $this, 'validate_user_caps' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_user_metas-fitler', array( $this, 'validate_user_metas' ), 1, 2 );
        }

        public function validate_user( $filter_args, $package_item ) {

            $filter_user_ids = $filter_args[ 'user_id' ];

            if ( !is_array( $filter_user_ids ) ) {

                return false;
            }

            $user_id = WTARS_Shipped_Product_Util::get_author_id( $package_item[ 'product_id' ] );

            $filter_compare = $filter_args[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value_list( $user_id, $filter_user_ids, $filter_compare );
        }

        public function validate_user_roles( $filter_args, $package_item ) {

            $filter_user_roles = $filter_args[ 'user_roles' ];

            if ( !is_array( $filter_user_roles ) ) {

                return false;
            }

            $user_roles = WTARS_Shipped_Product_Util::get_author_roles( $package_item[ 'product_id' ] );

            if ( !count( $user_roles ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $user_roles, $filter_user_roles, $filter_compare );
        }

        public function validate_user_caps( $filter_args, $package_item ) {

            $filter_user_caps = $filter_args[ 'user_caps' ];

            if ( !is_array( $filter_user_caps ) ) {

                return false;
            }

            $user_caps = WTARS_Shipped_Product_Util::get_author_caps( $package_item[ 'product_id' ] );

            if ( !count( $user_caps ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $user_caps, $filter_user_caps, $filter_compare );
        }

        public function validate_user_metas( $filter_args, $package_item ) {

            if ( !isset( $filter_args[ 'meta_key' ] ) ) {
                return false;
            }

            $filter_meta_key = $filter_args[ 'meta_key' ];

            if ( $filter_meta_key == '' ) {
                return false;
            }

            $filter_yes_no = 'no';

            if ( isset( $filter_args[ 'yes_no' ] ) && !empty( $filter_args[ 'yes_no' ] ) ) {
                $filter_yes_no = $filter_args[ 'yes_no' ];
            }

            $filter_meta_value = '';

            if ( isset( $filter_args[ 'meta_value' ] ) ) {
                $filter_meta_value = $filter_args[ 'meta_value' ];
            }

            $product_id = $package_item[ 'product_id' ];

            $meta_value = WTARS_Shipped_Product_Util::get_author_meta( $product_id, $filter_meta_key, array() );

            if ( is_array( $meta_value ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $filter_compare, $meta_value, $filter_meta_value, $filter_yes_no );
        }

    }

    new WTARS_Shipped_Product_Filter_Type_Author();
}
