<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Product_Filter_Type_Products' ) ) {

    class WTARS_Shipped_Product_Filter_Type_Products {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-spec_products-fitler', array( $this, 'validate_specific_products' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-product_var-fitler', array( $this, 'validate_product_variations' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-product_cats-fitler', array( $this, 'validate_product_categories' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-product_tags-fitler', array( $this, 'validate_product_tags' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-product_attrs-fitler', array( $this, 'validate_product_attributes' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-product_var_attrs-fitler', array( $this, 'validate_product_variation_attributes' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-product_qty-fitler', array( $this, 'validate_product_quantity' ), 1, 2 );
        }

        public function validate_specific_products( $filter_args, $package_item ) {

            if ( !isset( $filter_args[ 'product_slugs' ] ) ) {
                return false;
            }

            $filter_product_ids = WTARS_Shipped_Util::get_product_ids_by_slugs( $filter_args[ 'product_slugs' ] );

            if ( !count( $filter_product_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $product_id = $package_item[ 'product_id' ];

            return WTARS_Shipped_Validation_Util::validate_value_list( $product_id, $filter_product_ids, $filter_compare );
        }

        public function validate_product_variations( $filter_args, $package_item ) {

            if ( !isset( $filter_args[ 'variation_slugs' ] ) ) {
                return false;
            }

            $filter_variation_ids = WTARS_Shipped_Util::get_variation_ids_by_slugs( $filter_args[ 'variation_slugs' ] );

            if ( !count( $filter_variation_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $variation_id = $package_item[ 'variation_id' ];

            if ( 0 >= $variation_id ) {
                return false;
            }

            return WTARS_Shipped_Validation_Util::validate_value_list( $variation_id, $filter_variation_ids, $filter_compare );
        }

        public function validate_product_categories( $filter_args, $package_item ) {

            if ( !isset( $filter_args[ 'category_slugs' ] ) ) {
                return false;
            }

            $filter_category_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $filter_args[ 'category_slugs' ], 'product_cat' );

            if ( !count( $filter_category_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $category_ids = $package_item[ 'data' ][ 'category_ids' ];


            return WTARS_Shipped_Validation_Util::validate_list_list( $category_ids, $filter_category_ids, $filter_compare );
        }

        public function validate_product_tags( $filter_args, $package_item ) {

            if ( !isset( $filter_args[ 'tag_slugs' ] ) ) {
                return false;
            }

            $filter_tag_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $filter_args[ 'tag_slugs' ], 'product_tag' );

            if ( !count( $filter_tag_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $tag_ids = $package_item[ 'data' ][ 'tag_ids' ];


            return WTARS_Shipped_Validation_Util::validate_list_list( $tag_ids, $filter_tag_ids, $filter_compare );
        }

        public function validate_product_attributes( $filter_args, $package_item ) {

            if ( !isset( $filter_args[ 'attribute_slugs' ] ) ) {
                return false;
            }

            $filter_attribute_ids = WTARS_Shipped_Util::get_attribute_ids_by_slugs( $filter_args[ 'attribute_slugs' ] );

            if ( !count( $filter_attribute_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $attribute_ids = $package_item[ 'data' ][ 'attribute_ids' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $attribute_ids, $filter_attribute_ids, $filter_compare );
        }

        public function validate_product_variation_attributes( $filter_args, $package_item ) {

            if ( !isset( $filter_args[ 'attribute_slugs' ] ) ) {
                return false;
            }

            $filter_attribute_ids = WTARS_Shipped_Util::get_attribute_ids_by_slugs( $filter_args[ 'attribute_slugs' ] );

            if ( !count( $filter_attribute_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $attribute_ids = $package_item[ 'data' ][ 'variation_attribute_ids' ];

            return WTARS_Shipped_Validation_Util::validate_list_list( $attribute_ids, $filter_attribute_ids, $filter_compare );
        }

        public function validate_product_quantity( $filter_args, $package_item ) {

            $item_quantity = $package_item[ 'quantity' ];

            $filter_compare = $filter_args[ 'compare' ];

            if ( '--' == $filter_compare ) {

                $filter_from_quantity = 0;

                if ( is_numeric( $filter_args[ 'from_quantity' ] ) ) {

                    $filter_from_quantity = $filter_args[ 'from_quantity' ];
                }

                if ( 0 >= $filter_from_quantity ) {
                    return false;
                }

                $filter_to_quantity = 0;

                if ( is_numeric( $filter_args[ 'to_quantity' ] ) ) {

                    $filter_to_quantity = $filter_args[ 'to_quantity' ];
                }

                if ( 0 >= $filter_to_quantity ) {
                    return false;
                }

                $from_is_valid = WTARS_Shipped_Validation_Util::validate_value( '>=', $item_quantity, $filter_from_quantity, 'no' );

                $to_is_valid = WTARS_Shipped_Validation_Util::validate_value( '<=', $item_quantity, $filter_to_quantity, 'no' );

                return (true == $from_is_valid && true == $to_is_valid);
            }

            $filter_quantity = 0;

            if ( is_numeric( $filter_args[ 'quantity' ] ) ) {
                $filter_quantity = $filter_args[ 'quantity' ];
            }

            if ( 0 >= $filter_quantity ) {
                return false;
            }

            return WTARS_Shipped_Validation_Util::validate_value( $filter_compare, $item_quantity, $filter_quantity, 'no' );
        }

    }

    new WTARS_Shipped_Product_Filter_Type_Products();
}
