<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Product_Filter_Type_Properties' ) ) {

    class WTARS_Shipped_Product_Filter_Type_Properties {

        public function __construct() {

            add_filter( 'wtars_shipped/validate-item_is_downloadable-fitler', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_is_featured-fitler', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_sales_total-fitler', array( $this, 'validate_totals' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_is_on_sale-fitler', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_stock_status-fitler', array( $this, 'validate_stock_status' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_stock_quantity-fitler', array( $this, 'validate_totals' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_shipping_class-fitler', array( $this, 'validate_shipping_class' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_is_taxable-fitler', array( $this, 'validate_is_yes' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_tax_class-fitler', array( $this, 'validate_tax_class' ), 1, 2 );
            add_filter( 'wtars_shipped/validate-item_meta-fitler', array( $this, 'validate_meta' ), 1, 2 );
        }

        public function validate_is_yes( $filter_args, $package_item ) {

            $filter_type = $filter_args[ 'filter_type' ];

            $filter_value = 'no';

            if ( isset( $filter_args[ 'is_yes' ] ) && $filter_args[ 'is_yes' ] == 'yes' ) {

                $filter_value = 'yes';
            }

            $item_value = $this->get_is_yes( $filter_type, $package_item );

            return WTARS_Shipped_Validation_Util::validate_yes_no( $item_value, $filter_value );
        }

        public function validate_totals( $filter_args, $package_item ) {

            $filter_type = $filter_args[ 'filter_type' ];

            $item_totals = $this->get_item_totals( $filter_type, $package_item );

            $filter_compare = $filter_args[ 'compare' ];

            if ( '--' == $filter_compare ) {

                $filter_from_totals = 0;

                if ( is_numeric( $filter_args[ 'from_totals' ] ) ) {

                    $filter_from_totals = $filter_args[ 'from_totals' ];
                }

                $filter_to_totals = 1;

                if ( is_numeric( $filter_args[ 'to_totals' ] ) ) {

                    $filter_to_totals = $filter_args[ 'to_totals' ];
                }

                $from_is_valid = WTARS_Shipped_Validation_Util::validate_value( '>=', $item_totals, $filter_from_totals, 'no' );

                $to_is_valid = WTARS_Shipped_Validation_Util::validate_value( '<=', $item_totals, $filter_to_totals, 'no' );

                return (true == $from_is_valid && true == $to_is_valid);
            }

            $filter_totals = 0;

            if ( is_numeric( $filter_args[ 'totals' ] ) ) {

                $filter_totals = $filter_args[ 'totals' ];
            }

            return WTARS_Shipped_Validation_Util::validate_value( $filter_compare, $item_totals, $filter_totals, 'no' );
        }

        public function validate_stock_status( $filter_args, $package_item ) {

            if ( !is_array( $filter_args[ 'stock_statuses' ] ) ) {
                return false;
            }

            $filter_stock_statuses = $filter_args[ 'stock_statuses' ];

            $filter_compare = $filter_args[ 'compare' ];

            $item_stock_status = $package_item[ 'data' ][ 'stock_status' ];

            return WTARS_Shipped_Validation_Util::validate_value_list( $item_stock_status, $filter_stock_statuses, $filter_compare );
        }

        public function validate_shipping_class( $filter_args, $package_item ) {

            if ( !isset( $filter_args[ 'shipping_class_slugs' ] ) ) {
                return false;
            }

            $filter_shipping_class_ids = WTARS_Shipped_Util::get_product_term_ids_by_slugs( $filter_args[ 'shipping_class_slugs' ], 'product_shipping_class' );

            if ( !count( $filter_shipping_class_ids ) ) {
                return false;
            }

            $filter_compare = $filter_args[ 'compare' ];

            $item_shipping_class_id = $package_item[ 'data' ][ 'shipping_class_id' ];

            return WTARS_Shipped_Validation_Util::validate_value_list( $item_shipping_class_id, $filter_shipping_class_ids, $filter_compare );
        }

        public function validate_tax_class( $filter_args, $package_item ) {

            if ( !is_array( $filter_args[ 'tax_class_slugs' ] ) ) {
                return false;
            }

            $filter_tax_class_slugs = $filter_args[ 'tax_class_slugs' ];

            $filter_compare = $filter_args[ 'compare' ];

            $item_tax_class_slug = $this->get_tax_class( $package_item );

            return WTARS_Shipped_Validation_Util::validate_value_list( $item_tax_class_slug, $filter_tax_class_slugs, $filter_compare );
        }

        public function validate_meta( $filter_args, $package_item ) {

            $yes_no = 'no';

            $filter_value = '';

            if ( isset( $filter_args[ 'yes_no' ] ) ) {
                $yes_no = $filter_args[ 'yes_no' ];
            }

            if ( isset( $filter_args[ 'meta_value' ] ) ) {
                $filter_value = $filter_args[ 'meta_value' ];
            }

            $filter_key = $filter_args[ 'meta_key' ];

            $meta_value = get_post_meta( $package_item[ 'product_id' ], $filter_key, true );

            $filter_compare = $filter_args[ 'compare' ];

            return WTARS_Shipped_Validation_Util::validate_value( $filter_compare, $meta_value, $filter_value, $yes_no );
        }

        private function get_is_yes( $filter_type, $package_item ) {

            switch ( $filter_type ) {

                case 'item_is_downloadable':

                    return $package_item[ 'data' ][ 'is_downloadable' ];

                case 'item_is_featured':

                    return $package_item[ 'data' ][ 'is_featured' ];

                case 'item_is_on_sale':

                    return $package_item[ 'data' ][ 'is_on_sale' ];

                case 'item_is_taxable':

                    return $package_item[ 'data' ][ 'is_taxable' ];

                default:

                    return false;
            }
        }

        private function get_item_totals( $filter_type, $package_item ) {

            switch ( $filter_type ) {

                case 'item_sales_total':

                    return $package_item[ 'data' ][ 'total_sales' ];

                case 'item_stock_quantity':
                    if ( is_numeric( $package_item[ 'data' ][ 'stock_quantity' ] ) ) {
                        return $package_item[ 'data' ][ 'stock_quantity' ];
                    }
                    return 0;
                default:

                    return 0;
            }
        }

        private function get_tax_class( $package_item ) {

            if ( 'taxable' == $package_item[ 'data' ][ 'tax_status' ] && '' == $package_item[ 'data' ][ 'tax_class' ] ) {
                return '--0';
            }

            return $package_item[ 'data' ][ 'tax_class' ];
        }

    }

    new WTARS_Shipped_Product_Filter_Type_Properties();
}
