<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Product_Filter_Type_Weights' ) ) {

    class WTARS_Shipped_Product_Filter_Type_Weights {

        private $option_id_list = array();
        private $prefix = 'item_weight-';

        public function __construct() {

            add_filter( 'wtars_shipped/cache-data', array( $this, 'init' ), 1 );
        }

        public function init( $data ) {

            if ( !isset( $data[ 'wc' ][ 'instance_id' ] ) ) {
                return $data;
            }

            $instance_id = $data[ 'wc' ][ 'instance_id' ];

            foreach ( $this->get_option_ids( $instance_id ) as $option_id ) {

                if ( in_array( $option_id, $this->option_id_list ) ) {
                    continue;
                }

                add_filter( 'wtars_shipped/validate-' . $this->prefix . $option_id . '-fitler', array( $this, 'validate_weights' ), 1, 2 );

                $this->option_id_list[] = $option_id;
            }

            return $data;
        }

        public function validate_weights( $filter_args, $package_item ) {

            $item_weight = $this->get_item_weight( $filter_args, $package_item );

            $filter_compare = $filter_args[ 'compare' ];
            
            if ( '--' == $filter_compare ) {

                $filter_from_weight = 0;

                if ( is_numeric( $filter_args[ 'from_weight' ] ) ) {

                    $filter_from_weight = $filter_args[ 'from_weight' ];
                }

                $filter_to_weight = .5;

                if ( is_numeric( $filter_args[ 'to_weight' ] ) ) {

                    $filter_to_weight = $filter_args[ 'to_weight' ];
                }

                $from_is_valid = WTARS_Shipped_Validation_Util::validate_value( '>=', $item_weight, $filter_from_weight, 'no' );

                $to_is_valid = WTARS_Shipped_Validation_Util::validate_value( '<=', $item_weight, $filter_to_weight, 'no' );

                return (true == $from_is_valid && true == $to_is_valid);
            }

            $filter_weight = 0;

            if ( is_numeric( $filter_args[ 'weight' ] ) ) {

                $filter_weight = $filter_args[ 'weight' ];
            }
            return WTARS_Shipped_Validation_Util::validate_value( $filter_compare, $item_weight, $filter_weight, 'no' );
        }

        private function get_item_weight( $filter_args, $package_item ) {

            $instance_id = $filter_args[ 'instance_id' ];
            $option_id = preg_replace( '/' . $this->prefix . '/', '', $filter_args[ 'filter_type' ] );

            $weight_calc = new WTARS_Shipped_Weight_Calculator();

            $weight_args = array(
                'instance_id' => $instance_id,
                'option_id' => $option_id,
            );

            $item_weight = $weight_calc->get_item_weight( $package_item, $weight_args );

            return $item_weight;
        }

        public function get_option_ids( $instance_id ) {

            $opts = WTARS_Shipped::get_option( 'weight_calcs', $instance_id, array() );

            $options = array();

            foreach ( $opts as $opt ) {

                if ( !isset( $opt[ 'option_id' ] ) ) {
                    continue;
                }
                $options[] = $opt[ 'option_id' ];
            }

            if ( !count( $options ) ) {
                return self::get_default();
            }

            return $options;
        }

        private static function get_default() {

            return array( '2234343', '2234344' );
        }

    }

    new WTARS_Shipped_Product_Filter_Type_Weights();
}