<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Product_Filter_Types' ) ) {

    WTARS_Shipped_Inc::recursive_require( dirname( __FILE__ ), array( 'product-filter-types.php' ) );

    class WTARS_Shipped_Product_Filter_Types {

        private static $instance = null;

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function get_package_items( $data, $product_filters, $add_items_data = false ) {

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return array();
            }

            $package_items = WTARS_Shipped_Package::get_package_items_data( $data[ 'wc' ][ 'package' ][ 'items' ], $data[ 'wc' ][ 'cart' ][ 'items' ] );

            $this_obj = self::get_instance();

            if ( $add_items_data ) {
                return $this_obj->validate_package_items( $package_items, $product_filters, $data );
            }

            return $this_obj->remove_extra_data( $this_obj->validate_package_items( $package_items, $product_filters, $data ) );
        }

        private function validate_package_items( $package_items, $product_filters, $data ) {

            if ( !count( $product_filters ) ) {
                return $package_items;
            }

            $items = array();

            foreach ( $package_items as $key => $package_item ) {

                if ( true == $this->validate_filters( $package_item, $product_filters, $data ) ) {
                    $items[ $key ] = $package_item;
                }
            }
            return $items;
        }

        private function validate_filters( $package_item, $product_filters, $data ) {

            $instance_id = $data[ 'wc' ][ 'instance_id' ];

            $is_valid = false;

            foreach ( $this->get_filters( $product_filters, true, $instance_id ) as $filter_args ) {

                $is_vld = apply_filters( 'wtars_shipped/validate-' . $filter_args[ 'filter_type' ] . '-fitler', $filter_args, $package_item, $data );

                if ( true === $is_vld ) {
                    $is_valid = true;
                }

                if ( true != $is_valid ) {

                    return $is_valid;
                }
            }

            if ( true === $is_valid ) {
                return $is_valid;
            }

            foreach ( $this->get_filters( $product_filters, false, $instance_id ) as $filter_args ) {

                $is_vld_op = apply_filters( 'wtars_shipped/validate-' . $filter_args[ 'filter_type' ] . '-fitler', $filter_args, $package_item, $data );

                if ( true === $is_vld_op ) {
                    $is_valid = true;
                }
            }

            return $is_valid;
        }

        private function get_filters( $product_filters, $is_required, $instance_id ) {

            $filters = array();

            foreach ( $product_filters as $product_filter ) {

                $filter_type = $product_filter[ 'filter_type' ];
                $filter_arg = $product_filter[ 'filter_type_' . $filter_type ];
                $filter_arg[ 'instance_id' ] = $instance_id;

                if ( true == $is_required && 'yes' != $filter_arg[ 'is_req' ] ) {
                    continue;
                }

                if ( true != $is_required && 'yes' == $filter_arg[ 'is_req' ] ) {
                    continue;
                }


                $filters[] = $this->prepare_filter( $filter_arg, $filter_type );
            }

            return $filters;
        }

        private function prepare_filter( $filter_args, $filter_type ) {

            $filter = array(
                'filter_type' => $filter_type
            );

            foreach ( $filter_args as $key => $value ) {
                $filter[ $key ] = $value;
            }

            return $filter;
        }

        private function remove_extra_data( $package_items ) {

            $keys = array_keys( $package_items );

            foreach ( $keys as $key ) {

                if ( isset( $package_items[ $key ][ 'data' ] ) ) {

                    unset( $package_items[ $key ][ 'data' ] );
                }
            }

            return $package_items;
        }

    }

}
