<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Cart' ) ) {

    class WTARS_Shipped_Premium_Cart {

        private static $instance = null;
        private $cart_data = array();
        private $parent_products = array();

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function get_data() {

            return self::get_instance()->get_all_data();
        }

        private function get_all_data() {

            if ( count( $this->cart_data ) ) {

                return $this->cart_data;
            }

            $cart = $this->get_cart();

            if ( !$cart ) {

                return false;
            }

            $this->cart_data = $this->get_contents_data( array(), $cart );

            return $this->cart_data;
        }

        private function get_contents_data( $cart_data, $cart ) {

            $cart_data[ 'items' ] = array();

            foreach ( $cart->cart_contents as $key => $item ) {

                $cart_data[ 'items' ][ $key ] = $this->get_item( $item );
                $cart_data[ 'items' ][ $key ][ 'data' ] = $this->get_product_data( $item[ 'data' ], $key );
            }

            return $this->get_totals_data( $cart_data, $cart );
        }

        private function get_item( $cart_item ) {
            $item = array(
                'key' => $cart_item[ 'product_id' ] . '_' . $cart_item[ 'variation_id' ],
                'product_id' => $cart_item[ 'product_id' ],
                'variation_id' => $cart_item[ 'variation_id' ],
                'quantity' => $cart_item[ 'quantity' ],
                'line_price' => ($cart_item[ 'line_subtotal' ] > 0) ? ($cart_item[ 'line_subtotal' ] / $cart_item[ 'quantity' ]) : 0,
                'line_price_tax' => ($cart_item[ 'line_subtotal_tax' ] > 0) ? ($cart_item[ 'line_subtotal_tax' ] / $cart_item[ 'quantity' ]) : 0,
                'line_total_price' => ($cart_item[ 'line_total' ] > 0) ? ($cart_item[ 'line_total' ] / $cart_item[ 'quantity' ]) : 0,
                'line_total_price_tax' => ($cart_item[ 'line_tax' ] > 0) ? ($cart_item[ 'line_tax' ] / $cart_item[ 'quantity' ]) : 0,
                'line_subtotal' => $cart_item[ 'line_subtotal' ],
                'line_subtotal_tax' => $cart_item[ 'line_subtotal_tax' ],
                'line_total' => isset( $cart_item[ 'line_total' ] ) ? $cart_item[ 'line_total' ] : $cart_item[ 'line_subtotal' ],
                'line_tax' => isset( $cart_item[ 'line_tax' ] ) ? $cart_item[ 'line_tax' ] : $cart_item[ 'line_subtotal_tax' ],
            );

            if ( has_filter( 'wtars_shipped/get-cart-item' ) ) {
                $item = apply_filters( 'wtars_shipped/get-cart-item', $item, $cart_item );
            }

            return $item;
        }

        private function get_product_data( $product, $item_key ) {

            $item_data = array(
                'regular_price' => $product->get_regular_price(),
                'sale_price' => $product->get_sale_price(),
                'price' => $product->get_price(),
                'total_sales' => 0,
                'stock_status' => $product->get_stock_status(),
                'stock_quantity' => $product->get_stock_quantity(),
                'sold_individually' => $product->get_sold_individually(),
                'is_featured' => false,
                'is_on_sale' => $product->is_on_sale(),
                'is_virtual' => $product->is_virtual(),
                'is_downloadable' => $product->is_downloadable(),
                'is_taxable' => $product->is_taxable(),
                'tax_status' => $product->get_tax_status(),
                'tax_class' => $product->get_tax_class(),
                'shipping_class_id' => $product->get_shipping_class_id(),
                'weight' => $product->get_weight(),
                'dimensions' => $product->get_dimensions( false ),
            );

            if ( $product->get_parent_id() > 0 ) {

                $v_product = $this->get_parent_product( $product->get_parent_id() );

                $item_data[ 'total_sales' ] = $v_product->get_total_sales();
                $item_data[ 'is_featured' ] = $v_product->is_featured();
                $item_data[ 'category_ids' ] = $v_product->get_category_ids();
                $item_data[ 'tag_ids' ] = $v_product->get_tag_ids();

                $db_attrs = $v_product->get_attributes();
            } else {

                $item_data[ 'total_sales' ] = $product->get_total_sales();
                $item_data[ 'is_featured' ] = $product->is_featured();
                $item_data[ 'category_ids' ] = $product->get_category_ids();
                $item_data[ 'tag_ids' ] = $product->get_tag_ids();

                $db_attrs = $product->get_attributes();
            }

            $attrs = array();

            foreach ( $db_attrs as $db_attr ) {

                foreach ( $db_attr->get_options() as $attr_option ) {

                    $attrs[] = $attr_option;
                }
            }

            $item_data[ 'attribute_ids' ] = $attrs;

            $item_data[ 'variation_attribute_ids' ] = $this->get_variation_attribute_ids( $product, $db_attrs );

            if ( has_filter( 'wtars_shipped/get-cart-product-data' ) ) {

                $item_data = apply_filters( 'wtars_shipped/get-cart-product-data', $item_data, $product, $item_key );
            }

            return $item_data;
        }

        private function get_variation_attribute_ids( $product, $db_attrs ) {

            $attrs = array();

            if ( 'variation' != $product->get_type() ) {

                return $attrs;
            }

            $variation_terms = array();

            foreach ( $product->get_attributes() as $v_taxonomy => $v_slug ) {

                $variation_terms[] = $v_taxonomy . ':' . $v_slug;
            }

            $terms = array();

            foreach ( $db_attrs as $db_attr ) {

                if ( !method_exists( $db_attr, 'get_terms' ) ) {

                    continue;
                }

                foreach ( $db_attr->get_terms() as $db_term ) {

                    $terms[ $db_term->term_id ] = $db_term->taxonomy . ':' . $db_term->slug;
                }
            }

            foreach ( $terms as $key => $term ) {

                if ( !in_array( $term, $variation_terms ) ) {

                    continue;
                }

                $attrs[] = $key;
            }

            return $attrs;
        }

        private function get_totals_data( $cart_data, $cart ) {

            $cart_data[ 'totals' ] = $cart->get_totals();

            if ( has_filter( 'wtars_shipped/get-cart-totals' ) ) {

                $cart_data[ 'totals' ] = apply_filters( 'wtars_shipped/get-cart-totals', $cart_data[ 'totals' ], $cart );
            }

            return self::get_applied_coupons( $cart_data, $cart );
        }

        private function get_applied_coupons( $cart_data, $cart ) {

            $cart_data[ 'applied_coupons' ] = array();

            $coupon_discount_totals = WC()->session->get( 'coupon_discount_totals', array() );
            $coupon_discount_tax_totals = WC()->session->get( 'coupon_discount_tax_totals', array() );
            $coupons = WC()->session->get( 'applied_coupons', array() );

            foreach ( $coupons as $coupon ) {

                $cart_coupon = array(
                    'coupon_code' => $coupon,
                    'coupon_totals' => 0,
                    'coupon_totals_tax' => 0
                );

                if ( isset( $coupon_discount_totals[ $coupon ] ) ) {
                    $cart_coupon[ 'coupon_totals' ] = $coupon_discount_totals[ $coupon ];
                }

                if ( isset( $coupon_discount_tax_totals[ $coupon ] ) ) {
                    $cart_coupon[ 'coupon_totals_tax' ] = $coupon_discount_tax_totals[ $coupon ];
                }

                $cart_data[ 'applied_coupons' ][] = $cart_coupon;
            }

            if ( has_filter( 'wtars_shipped/get-cart-applied-coupons' ) ) {
                $cart_data[ 'applied_coupons' ] = apply_filters( 'wtars_shipped/get-cart-applied-coupons', $cart_data[ 'applied_coupons' ], $cart );
            }

            return $this->get_shipping_rate( $cart_data, $cart );
        }

        private function get_shipping_rate( $cart_data, $cart ) {

            $needs_shipping = $cart->needs_shipping();

            $cart_data[ 'needs_shipping' ] = $needs_shipping;

            $cart_data[ 'shipping_rates' ] = array();

            $chosen_rate = WC()->session->get( 'chosen_shipping_methods', array() );

            $cnt = 0;

            while ( $package = WC()->session->get( 'shipping_for_package_' . $cnt, false ) ) {

                if ( isset( $package[ 'rates' ] ) && $needs_shipping ) {
                    foreach ( $package[ 'rates' ] as $key => $shipping_rate ) {

                        if ( in_array( $shipping_rate->get_id(), $chosen_rate ) ) {
                            $rate_id = $shipping_rate->get_id();
                            $cart_data[ 'shipping_rates' ][] = array(
                                'id' => $rate_id,
                                'method_id' => $shipping_rate->get_method_id(),
                                'instance_id' => $shipping_rate->get_instance_id(),
                                'cost' => $shipping_rate->get_cost(),
                                'shipping_tax' => $shipping_rate->get_shipping_tax(),
                                'taxes' => $shipping_rate->get_taxes(),
                            );
                        }
                    }
                }
                $cnt++;
            }


            if ( has_filter( 'wtars_shipped/get-cart-shipping-rates' ) ) {
                $cart_data[ 'shipping_rates' ] = apply_filters( 'wtars_shipped/get-cart-shipping-rates', $cart_data[ 'shipping_rates' ], $cart );
            }

            return $this->get_payment_method( $cart_data, $cart );
        }

        private function get_payment_method( $cart_data, $cart ) {

            $cart_data[ 'method_id' ] = WC()->session->get( 'chosen_payment_method', '' );

            if ( has_filter( 'wtars_shipped/get-cart-method-id' ) ) {
                $cart_data[ 'method_id' ] = apply_filters( 'wtars_shipped/get-cart-method-id', $cart_data[ 'method_id' ], $cart );
            }

            return $this->get_customer( $cart_data, $cart );
        }

        private function get_customer( $cart_data, $cart ) {

            $cart_data[ 'customer' ] = array();

            $customer = WC()->session->get( 'customer', false );

            if ( $customer ) {

                $cart_data[ 'customer' ] = array(
                    'id' => $customer[ 'id' ],
                    'email' => $customer[ 'email' ],
                );
            }

            if ( has_filter( 'wtars_shipped/get-cart-customer' ) ) {
                $cart_data[ 'customer' ] = apply_filters( 'wtars_shipped/get-cart-customer', $cart_data[ 'customer' ], $cart );
            }

            return $cart_data;
        }

        private function get_parent_product( $parent_id ) {

            if ( isset( $this->parent_products[ $parent_id ] ) ) {

                return $this->parent_products[ $parent_id ];
            }

            $this->parent_products[ $parent_id ] = wc_get_product( $parent_id );

            return $this->parent_products[ $parent_id ];
        }

        private function get_cart() {

            if ( method_exists( WC()->cart, 'is_empty' ) && WC()->cart->is_empty() ) {

                return false;
            }

            return WC()->cart;
        }

    }

}
