<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Groups' ) ) {

    class WTARS_Shipped_Groups {

        private static $instance = null;

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function get_packages( $data, $group_by, $product_filters ) {

            $this_obj = self::get_instance();

            $grouped_package_items = $this_obj->group_items( $this_obj->filter_packages( $data, $product_filters ), $group_by );

            
            
            $grouped_data = array();

            $cnt = 0;
            foreach ( $grouped_package_items as $grouped_package_item ) {

                if ( !count( $grouped_package_item ) ) {
                    continue;
                }

                $grouped_data[ $cnt ] = $data;

                $grouped_data[ $cnt ][ 'wc' ][ 'package' ][ 'items' ] = $this_obj->remove_extra_data( $grouped_package_item );
                
                $cnt++;
            }
            
            if ( has_filter( 'wtars_shipped/get-grouped-packages' ) ) {
                $grouped_data = apply_filters( 'wtars_shipped/get-grouped-packages', $grouped_data, $group_by, $data );
            }
            
            return $grouped_data;
        }

        private function group_items( $package_items, $group_by ) {

            switch ( $group_by ) {
                case 'quantity_unit':
                    return $this->group_by_qty_unit( $package_items );

                case 'line_item':
                    return $this->group_by_line( $package_items );

                case 'product':
                    return $this->group_by_product( $package_items );

                case 'product_category':
                    return $this->group_by_category( $package_items );

                case 'shipping_class':
                    return $this->group_by_shipping_class( $package_items );

                default:
                    return array( $package_items );
            }
        }

        private function group_by_qty_unit( $package_items ) {

            $items = array();


            foreach ( $package_items as $key => $package_item ) {

                $qty = $package_item[ 'quantity' ];

                for ( $index = 0; $index < $qty; $index++ ) {
                    
                    $index_key = $key . '_' . $index;
                    
                    $items[ $index_key ][ $key ] = $package_item;

                    $items[ $index_key ][ $key ][ 'line_subtotal' ] = $package_item[ 'line_price' ];
                    $items[ $index_key ][ $key ][ 'line_subtotal_tax' ] = $package_item[ 'line_price_tax' ];

                    $items[ $index_key ][ $key ][ 'line_total' ] = $package_item[ 'line_total_price' ];
                    $items[ $index_key ][ $key ][ 'line_tax' ] = $package_item[ 'line_total_price_tax' ];

                    $items[ $index_key ][ $key ][ 'quantity' ] = 1;
                }
            }

            return $items;
        }

        private function group_by_line( $package_items ) {

            $items = array();

            foreach ( $package_items as $key => $package_item ) {
                $items[ $key ][ $key ] = $package_item;
            }

            return $items;
        }

        private function group_by_product( $package_items ) {

            $items = array();

            foreach ( $package_items as $key => $package_item ) {

                $group_key = $package_item[ 'product_id' ];

                $items[ $group_key ][ $key ] = $package_item;
            }

            return $items;
        }

        private function group_by_category( $package_items ) {
            $items = array();

            foreach ( $package_items as $key => $package_item ) {

                $group_key = 0;
                if ( count( $package_item[ 'data' ][ 'category_ids' ] ) ) {
                    $group_key = $package_item[ 'data' ][ 'category_ids' ][ 0 ];
                }

                $items[ $group_key ][ $key ] = $package_item;
            }

            return $items;
        }

        private function group_by_shipping_class( $package_items ) {

            $items = array();

            foreach ( $package_items as $key => $package_item ) {

                $group_key = $package_item[ 'data' ][ 'shipping_class_id' ];

                $items[ $group_key ][ $key ] = $package_item;
            }


            return $items;
        }

        private function filter_packages( $data, $product_filters ) {

            $package_items = WTARS_Shipped_Product_Filter_Types::get_package_items( $data, $product_filters, true );

            return $package_items;
        }

        private function remove_extra_data( $package_items ) {

            $keys = array_keys( $package_items );

            foreach ( $keys as $key ) {

                if ( isset( $package_items[ $key ][ 'data' ] ) ) {

                    unset( $package_items[ $key ][ 'data' ] );
                }
            }

            return $package_items;
        }

    }

}