<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium_Package' ) ) {

    class WTARS_Shipped_Premium_Package {

        private static $instance = null;
        private $package_data = array();

        private static function get_instance() {
            if ( null == self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public static function get_data( $package ) {

            return self::get_instance()->get_all_data( $package );
        }

        private function get_all_data( $package ) {
            $hash_key = $this->get_hash_key( $package );


            if ( isset( $this->package_data[ $hash_key ] ) ) {

                return $this->package_data[ $hash_key ];
            }

            if ( !$package ) {

                return false;
            }

            $this->package_data[ $hash_key ] = $this->get_contents_data( array(), $package );

            return $this->package_data[ $hash_key ];
        }

        private function get_contents_data( $package_data, $package ) {

            $package_data[ 'items' ] = array();

            foreach ( $package[ 'contents' ] as $key => $item ) {

                $package_data[ 'items' ][ $key ] = $this->get_item( $item );
            }

            return $this->get_destination( $package_data, $package );
        }

        private function get_item( $package_item ) {

            $item = array(
                'key' => $package_item[ 'product_id' ] . '_' . $package_item[ 'variation_id' ],
                'product_id' => $package_item[ 'product_id' ],
                'variation_id' => $package_item[ 'variation_id' ],
                'quantity' => $package_item[ 'quantity' ],
                'line_price' => ($package_item[ 'line_subtotal' ] > 0) ? ($package_item[ 'line_subtotal' ] / $package_item[ 'quantity' ]) : 0,
                'line_price_tax' => ($package_item[ 'line_subtotal_tax' ] > 0) ? ($package_item[ 'line_subtotal_tax' ] / $package_item[ 'quantity' ]) : 0,
                'line_total_price' => ($package_item[ 'line_total' ] > 0) ? ($package_item[ 'line_total' ] / $package_item[ 'quantity' ]) : 0,
                'line_total_price_tax' => ($package_item[ 'line_tax' ] > 0) ? ($package_item[ 'line_tax' ] / $package_item[ 'quantity' ]) : 0,
                'line_subtotal' => $package_item[ 'line_subtotal' ],
                'line_subtotal_tax' => $package_item[ 'line_subtotal_tax' ],
                'line_total' => isset( $package_item[ 'line_total' ] ) ? $package_item[ 'line_total' ] : $package_item[ 'line_subtotal' ],
                'line_tax' => isset( $package_item[ 'line_tax' ] ) ? $package_item[ 'line_tax' ] : $package_item[ 'line_subtotal_tax' ],
            );

            if ( has_filter( 'wtars_shipped/get-package-item' ) ) {
                $item = apply_filters( 'wtars_shipped/get-package-item', $item, $package_item );
            }

            return $item;
        }

        private function get_destination( $package_data, $package ) {

            $package_data[ 'destination' ] = $package[ 'destination' ];

            if ( has_filter( 'wtars_shipped/get-package-destination' ) ) {
                $package_data[ 'package_cost' ] = apply_filters( 'wtars_shipped/get-package-destination', $package_data[ 'destination' ], $package );
            }

            return $package_data;
        }

        private function get_hash_key( $package ) {

            return wp_json_encode( md5( wp_json_encode( $package ) ) );
        }

    }

}
