<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Weight_Calculator' ) ) {

    class WTARS_Shipped_Weight_Calculator {

        public function get_total_weight( $package_items, $weight_args ) {

            $total_weight = 0;

            foreach ( $package_items as $package_item ) {
                $total_weight += $this->get_item_weight( $package_item, $weight_args );
            }

            return $total_weight;
        }

        public function get_item_weight( $package_item, $weight_args ) {

            $option = $this->get_options( $weight_args[ 'option_id' ], $weight_args[ 'instance_id' ] );

            $original_weight = $this->get_original_weight( $package_item, $option[ 'round_weight' ] );

            if ( 'no' == $option[ 'formula' ] ) {

                return $original_weight;
            }

            $calc_weight = $this->get_calculate_weight( $package_item, $option );

            if ( 'no' == $option[ 'compare_weights' ] ) {
                return $calc_weight;
            }

            if ( $calc_weight > $original_weight ) {
                return $calc_weight;
            }

            return $original_weight;
        }

        private function get_calculate_weight( $package_item, $option ) {

            $dimensions = $this->get_dimensions( $package_item, $option[ 'round_measurements' ] );

            $volume = ($dimensions[ 'length' ] * $dimensions[ 'width' ]) * $dimensions[ 'height' ];

            $weight = 0;

            if ( $volume <= 0 ) {
                return $weight;
            }

            $dim_factor = $option[ 'dim_factor' ];

            if ( !is_numeric( $dim_factor ) || $dim_factor <= 0 ) {
                return $weight;
            }

            if ( 'divide' == $option[ 'formula' ] ) {
                $weight = $this->round_number( ($volume / $dim_factor ), $option[ 'round_weight' ] );
            }

            if ( 'multiply' == $option[ 'formula' ] ) {
                $weight = $this->round_number( ($volume * $dim_factor ), $option[ 'round_weight' ] );
            }

            return $weight * $package_item[ 'quantity' ];
        }

        private function get_original_weight( $package_item, $round_mode ) {

            if ( !isset( $package_item[ 'data' ][ 'weight' ] ) ) {

                return 0;
            }

            if ( !is_numeric( $package_item[ 'data' ][ 'weight' ] ) ) {

                return 0;
            }

            $weight = $this->round_number( $package_item[ 'data' ][ 'weight' ], $round_mode );

            return $weight * $package_item[ 'quantity' ];
        }

        private function get_dimensions( $package_item, $round_mode ) {

            if ( !isset( $package_item[ 'data' ][ 'dimensions' ] ) ) {

                return array(
                    'length' => 0,
                    'width' => 0,
                    'height' => 0,
                );
            }

            $dimensions = $package_item[ 'data' ][ 'dimensions' ];

            if ( !isset( $dimensions[ 'length' ] ) || !is_numeric( $dimensions[ 'length' ] ) ) {
                $dimensions[ 'length' ] = 0;
            }

            if ( !isset( $dimensions[ 'width' ] ) || !is_numeric( $dimensions[ 'width' ] ) ) {
                $dimensions[ 'width' ] = 0;
            }

            if ( !isset( $dimensions[ 'height' ] ) || !is_numeric( $dimensions[ 'height' ] ) ) {
                $dimensions[ 'height' ] = 0;
            }

            $dimensions[ 'length' ] = $this->round_number( $dimensions[ 'length' ], $round_mode );
            $dimensions[ 'width' ] = $this->round_number( $dimensions[ 'width' ], $round_mode );
            $dimensions[ 'height' ] = $this->round_number( $dimensions[ 'height' ], $round_mode );

            return $dimensions;
        }

        private function round_number( $weight, $round_mode ) {

            if ( 'round_up_whole' == $round_mode ) {
                return ceil( $weight / 1 ) * 1;
            }

            if ( 'round_down_whole' == $round_mode ) {
                return floor( $weight / 1 ) * 1;
            }

            if ( 'round_whole' == $round_mode ) {
                return round( $weight / 1 ) * 1;
            }

            if ( 'round_up_half' == $round_mode ) {
                return ceil( $weight / 0.5 ) * 0.5;
            }

            if ( 'round_down_half' == $round_mode ) {
                return floor( $weight / 0.5 ) * 0.5;
            }

            if ( 'round_half' == $round_mode ) {
                return round( $weight / 0.5 ) * 0.5;
            }

            return $weight;
        }

        private function get_options( $option_id, $instance_id ) {

            $options = WTARS_Shipped::get_option( 'weight_calcs', $instance_id, $this->get_defaults() );

            foreach ( $options as $option ) {

                if ( $option_id == $option[ 'option_id' ] ) {
                    return $option;
                }
            }

            if ( count( $options ) ) {
                return $options[ 0 ];
            }

            return array();
        }

        private function get_defaults() {

            return array(
                array(
                    'option_id' => '2234343',
                    'formula' => 'no',
                    'round_weight' => 'no',
                ),
                array(
                    'option_id' => '2234344',
                    'formula' => 'no',
                    'round_weight' => 'no',
                )
            );
        }

    }

}