<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Premium' ) ) {
    require_once dirname( __FILE__ ) . '/utils/shipped-utils.php';
    require_once dirname( __FILE__ ) . '/shipped-cart.php';
    require_once dirname( __FILE__ ) . '/shipped-package.php';
    require_once dirname( __FILE__ ) . '/shipped-groups.php';
    require_once dirname( __FILE__ ) . '/shipped-cache.php';
    require_once dirname( __FILE__ ) . '/shipped-weight-calculator.php';

    require_once dirname( __FILE__ ) . '/modules/shipping-rates/shipping-rates.php';
    require_once dirname( __FILE__ ) . '/modules/cart-fees/cart-fees.php';
    require_once dirname( __FILE__ ) . '/modules/checkout-messages/checkout-messages.php';

    require_once dirname( __FILE__ ) . '/condition-types/condition-types.php';
    require_once dirname( __FILE__ ) . '/product-filter-types/product-filter-types.php';
    require_once dirname( __FILE__ ) . '/cost-types/cost-types.php';
    require_once dirname( __FILE__ ) . '/parameter-types/parameter-types.php';
    require_once dirname( __FILE__ ) . '/total-types/total-types.php';

    class WTARS_Shipped_Premium {

        private $shipping_rates;
        private $cart_fees;

        public function __construct() {

            new WTARS_Shipped_Premium_Shipping_Rates_Engine( true );

            $this->shipping_rates = new WTARS_Shipped_Premium_Shipping_Rates();
            $this->cart_fees = new WTARS_Shipped_Premium_Cart_Fees();

            add_filter( 'woocommerce_shipping_wtars_shipped_is_available', array( $this, 'shipping_is_available' ), 10, 3 );

            add_filter( 'wtars_shipped/process-cart-fees', array( $this, 'shipped_process_fees' ), 10, 3 );

            add_action( 'woocommerce_cart_calculate_fees', array( $this, 'calculate_fees' ), 100, 1 );
            add_filter( 'woocommerce_cart_totals_get_fees_from_cart_taxes', array( $this, 'get_fee_taxes' ), 100, 3 );
            add_filter( 'woocommerce_cart_totals_fee_html', array( $this, 'get_fee_html' ), 100, 2 );
            add_filter( 'woocommerce_sort_fees_callback', array( $this, 'sort_fees_callback' ), 999999, 3 );
        }

        public function shipping_is_available( $is_available, $package, $shipping_method ) {

            $instance_id = $shipping_method->get_instance_id();

            //process all data 
            $data = WTARS_Shipped::process_data( $package, $instance_id );

            //set availability
            return $this->shipping_rates->get_is_available( $is_available, $instance_id, $data );
        }

        public function shipped_process_fees( $package, $data, $instance_id ) {
            return $this->cart_fees->process_fees( $package, $data, $instance_id );
        }

        public function calculate_fees( $cart ) {

            if ( is_admin() && !defined( 'DOING_AJAX' ) ) {
                return;
            }

            // apply fee taxes (if applicable)
            $this->cart_fees->apply_cart_fees();
        }

        public function get_fee_taxes( $fee_taxes, $fee, $cart_totals ) {

            // apply fee taxes (if applicable)
            return $this->cart_fees->get_taxes( $fee_taxes, $fee->object->id );
        }

        public function get_fee_html( $fee_html, $fee ) {

            // apply fee html (if applicable)
            return $this->cart_fees->get_fee_html( $fee_html, $fee->id );
        }

        public function sort_fees_callback( $a_g_b, $a, $b ) {

            if ( is_admin() && !defined( 'DOING_AJAX' ) ) {
                return;
            }

            $sort_order = array( 'a' => 0, 'b' => 0 );

            // get fees sort order (if applicable)
            $f_sort_order = $this->cart_fees->get_sort_order( $sort_order, $a, $b );


            // apply sort orders
            if ( $f_sort_order[ 'a' ] < $f_sort_order[ 'b' ] ) {
                return -1;
            }
            if ( $f_sort_order[ 'b' ] < $f_sort_order[ 'a' ] ) {
                return 1;
            }


            return $a_g_b;
        }

    }

    new WTARS_Shipped_Premium();
}