<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Customer_Util' ) ) {

    require_once dirname( __FILE__ ) . '/order-history-utils/order-history-util.php';
    require_once dirname( __FILE__ ) . '/order-history-utils/order-history-posts-util.php';
    require_once dirname( __FILE__ ) . '/order-history-utils/order-history-hpos-util.php';

    class WTARS_Shipped_Customer_Util {

        private static $users = array();
        private static $data_store_key = 'wtars_shipped';
        private static $data_store = array();

        public static function get_is_logged_in( $data ) {

            if ( !isset( $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'id' ] ) ) {
                return false;
            }

            $user_id = $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'id' ];

            return ($user_id > 0);
        }

        public static function get_user_email( $data ) {

            if ( !isset( $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'email' ] ) ) {
                return '';
            }

            return $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'email' ];
        }

        public static function get_user_roles( $data ) {

            $user = self::get_user_by( $data );

            if ( !$user ) {
                return array();
            }

            return $user->roles;
        }

        public static function get_user_meta( $data, $meta_key, $default = array() ) {

            if ( !isset( $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'id' ] ) ) {
                return $default;
            }

            $user_id = $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'id' ];

            if ( 0 >= $user_id ) {
                return $default;
            }

            return self::get_meta( $user_id, $meta_key, $default );
        }

        public static function get_user_caps( $data ) {

            $user_caps = array();

            $user = self::get_user_by( $data );

            if ( !$user ) {
                return $user_caps;
            }

            foreach ( $user->allcaps as $key => $user_cap ) {

                if ( $user_cap == true ) {
                    $user_caps[] = $key;
                }
            }

            return $user_caps;
        }

        public static function get_coupon_used( $data, $from_date, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $data_key = 'coupons_used_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {

                return self::$data_store[ $data_key ];
            }

            $coupons_used = self::get_data( $user_id, $data_key, false );

            if ( is_array( $coupons_used ) ) {

                return $coupons_used;
            }

            $order_history = WTARS_Shipped_Order_History_Util::get_instance();

            $coupons_used = $order_history->get_coupon_used( $user_id, $from_date, array() );

            self::$data_store[ $data_key ] = $coupons_used;

            self::store_data( $user_id, $data_key, $coupons_used, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $coupons_used;
        }

        public static function get_order_total( $data, $from_date, $total_type, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return 0;
            }

            $data_key = 'order_total_' . strtolower( $total_type ) . '_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {
                return self::$data_store[ $data_key ];
            }

            $order_total = self::get_data( $user_id, $data_key, -1 );

            if ( 0 <= $order_total ) {

                return $order_total;
            }

            $order_history = WTARS_Shipped_Order_History_Util::get_instance();

            $order_total = $order_history->get_order_total( $user_id, $from_date, $total_type, 0 );

            self::$data_store[ $data_key ] = $order_total;

            self::store_data( $user_id, $data_key, $order_total, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $order_total;
        }

        public static function get_last_order_date( $data ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return '';
            }

            $data_key = 'last_order_date';

            if ( isset( self::$data_store[ $data_key ] ) ) {

                return self::$data_store[ $data_key ];
            }

            $last_order_date = self::get_data( $user_id, $data_key, false );

            if ( false !== $last_order_date ) {

                return $last_order_date;
            }

            $order_history = WTARS_Shipped_Order_History_Util::get_instance();

            $last_order_date = $order_history->get_last_order_date( $user_id, '' );

            self::$data_store[ $data_key ] = $last_order_date;

            self::store_data( $user_id, $data_key, $last_order_date, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $last_order_date;
        }

        public static function get_last_order_totals( $data ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return 0;
            }

            $data_key = 'last_order_totals';

            if ( isset( self::$data_store[ $data_key ] ) ) {

                return self::$data_store[ $data_key ];
            }

            $last_order_totals = self::get_data( $user_id, $data_key, -1 );

            if ( 0 <= $last_order_totals ) {

                return $last_order_totals;
            }

            $order_history = WTARS_Shipped_Order_History_Util::get_instance();

            $last_order_totals = $order_history->get_last_order_totals( $user_id, 0 );

            self::$data_store[ $data_key ] = $last_order_totals;

            self::store_data( $user_id, $data_key, $last_order_totals, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $last_order_totals;
        }

        public static function get_reviews_count( $data, $from_date, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return 0;
            }

            $data_key = 'reviews_count_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {
                return self::$data_store[ $data_key ];
            }

            $reviews_count = self::get_data( $user_id, $data_key, -1 );

            if ( 0 <= $reviews_count ) {

                return $reviews_count;
            }

            $reviews_count = 0;


            try {

                global $wpdb;

                $sql = "SELECT COUNT(comment_ID) FROM {$wpdb->prefix}comments"
                        . " WHERE (user_id = " . esc_sql( $user_id ) . ")"
                        . " AND (comment_approved = 1)"
                        . " AND (comment_type = 'review')";

                if ( $from_date != '' ) {
                    $sql = $sql . " AND (comment_date >= '" . esc_sql( $from_date ) . "')";
                }


                $results = $wpdb->get_var( $sql );

                if ( $results ) {

                    $reviews_count = $results;
                }

                self::$data_store[ $data_key ] = $reviews_count;

                self::store_data( $user_id, $data_key, $reviews_count, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );
            } catch ( Exception $ex ) {

                return $reviews_count;
            }

            return $reviews_count;
        }

        public static function get_purchased_products( $data, $from_date, $product_ids, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $data_key = 'purchased_products_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {
                return self::$data_store[ $data_key ];
            }

            $products = array();


            $history_data = self::get_history_data( $user_id, $from_date, $hash_key );


            foreach ( $history_data as $data ) {
                if ( WTARS_Shipped_Validation_Util::validate_value_list( $data[ 'product_id' ], $product_ids, 'in_list' ) != true ) {
                    continue;
                }
                $products[] = $data;
            }

            self::$data_store[ $data_key ] = $products;

            return $products;
        }

        public static function get_purchased_variations( $data, $from_date, $variation_ids, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $data_key = 'purchased_variations_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {
                return self::$data_store[ $data_key ];
            }

            $products = array();


            $history_data = self::get_history_data( $user_id, $from_date, $hash_key );

            foreach ( $history_data as $data ) {

                if ( 0 >= $data[ 'variation_id' ] ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_value_list( $data[ 'variation_id' ], $variation_ids, 'in_list' ) != true ) {
                    continue;
                }
                $products[] = $data;
            }

            self::$data_store[ $data_key ] = $products;

            return $products;
        }

        public static function get_purchased_terms( $data, $from_date, $term_ids, $taxonomy, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $products = array();

            $history_data = self::get_history_data( $user_id, $from_date, $hash_key );

            if ( !count( $history_data ) ) {
                return $products;
            }

            $product_ids = array();

            foreach ( $history_data as $history_prod ) {

                if ( in_array( $history_prod[ 'product_id' ], $product_ids ) ) {
                    continue;
                }

                $product_ids[] = $history_prod[ 'product_id' ];
            }

            $product_terms = false;

            $data_key = 'products_terms_' . $taxonomy . '_' . $hash_key;

            if ( !$product_terms && isset( self::$data_store[ $data_key ] ) ) {
                $product_terms = self::$data_store[ $data_key ];
            }

            if ( !$product_terms ) {

                $product_terms = self::get_data( $user_id, $data_key, false );
            }

            if ( !$product_terms ) {

                $product_terms = WTARS_Shipped_Product_Util::get_terms_by_product_ids( $product_ids, $taxonomy );

                self::$data_store[ $data_key ] = $product_terms;

                self::store_data( $user_id, $data_key, $product_terms, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );
            }

            foreach ( $history_data as $data ) {

                $product_id = $data[ 'product_id' ];

                if ( !isset( $product_terms[ $product_id ] ) ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_list_list( $product_terms[ $product_id ], $term_ids, 'in_list' ) != true ) {
                    continue;
                }

                $products[] = $data;
            }

            return $products;
        }

        public static function get_purchased_attributes( $data, $from_date, $attribute_ids, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $products = array();

            $history_data = self::get_history_data( $user_id, $from_date, $hash_key );

            if ( !count( $history_data ) ) {
                return $products;
            }

            $product_ids = array();

            foreach ( $history_data as $history_prod ) {

                if ( in_array( $history_prod[ 'product_id' ], $product_ids ) ) {
                    continue;
                }

                $product_ids[] = $history_prod[ 'product_id' ];
            }

            $product_attributes = false;

            $data_key = 'products_attributes_' . $hash_key;

            if ( !$product_attributes && isset( self::$data_store[ $data_key ] ) ) {
                $product_attributes = self::$data_store[ $data_key ];
            }

            if ( !$product_attributes ) {

                $product_attributes = self::get_data( $user_id, $data_key, false );
            }

            if ( !$product_attributes ) {

                $product_attributes = WTARS_Shipped_Product_Util::get_attributes_by_product_ids( $product_ids );

                self::$data_store[ $data_key ] = $product_attributes;

                self::store_data( $user_id, $data_key, $product_attributes, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );
            }

            foreach ( $history_data as $data ) {

                $product_id = $data[ 'product_id' ];

                if ( !isset( $product_attributes[ $product_id ] ) ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_list_list( $product_attributes[ $product_id ], $attribute_ids, 'in_list' ) != true ) {
                    continue;
                }

                $products[] = $data;
            }

            return $products;
        }

        public static function get_purchased_product_ids( $data, $from_date, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $data_key = 'purchased_product_ids_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {
                return self::$data_store[ $data_key ];
            }

            $purchased_products = self::get_data( $user_id, $data_key, false );

            if ( $purchased_products ) {

                return $purchased_products;
            }

            $purchased_products = array();

            $history_data = self::get_history_data( $user_id, $from_date, $hash_key );


            foreach ( $history_data as $product ) {

                if ( in_array( $product[ 'product_id' ], $purchased_products ) ) {
                    continue;
                }

                $purchased_products[] = $product[ 'product_id' ];
            }

            self::$data_store[ $data_key ] = $purchased_products;

            self::store_data( $user_id, $data_key, $purchased_products, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $purchased_products;
        }

        public static function get_purchased_variation_ids( $data, $from_date, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $data_key = 'purchased_variation_ids_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {
                return self::$data_store[ $data_key ];
            }

            $purchased_variations = self::get_data( $user_id, $data_key, false );

            if ( $purchased_variations ) {

                return $purchased_variations;
            }

            $purchased_variations = array();

            $history_data = self::get_history_data( $user_id, $from_date, $hash_key );


            foreach ( $history_data as $product ) {

                if ( in_array( $product[ 'variation_id' ], $purchased_variations ) ) {
                    continue;
                }

                if ( 0 >= $product[ 'variation_id' ] ) {
                    continue;
                }

                $purchased_variations[] = $product[ 'variation_id' ];
            }

            self::$data_store[ $data_key ] = $purchased_variations;

            self::store_data( $user_id, $data_key, $purchased_variations, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $purchased_variations;
        }

        public static function get_purchased_term_ids( $data, $from_date, $taxonomy, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $data_key = 'purchased_term_ids_' . $taxonomy . '_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {
                return self::$data_store[ $data_key ];
            }

            $purchased_terms = self::get_data( $user_id, $data_key, false );

            if ( $purchased_terms ) {

                return $purchased_terms;
            }

            $purchased_terms = array();

            $product_ids = self::get_history_data_ids( $user_id, $from_date, $hash_key );

            if ( !count( $product_ids ) ) {
                return $purchased_terms;
            }

            $product_terms = WTARS_Shipped_Product_Util::get_terms_by_product_ids( $product_ids, $taxonomy );

            foreach ( $product_terms as $product_term ) {

                foreach ( $product_term as $term ) {
                    if ( in_array( $term, $purchased_terms ) ) {
                        continue;
                    }
                    $purchased_terms[] = $term;
                }
            }

            self::$data_store[ $data_key ] = $purchased_terms;

            self::store_data( $user_id, $data_key, $purchased_terms, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $purchased_terms;
        }

        public static function get_purchased_attribute_ids( $data, $from_date, $hash_key ) {

            $user_id = self::get_user_id( $data );

            if ( 0 >= $user_id ) {

                return array();
            }

            $data_key = 'purchased_attr_ids_' . '_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {
                return self::$data_store[ $data_key ];
            }

            $purchased_attributes = self::get_data( $user_id, $data_key, false );

            if ( $purchased_attributes ) {

                return $purchased_attributes;
            }

            $purchased_attributes = array();

            $product_ids = self::get_history_data_ids( $user_id, $from_date, $hash_key );

            if ( !count( $product_ids ) ) {
                return $purchased_attributes;
            }

            $product_attributes = WTARS_Shipped_Product_Util::get_attributes_by_product_ids( $product_ids );

            foreach ( $product_attributes as $product_attribute ) {

                foreach ( $product_attribute as $attribute ) {
                    if ( in_array( $attribute, $purchased_attributes ) ) {
                        continue;
                    }
                    $purchased_attributes[] = $attribute;
                }
            }

            self::$data_store[ $data_key ] = $purchased_attributes;

            self::store_data( $user_id, $data_key, $purchased_attributes, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $purchased_attributes;
        }

        private static function get_history_data_ids( $user_id, $from_date, $hash_key ) {

            $product_ids = array();

            $history_data = self::get_history_data( $user_id, $from_date, $hash_key );

            foreach ( $history_data as $product ) {

                if ( in_array( $product[ 'product_id' ], $product_ids ) ) {
                    continue;
                }

                $product_ids[] = $product[ 'product_id' ];
            }

            return $product_ids;
        }

        private static function get_history_data( $user_id, $from_date, $hash_key ) {

            if ( 0 >= $user_id ) {

                return array();
            }

            $data_key = 'history_data_' . $hash_key;

            if ( isset( self::$data_store[ $data_key ] ) ) {

                return self::$data_store[ $data_key ];
            }

            $history_data = self::get_data( $user_id, $data_key, false );

            if ( false !== $history_data ) {

                return $history_data;
            }

            $order_history = WTARS_Shipped_Order_History_Util::get_instance();

            $history_data = $order_history->get_history_data( $user_id, $from_date, array() );

            self::$data_store[ $data_key ] = $history_data;

            self::store_data( $user_id, $data_key, $history_data, current_time( 'U' ) + (MINUTE_IN_SECONDS * 30) );

            return $history_data;
        }

        private static function get_data( $user_id, $data_key, $default ) {

            $data_store = self::get_meta( $user_id, self::$data_store_key, array() );

            if ( !isset( $data_store[ $data_key ] ) ) {

                return $default;
            }

            $store_time = $data_store[ $data_key . '_expires' ];

            if ( $store_time <= current_time( 'U' ) ) {

                unset( $data_store[ $data_key ] );
                unset( $data_store[ $data_key . '_expires' ] );

                update_user_meta( $user_id, self::$data_store_key, $data_store );

                return $default;
            }

            return $data_store[ $data_key ];
        }

        private static function store_data( $user_id, $data_key, $data_value, $expiration = 0 ) {

            $data_store = self::get_meta( self::$data_store_key, array() );

            $data_store[ $data_key ] = $data_value;

            $data_store[ $data_key . '_expires' ] = $expiration;

            update_user_meta( $user_id, self::$data_store_key, $data_store );
        }

        private static function get_meta( $user_id, $meta_key, $default = array() ) {

            $user_meta = get_user_meta( $user_id, $meta_key, true );

            if ( !$user_meta ) {

                return $default;
            }

            return $user_meta;
        }

        private static function get_user_id( $data ) {

            if ( !isset( $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'id' ] ) ) {
                return 0;
            }

            return $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'id' ];
        }

        private static function get_user_by( $data ) {

            if ( !isset( $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'id' ] ) ) {
                return false;
            }

            $user_id = $data[ 'wc' ][ 'cart' ][ 'customer' ][ 'id' ];

            if ( 0 >= $user_id ) {
                return false;
            }

            if ( isset( self::$users[ $user_id ] ) ) {

                return self::$users[ $user_id ];
            }

            $user = get_user_by( 'id', $user_id );

            if ( $user ) {
                self::$users[ $user_id ] = $user;
            }

            return $user;
        }

    }

}
