<?php

if ( !class_exists( 'WTARS_Shipped_Order_Util' ) ) {

    class WTARS_Shipped_Order_Util {

        public static function get_package_product_ids( $data ) {

            $product_ids = array();

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return $product_ids;
            }

            foreach ( $data[ 'wc' ][ 'package' ][ 'items' ] as $package_item ) {

                if ( isset( $package_item[ 'product_id' ] ) && 0 < $package_item[ 'product_id' ] ) {
                    $product_ids[] = $package_item[ 'product_id' ];
                }
            }

            return $product_ids;
        }

        public static function get_package_variation_ids( $data ) {
            $variation_ids = array();

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return $variation_ids;
            }

            foreach ( $data[ 'wc' ][ 'package' ][ 'items' ] as $package_item ) {

                if ( isset( $package_item[ 'variation_id' ] ) && 0 < $package_item[ 'variation_id' ] ) {
                    $variation_ids[] = $package_item[ 'variation_id' ];
                }
            }

            return $variation_ids;
        }

        public static function get_package_category_ids( $data ) {

            $category_ids = array();

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return $category_ids;
            }

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'category_ids' ] ) ) {
                    continue;
                }

                foreach ( $package_item[ 'data' ][ 'category_ids' ] as $category_id ) {
                    if ( !in_array( $category_id, $category_ids ) ) {
                        $category_ids[] = $category_id;
                    }
                }
            }

            return $category_ids;
        }

        public static function get_package_tag_ids( $data ) {
            $tag_ids = array();

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return $tag_ids;
            }

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'tag_ids' ] ) ) {
                    continue;
                }

                foreach ( $package_item[ 'data' ][ 'tag_ids' ] as $tag_id ) {
                    if ( !in_array( $tag_id, $tag_ids ) ) {
                        $tag_ids[] = $tag_id;
                    }
                }
            }

            return $tag_ids;
        }

        public static function get_package_attribute_ids( $data ) {

            $attribute_ids = array();

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return $attribute_ids;
            }

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'attribute_ids' ] ) ) {
                    continue;
                }

                foreach ( $package_item[ 'data' ][ 'attribute_ids' ] as $attribute_id ) {

                    if ( !in_array( $attribute_id, $attribute_ids ) ) {

                        $attribute_ids[] = $attribute_id;
                    }
                }
            }

            return $attribute_ids;
        }

        public static function get_package_tax_classes( $data ) {

            $tax_classes = array();

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return $tax_classes;
            }

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'tax_status' ] ) || !isset( $package_item[ 'data' ][ 'tax_class' ] ) ) {
                    continue;
                }

                $tax_class = $package_item[ 'data' ][ 'tax_class' ];
                $tax_status = $package_item[ 'data' ][ 'tax_status' ];
                if ( 'none' == $tax_status ) {
                    continue;
                }
                if ( '' == $tax_class ) {
                    $tax_class = '--0';
                }
                if ( !in_array( $tax_class, $tax_classes ) ) {
                    $tax_classes[] = $tax_class;
                }
            }

            return $tax_classes;
        }

        public static function get_package_shipping_classes( $data ) {

            $shipping_classes = array();

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return $shipping_classes;
            }

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'shipping_class_id' ] ) ) {
                    continue;
                }

                $shipping_class = $package_item[ 'data' ][ 'shipping_class_id' ];

                if ( 0 < $shipping_class ) {
                    $shipping_classes[] = $shipping_class;
                }
            }

            return $shipping_classes;
        }

        public static function get_package_product_metas( $data, $meta_key ) {

            $product_metas = array();

            if ( !isset( $data[ 'wc' ][ 'package' ][ 'items' ] ) ) {
                return $product_metas;
            }

            $product_ids = array();

            foreach ( $data[ 'wc' ][ 'package' ][ 'items' ] as $key => $package_item ) {

                $product_ids[ $key ] = $package_item[ 'product_id' ];
            }

            $metas = WTARS_Shipped_Product_Util::get_metas_by_ids( $product_ids, $meta_key );

            foreach ( $metas as $meta ) {
                $product_metas[] = $meta;
            }

            return $product_metas;
        }

        public static function get_package_items_by_ids( $data, $product_ids ) {

            $package_items = array();

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'product_id' ] ) ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_value_list( $package_item[ 'product_id' ], $product_ids, 'in_list' ) != true ) {
                    continue;
                }

                $package_items[] = $package_item;
            }

            return $package_items;
        }

        public static function get_package_items_by_variation_ids( $data, $variation_ids ) {

            $package_items = array();

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'variation_id' ] ) || 0 >= $package_item[ 'variation_id' ] ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_value_list( $package_item[ 'variation_id' ], $variation_ids, 'in_list' ) != true ) {
                    continue;
                }

                $package_items[] = $package_item;
            }

            return $package_items;
        }

        public static function get_package_items_by_category_ids( $data, $category_ids ) {

            $package_items = array();

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'category_ids' ] ) ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_list_list( $package_item[ 'data' ][ 'category_ids' ], $category_ids, 'in_list' ) != true ) {
                    continue;
                }

                $package_items[] = $package_item;
            }

            return $package_items;
        }

        public static function get_package_items_by_tag_ids( $data, $category_ids ) {

            $package_items = array();

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'tag_ids' ] ) ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_list_list( $package_item[ 'data' ][ 'tag_ids' ], $category_ids, 'in_list' ) != true ) {
                    continue;
                }

                $package_items[] = $package_item;
            }

            return $package_items;
        }

        public static function get_package_items_by_attribute_ids( $data, $attribute_ids ) {

            $package_items = array();

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'attribute_ids' ] ) ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_list_list( $package_item[ 'data' ][ 'attribute_ids' ], $attribute_ids, 'in_list' ) != true ) {
                    continue;
                }

                $package_items[] = $package_item;
            }

            return $package_items;
        }

        public static function get_package_items_by_tax_classes( $data, $tax_classes ) {

            $package_items = array();

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'tax_status' ] ) || !isset( $package_item[ 'data' ][ 'tax_class' ] ) ) {
                    continue;
                }

                $tax_class = $package_item[ 'data' ][ 'tax_class' ];
                $tax_status = $package_item[ 'data' ][ 'tax_status' ];
                if ( 'none' == $tax_status ) {
                    continue;
                }

                if ( '' == $tax_class ) {
                    $tax_class = '--0';
                }

                if ( WTARS_Shipped_Validation_Util::validate_value_list( $tax_class, $tax_classes, 'in_list' ) != true ) {
                    continue;
                }

                $package_items[] = $package_item;
            }

            return $package_items;
        }

        public static function get_package_items_by_shipping_class_ids( $data, $shipping_class_id ) {

            $package_items = array();

            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'data' ][ 'shipping_class_id' ] ) ) {
                    continue;
                }

                $item_shipping_class_id = $package_item[ 'data' ][ 'shipping_class_id' ];

                if ( 0 >= $item_shipping_class_id ) {
                    continue;
                }

                if ( WTARS_Shipped_Validation_Util::validate_value_list( $item_shipping_class_id, $shipping_class_id, 'in_list' ) != true ) {
                    continue;
                }

                $package_items[] = $package_item;
            }

            return $package_items;
        }

        public static function get_package_items_by_meta( $data, $meta_key, $meta_value ) {

            $package_items = array();

            $product_metas = WTARS_Shipped_Product_Util::get_metas_by_ids( self::get_package_product_ids( $data ), $meta_key );
            
            foreach ( self::get_package_items( $data ) as $package_item ) {

                if ( !isset( $package_item[ 'product_id' ] ) ) {
                    continue;
                }

                $product_id = $package_item[ 'product_id' ];

                if ( !isset( $product_metas[ $product_id ] ) ) {
                    continue;
                }

                $product_meta = $product_metas[ $product_id ];

                if ( WTARS_Shipped_Validation_Util::validate_value( '==', $product_meta, $meta_value ) != true ) {
                    continue;
                }

                $package_items[] = $package_item;
            }

            return $package_items;
        }

        private static function get_package_items( $data ) {

            return WTARS_Shipped_Product_Filter_Types::get_package_items( $data, array(), true );
        }

    }

}