<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}


if ( !class_exists( 'WTARS_Shipped_Product_Util' ) ) {

    class WTARS_Shipped_Product_Util {

        private static $product_user_ids = array();
        private static $users = array();

        public static function get_terms_by_product_ids( $product_ids, $taxonomy ) {

            $product_terms = array();

            try {
                global $wpdb;

                $sql = "SELECT term_relationships.object_id AS post_id, terms.term_id"
                        . " FROM {$wpdb->prefix}term_relationships AS term_relationships"
                        . " LEFT JOIN {$wpdb->prefix}term_taxonomy AS term_taxonomy ON term_relationships.term_taxonomy_id = term_taxonomy.term_taxonomy_id"
                        . " LEFT JOIN {$wpdb->prefix}terms AS terms ON terms.term_id = term_taxonomy.term_id"
                        . " WHERE (term_relationships.object_id IN (" . implode( ',', array_map( 'esc_sql', $product_ids ) ) . "))"
                        . " AND (term_taxonomy.taxonomy='" . esc_sql( $taxonomy ) . "')";


                $results = $wpdb->get_results( $sql, ARRAY_A );

                foreach ( $results as $row ) {

                    if ( !isset( $product_terms[ $row[ 'post_id' ] ] ) ) {

                        $product_terms[ $row[ 'post_id' ] ] = array();
                    }

                    $product_terms[ $row[ 'post_id' ] ][] = $row[ 'term_id' ];
                }

                return $product_terms;
            } catch ( Exception $ex ) {

                return $product_terms;
            }
        }

        public static function get_attributes_by_product_ids( $product_ids ) {

            $product_attributes = array();

            $taxonomies = self::get_product_attribute_taxonomies( $product_ids );

            if ( !count( $taxonomies ) ) {
                return $product_attributes;
            }

            try {

                global $wpdb;

                $sql = "SELECT term_relationships.object_id AS post_id, terms.term_id"
                        . " FROM {$wpdb->prefix}term_relationships AS term_relationships"
                        . " LEFT JOIN {$wpdb->prefix}term_taxonomy AS term_taxonomy ON term_relationships.term_taxonomy_id = term_taxonomy.term_taxonomy_id"
                        . " LEFT JOIN {$wpdb->prefix}terms AS terms ON terms.term_id = term_taxonomy.term_id"
                        . " WHERE (term_relationships.object_id IN (" . implode( ',', array_map( 'esc_sql', $product_ids ) ) . "))"
                        . " AND (term_taxonomy.taxonomy IN('" . implode( "','", array_map( 'esc_sql', $taxonomies ) ) . "'))";


                $results = $wpdb->get_results( $sql, ARRAY_A );

                foreach ( $results as $row ) {

                    if ( !isset( $product_attributes[ $row[ 'post_id' ] ] ) ) {

                        $product_attributes[ $row[ 'post_id' ] ] = array();
                    }

                    $product_attributes[ $row[ 'post_id' ] ][] = $row[ 'term_id' ];
                }

                return $product_attributes;
            } catch ( Exception $ex ) {

                return $product_attributes;
            }
        }

        public static function get_metas_by_ids( $product_ids, $meta_key ) {

            $metas = array();

            if ( !count( $product_ids ) ) {
                return $metas;
            }

            if ( empty( $meta_key ) ) {
                return $metas;
            }

            try {
                global $wpdb;

                $sql = "SELECT post_id, meta_value FROM {$wpdb->prefix}postmeta"
                        . " WHERE (post_id IN(" . implode( ",", array_map( 'esc_sql', array_values( $product_ids ) ) ) . "))"
                        . " AND (meta_key='%s')";


                $results = $wpdb->get_results( $wpdb->prepare( $sql, $meta_key ), ARRAY_A );

                foreach ( $results as $row ) {
                    $metas[ $row[ 'post_id' ] ] = $row[ 'meta_value' ];
                }
            } catch ( Exception $ex ) {

                return $metas;
            }


            return $metas;
        }

        public static function get_author_id( $product_id ) {

            return self::get_user_id_by_product( $product_id );
        }

        public static function get_author_roles( $product_id ) {

            $user = self::get_user_by_product( $product_id );

            if ( !$user ) {
                return array();
            }

            return $user->roles;
        }

        public static function get_author_caps( $product_id ) {

            $user = self::get_user_by_product( $product_id );

            $user_caps = array();

            if ( !$user ) {
                return $user_caps;
            }

            foreach ( $user->allcaps as $key => $user_cap ) {

                if ( $user_cap == true ) {
                    $user_caps[] = $key;
                }
            }

            return $user_caps;
        }

        public static function get_author_meta( $product_id, $meta_key, $default = array() ) {

            $user_id = self::get_user_id_by_product( $product_id );

            if ( 0 >= $user_id ) {
                return $default;
            }

            $user_meta = get_user_meta( $user_id, $meta_key, true );

            if ( !$user_meta ) {

                return $default;
            }

            return $user_meta;
        }

        private static function get_product_attribute_taxonomies( $product_ids ) {

            $attribute_taxonomies = array();

            try {
                global $wpdb;

                $sql = "SELECT postmeta.meta_value"
                        . " FROM {$wpdb->prefix}postmeta AS postmeta"
                        . " WHERE (postmeta.post_id IN(" . implode( ',', array_map( 'esc_sql', $product_ids ) ) . "))"
                        . " AND (postmeta.meta_key='_product_attributes')";


                $results = $wpdb->get_results( $sql, ARRAY_A );
            } catch ( Exception $ex ) {

                return $attribute_taxonomies;
            }

            if ( !isset( $results ) ) {
                return $attribute_taxonomies;
            }

            if ( !is_array( $results ) ) {
                return $attribute_taxonomies;
            }

            foreach ( $results as $row ) {

                $attr_obj = self::try_unserialize( $row[ 'meta_value' ] );

                foreach ( array_keys( $attr_obj ) as $key ) {
                    if ( !in_array( $key, $attribute_taxonomies ) ) {
                        $attribute_taxonomies[] = $key;
                    }
                }
            }

            return $attribute_taxonomies;
        }

        private static function try_unserialize( $str_obj ) {
            try {

                $obj = unserialize( $str_obj );
                if ( is_array( $obj ) ) {
                    return $obj;
                }
                return array();
            } catch ( Exception $ex ) {
                return array();
            }
        }

        private static function get_user_by_product( $product_id ) {

            $user_id = self::get_user_id_by_product( $product_id );

            if ( 0 >= $user_id ) {

                return false;
            }

            if ( isset( self::$users[ $user_id ] ) ) {

                return self::$users[ $user_id ];
            }

            $user = get_user_by( 'id', $user_id );

            if ( $user ) {
                self::$users[ $user_id ] = $user;
            }

            return $user;
        }

        private static function get_user_id_by_product( $product_id ) {

            if ( isset( self::$product_user_ids[ $product_id ] ) ) {

                return self::$product_user_ids[ $product_id ];
            }

            try {
                global $wpdb;

                $sql = "SELECT post_author FROM $wpdb->posts WHERE (id = " . esc_sql( $product_id ) . ")";

                $result = $wpdb->get_var( $sql );

                if ( $result != null ) {

                    self::$product_user_ids[ $product_id ] = $result;

                    return $result;
                }

                return 0;
            } catch ( Exception $ex ) {

                return 0;
            }
        }

    }

}