<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( !class_exists( 'WTARS_Shipped_Util' ) ) {

    WTARS_Shipped_Inc::recursive_require( dirname( __FILE__ ), array( 'shipped-utils.php' ) );

    class WTARS_Shipped_Util {

        public static function round_num( $val, int $precision = 0, int $mode = PHP_ROUND_HALF_UP ): float {

            if ( !is_numeric( $val ) ) {

                $val = floatval( $val );
            }

            return round( $val, $precision, $mode );
        }

        public static function get_value_by_range( $total_value, $range_args ) {

            if ( $total_value <= 0 ) {

                return 0;
            }

            if ( !$range_args ) {

                return $total_value;
            }

            if ( is_array( $range_args ) && !count( $range_args ) ) {

                return $total_value;
            }

            return self::get_value_from_range( self::get_value_to_range( $total_value, $range_args ), $range_args );
        }

        public static function get_product_ids_by_slugs( $slugs ) {

            $product_ids = array();


            $sql_hash = 'shp_product_ids' . md5( wp_json_encode( $slugs ) );

            $t_product_ids = get_transient( $sql_hash );

            if ( $t_product_ids ) {
                return $t_product_ids;
            }

            try {
                global $wpdb;

                $sql = "SELECT id FROM " . $wpdb->posts
                        . " WHERE (post_type='product')"
                        . " AND post_name IN('" . implode( "','", array_map( 'esc_sql', $slugs ) ) . "')";


                $results = $wpdb->get_results( $sql, ARRAY_A );

                foreach ( $results as $row ) {
                    $product_ids[] = $row[ 'id' ];
                }

                set_transient( $sql_hash, $product_ids, MINUTE_IN_SECONDS + 30 );
            } catch ( Exception $ex ) {
                return $product_ids;
            }


            return $product_ids;
        }

        public static function get_variation_ids_by_slugs( $slugs ) {

            $variation_ids = array();


            $sql_hash = 'shp_variation_ids' . md5( wp_json_encode( $slugs ) );

            $t_variation_ids = get_transient( $sql_hash );

            if ( $t_variation_ids ) {
                return $t_variation_ids;
            }

            try {
                global $wpdb;

                $sql = "SELECT id FROM " . $wpdb->posts
                        . " WHERE (post_type='product_variation')"
                        . " AND post_name IN('" . implode( "','", array_map( 'esc_sql', $slugs ) ) . "')";


                $results = $wpdb->get_results( $sql, ARRAY_A );

                foreach ( $results as $row ) {
                    $variation_ids[] = $row[ 'id' ];
                }

                set_transient( $sql_hash, $variation_ids, MINUTE_IN_SECONDS + 30 );
            } catch ( Exception $ex ) {
                return $variation_ids;
            }


            return $variation_ids;
        }

        public static function get_product_term_ids_by_slugs( $slugs, $taxonomy ) {
            $term_ids = array();

            $sql_hash = 'shp_' . $taxonomy . '_terms_ids' . md5( wp_json_encode( $slugs ) );

            $t_term_ids = get_transient( $sql_hash );

            if ( $t_term_ids ) {
                return $t_term_ids;
            }

            try {
                global $wpdb;

                $sql = "SELECT terms.term_id FROM {$wpdb->prefix}terms AS terms"
                        . " LEFT JOIN {$wpdb->prefix}term_taxonomy AS term_taxonomy ON terms.term_id=term_taxonomy.term_id"
                        . " WHERE (term_taxonomy.taxonomy=%s)"
                        . " AND slug IN('" . implode( "','", array_map( 'esc_sql', $slugs ) ) . "')";

                $results = $wpdb->get_results( $wpdb->prepare( $sql, $taxonomy ), ARRAY_A );

                foreach ( $results as $row ) {
                    $term_ids[] = $row[ 'term_id' ];
                }

                set_transient( $sql_hash, $term_ids, MINUTE_IN_SECONDS + 30 );
            } catch ( Exception $ex ) {
                return $term_ids;
            }
            return $term_ids;
        }

        public static function get_attribute_ids_by_slugs( $slugs ) {

            $attribute_ids = array();

            $sql_hash = 'shp_attribute_ids' . md5( wp_json_encode( $slugs ) );

            $t_attribute_ids = get_transient( $sql_hash );

            if ( $t_attribute_ids ) {
                return $t_attribute_ids;
            }

            $sql_slugs = array();

            $sql_taxonomy = array();

            foreach ( $slugs as $slug ) {
                $split_slug = explode( ':', $slug );
                if ( 2 != count( $split_slug ) ) {
                    continue;
                }

                if ( !in_array( $split_slug[ 0 ], $sql_slugs ) ) {
                    $sql_slugs[] = $split_slug[ 0 ];
                }
                if ( !in_array( $split_slug[ 1 ], $sql_taxonomy ) ) {
                    $sql_taxonomy[] = $split_slug[ 1 ];
                }
            }

            try {
                global $wpdb;

                $sql = "SELECT terms.term_id, terms.slug, term_taxonomy.taxonomy FROM {$wpdb->prefix}terms AS terms"
                        . " LEFT JOIN {$wpdb->prefix}term_taxonomy AS term_taxonomy ON terms.term_id=term_taxonomy.term_id"
                        . " WHERE (terms.slug IN('" . implode( "','", array_map( 'esc_sql', $sql_slugs ) ) . "'))"
                        . " AND (term_taxonomy.taxonomy IN('" . implode( "','", array_map( 'esc_sql', $sql_taxonomy ) ) . "'))";

                $results = $wpdb->get_results( $sql, ARRAY_A );

                foreach ( $results as $row ) {

                    if ( !in_array( $row[ 'slug' ] . ':' . $row[ 'taxonomy' ], $slugs ) ) {
                        continue;
                    }

                    $attribute_ids[] = $row[ 'term_id' ];
                }

                set_transient( $sql_hash, $attribute_ids, MINUTE_IN_SECONDS + 30 );
            } catch ( Exception $ex ) {
                return $attribute_ids;
            }
            return $attribute_ids;
        }

        private static function get_value_from_range( $total_value, $range_args ) {

            if ( $range_args[ 'value_from' ] <= 0 ) {

                return $total_value;
            }

            $value_from = $range_args[ 'value_from' ];

            $total_value = $total_value - $value_from;

            if ( $total_value < 0 ) {

                $total_value = 0;
            }

            return $total_value;
        }

        private static function get_value_to_range( $total_value, $range_args ) {


            if ( $range_args[ 'value_to' ] <= 0 ) {

                return $total_value;
            }

            $value_to = $range_args[ 'value_to' ];

            if ( $total_value > $value_to ) {

                return $value_to;
            }

            return $total_value;
        }

    }

}