<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}
if ( !class_exists( 'WTARS_Shipped_Premium_Extension' ) ) {

    class WTARS_Shipped_Premium_Extension {

        public function __construct() {

            if ( !defined( 'WTARS_SHIPPED_PRO_ASSETS_URL' ) ) {
                
                define( 'WTARS_SHIPPED_PRO_ASSETS_URL', plugins_url( 'assets/', __FILE__ ) );
            }

            if ( is_admin() ) {
                
                add_action( 'reon/init', array( $this, 'load_admin_page' ) );
                add_action( 'reon/render-option-page', array( $this, 'enqueue_admin_scripts' ), 20 );
            }

            add_action( 'init', array( $this, 'init_public' ) );
            
            require_once dirname( __FILE__ ) . '/compatibility/compatibility.php';
        }

        public function load_admin_page() {

            require_once dirname( __FILE__ ) . '/admin/admin.php';
        }

        public function init_public() {

            require_once dirname( __FILE__ ) . '/public/shipped.php';
        }

        public static function get_other_shipping_rates( $args ) {

            $data_list_args = array(
                'source' => 'wc:zones_shipping',
                'ajax' => false
            );

            $shipping_rates = array();

            foreach ( ReonApi::get_data_list( $data_list_args ) as $key => $method ) {

                if ( $args[ 'instance_id' ] == $key ) {

                    continue;
                }

                $shipping_rates[ $key ] = $method;
            }

            return apply_filters( 'wtars_shipped_admin/get-other-shipping-rates', $shipping_rates, $args );
        }

        public static function get_other_shipping_rate_ids( $rates, $instance_id ) {

            $rate_instance_ids = array();

            if ( !count( $rates ) ) {

                return $rate_ids;
            }

            $keys = array_keys( $rates );

            foreach ( $keys as $key ) {

                $rate_instance_id = $rates[ $key ]->get_instance_id();

                if ( $rate_instance_id == $instance_id ) {
                    continue;
                }

                $rate_instance_ids[ $key ] = $rate_instance_id;
            }

            if ( has_filter( 'wtars_shipped/get-other-shipping-rate-ids' ) ) {

                $rate_instance_ids = apply_filters( 'wtars_shipped/get-other-shipping-rate-ids', $rate_instance_ids, $rates );
            }

            return $rate_instance_ids;
        }

        public function enqueue_admin_scripts( $page ) {

            //FreshDesk Help
            if ( defined( 'WTARS_SHIPPED_ADMIN_PAGE' ) ) {

                $freshdesk_widget_id = '51000000763';

                $freshdesk_script = 'window.fwSettings={'
                        . " 'widget_id':" . $freshdesk_widget_id . " };"
                        . '!function(){if("function"!=typeof window.FreshworksWidget){var n=function(){n.q.push(arguments)};n.q=[],window.FreshworksWidget=n}}() ';

                wp_enqueue_script( 'freshdesk', 'https://aus-widget.freshworks.com/widgets/' . $freshdesk_widget_id . '.js', array(), '1.0', true );
                wp_add_inline_script( 'freshdesk', $freshdesk_script, 'before' );
            }
        }

    }

}